@@ -37,11 +37,7 @@
 #include <libgen.h>
 #include <limits.h>
 #include <unistd.h>
-#if defined(__OpenBSD__)
-#include <soundcard.h>
-#else
-#include <sys/soundcard.h>
-#endif
+#include <oss-includes.h>
 #include <sys/ioctl.h>
 
 #include <freerdp/freerdp.h>
@@ -67,16 +63,15 @@ typedef struct
 	rdpContext* rdpcontext;
 } AudinOSSDevice;
 
-#define OSS_LOG_ERR(_text, _error)                                    \
-	do                                                                \
-	{                                                                 \
-		if (_error != 0)                                              \
-		{                                                             \
-			char buffer[256] = { 0 };                                 \
-			WLog_ERR(TAG, "%s: %i - %s\n", _text, _error,             \
-			         winpr_strerror(_error, buffer, sizeof(buffer))); \
-		}                                                             \
-	} while (0)
+static void OSS_LOG_ERR(const char* _text, int _error)
+{
+	if ((_error) != 0)
+	{
+		char buffer[256] = { 0 };
+		WLog_ERR(TAG, "%s: %i - %s\n", (_text), (_error),
+		         winpr_strerror((_error), buffer, sizeof(buffer)));
+	}
+}
 
 static UINT32 audin_oss_get_format(const AUDIO_FORMAT* format)
 {
@@ -165,8 +160,8 @@ static DWORD WINAPI audin_oss_thread_func(LPVOID arg)
 
 	if (oss->dev_unit != -1)
 	{
-		sprintf_s(dev_name, (PATH_MAX - 1), "/dev/dsp%i", oss->dev_unit);
-		sprintf_s(mixer_name, PATH_MAX - 1, "/dev/mixer%i", oss->dev_unit);
+		(void)sprintf_s(dev_name, (PATH_MAX - 1), "/dev/dsp%i", oss->dev_unit);
+		(void)sprintf_s(mixer_name, PATH_MAX - 1, "/dev/mixer%i", oss->dev_unit);
 	}
 
 	WLog_INFO(TAG, "open: %s", dev_name);
@@ -233,7 +228,8 @@ static DWORD WINAPI audin_oss_thread_func(LPVOID arg)
 	if (ioctl(pcm_handle, SNDCTL_DSP_SETFRAGMENT, &tmp) == -1)
 		OSS_LOG_ERR("SNDCTL_DSP_SETFRAGMENT failed", errno);
 
-	buffer_size = (oss->FramesPerPacket * oss->format.nChannels * (oss->format.wBitsPerSample / 8));
+	buffer_size =
+	    (1ull * oss->FramesPerPacket * oss->format.nChannels * (oss->format.wBitsPerSample / 8ull));
 	buffer = (BYTE*)calloc((buffer_size + sizeof(void*)), sizeof(BYTE));
 
 	if (NULL == buffer)
@@ -390,7 +386,7 @@ static UINT audin_oss_parse_addin_args(AudinOSSDevice* device, const ADDIN_ARGV*
 	char* eptr = NULL;
 	DWORD flags = 0;
 	const COMMAND_LINE_ARGUMENT_A* arg = NULL;
-	AudinOSSDevice* oss = (AudinOSSDevice*)device;
+	AudinOSSDevice* oss = device;
 	COMMAND_LINE_ARGUMENT_A audin_oss_args[] = { { "dev", COMMAND_LINE_VALUE_REQUIRED, "<device>",
 		                                           NULL, NULL, -1, NULL, "audio device name" },
 		                                         { NULL, 0, NULL, NULL, NULL, -1, NULL, NULL } };
