@@ -44,7 +44,10 @@ UINT rail_send_pdu(railPlugin* rail, wStream* s, UINT16 orderType)
 	UINT16 orderLength = 0;
 
 	if (!rail || !s)
+	{
+		Stream_Free(s, TRUE);
 		return ERROR_INVALID_PARAMETER;
+	}
 
 	orderLength = (UINT16)Stream_GetPosition(s);
 	Stream_SetPosition(s, 0);
@@ -469,6 +472,13 @@ static UINT rail_recv_handshake_ex_order(railPlugin* rail, wStream* s)
 	rail->channelBuildNumber = serverHandshake.buildNumber;
 	rail->channelFlags = serverHandshake.railHandshakeFlags;
 
+	{
+		char buffer[192] = { 0 };
+		WLog_DBG(TAG, "HandshakeFlags=%s [buildNumber=0x%08" PRIx32 "]",
+		         rail_handshake_ex_flags_to_string(rail->channelFlags, buffer, sizeof(buffer)),
+		         rail->channelBuildNumber);
+	}
+
 	if (rail->sendHandshake)
 	{
 		RAIL_HANDSHAKE_ORDER clientHandshake = { 0 };
@@ -1107,13 +1117,10 @@ UINT rail_order_recv(LPVOID userdata, wStream* s)
  */
 UINT rail_send_handshake_order(railPlugin* rail, const RAIL_HANDSHAKE_ORDER* handshake)
 {
-	wStream* s = NULL;
-	UINT error = 0;
-
 	if (!rail || !handshake)
 		return ERROR_INVALID_PARAMETER;
 
-	s = rail_pdu_init(RAIL_HANDSHAKE_ORDER_LENGTH);
+	wStream* s = rail_pdu_init(RAIL_HANDSHAKE_ORDER_LENGTH);
 
 	if (!s)
 	{
@@ -1122,9 +1129,7 @@ UINT rail_send_handshake_order(railPlugin* rail, const RAIL_HANDSHAKE_ORDER* han
 	}
 
 	rail_write_handshake_order(s, handshake);
-	error = rail_send_pdu(rail, s, TS_RAIL_ORDER_HANDSHAKE);
-	Stream_Free(s, TRUE);
-	return error;
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_HANDSHAKE);
 }
 
 /**
@@ -1134,13 +1139,10 @@ UINT rail_send_handshake_order(railPlugin* rail, const RAIL_HANDSHAKE_ORDER* han
  */
 UINT rail_send_handshake_ex_order(railPlugin* rail, const RAIL_HANDSHAKE_EX_ORDER* handshakeEx)
 {
-	wStream* s = NULL;
-	UINT error = 0;
-
 	if (!rail || !handshakeEx)
 		return ERROR_INVALID_PARAMETER;
 
-	s = rail_pdu_init(RAIL_HANDSHAKE_EX_ORDER_LENGTH);
+	wStream* s = rail_pdu_init(RAIL_HANDSHAKE_EX_ORDER_LENGTH);
 
 	if (!s)
 	{
@@ -1149,9 +1151,7 @@ UINT rail_send_handshake_ex_order(railPlugin* rail, const RAIL_HANDSHAKE_EX_ORDE
 	}
 
 	rail_write_handshake_ex_order(s, handshakeEx);
-	error = rail_send_pdu(rail, s, TS_RAIL_ORDER_HANDSHAKE_EX);
-	Stream_Free(s, TRUE);
-	return error;
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_HANDSHAKE_EX);
 }
 
 /**
@@ -1178,11 +1178,14 @@ UINT rail_send_client_status_order(railPlugin* rail, const RAIL_CLIENT_STATUS_OR
 
 	error = rail_write_client_status_order(s, clientStatus);
 
-	if (error == ERROR_SUCCESS)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_CLIENTSTATUS);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_CLIENTSTATUS);
 }
 
 /**
@@ -1217,11 +1220,7 @@ UINT rail_send_client_exec_order(railPlugin* rail, UINT16 flags,
 		goto out;
 	}
 
-	if ((error = rail_send_pdu(rail, s, TS_RAIL_ORDER_EXEC)))
-	{
-		WLog_ERR(TAG, "rail_send_pdu failed with error %" PRIu32 "!", error);
-		goto out;
-	}
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_EXEC);
 
 out:
 	Stream_Free(s, TRUE);
@@ -1251,11 +1250,14 @@ UINT rail_send_client_activate_order(railPlugin* rail, const RAIL_ACTIVATE_ORDER
 
 	error = rail_write_client_activate_order(s, activate);
 
-	if (error == ERROR_SUCCESS)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_ACTIVATE);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_ACTIVATE);
 }
 
 /**
@@ -1281,11 +1283,14 @@ UINT rail_send_client_sysmenu_order(railPlugin* rail, const RAIL_SYSMENU_ORDER*
 
 	error = rail_write_client_sysmenu_order(s, sysmenu);
 
-	if (error == ERROR_SUCCESS)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_SYSMENU);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_SYSMENU);
 }
 
 /**
@@ -1311,11 +1316,14 @@ UINT rail_send_client_syscommand_order(railPlugin* rail, const RAIL_SYSCOMMAND_O
 
 	error = rail_write_client_syscommand_order(s, syscommand);
 
-	if (error == ERROR_SUCCESS)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_SYSCOMMAND);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_SYSCOMMAND);
 }
 
 /**
@@ -1342,11 +1350,14 @@ UINT rail_send_client_notify_event_order(railPlugin* rail,
 
 	error = rail_write_client_notify_event_order(s, notifyEvent);
 
-	if (ERROR_SUCCESS == error)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_NOTIFY_EVENT);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_NOTIFY_EVENT);
 }
 
 /**
@@ -1372,11 +1383,14 @@ UINT rail_send_client_window_move_order(railPlugin* rail, const RAIL_WINDOW_MOVE
 
 	error = rail_write_client_window_move_order(s, windowMove);
 
-	if (error == ERROR_SUCCESS)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_WINDOWMOVE);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_WINDOWMOVE);
 }
 
 /**
@@ -1403,11 +1417,13 @@ UINT rail_send_client_get_appid_req_order(railPlugin* rail,
 
 	error = rail_write_client_get_appid_req_order(s, getAppIdReq);
 
-	if (error == ERROR_SUCCESS)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_GET_APPID_REQ);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_GET_APPID_REQ);
 }
 
 /**
@@ -1437,11 +1453,13 @@ UINT rail_send_client_langbar_info_order(railPlugin* rail,
 
 	error = rail_write_langbar_info_order(s, langBarInfo);
 
-	if (ERROR_SUCCESS == error)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_LANGBARINFO);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_LANGBARINFO);
 }
 
 UINT rail_send_client_languageime_info_order(railPlugin* rail,
@@ -1466,11 +1484,13 @@ UINT rail_send_client_languageime_info_order(railPlugin* rail,
 
 	error = rail_write_languageime_info_order(s, langImeInfo);
 
-	if (ERROR_SUCCESS == error)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_LANGUAGEIMEINFO);
+	if (ERROR_SUCCESS != error)
+	{
 
-	Stream_Free(s, TRUE);
-	return error;
+		Stream_Free(s, TRUE);
+		return error;
+	}
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_LANGUAGEIMEINFO);
 }
 
 UINT rail_send_client_compartment_info_order(railPlugin* rail,
@@ -1495,22 +1515,20 @@ UINT rail_send_client_compartment_info_order(railPlugin* rail,
 
 	error = rail_write_compartment_info_order(s, compartmentInfo);
 
-	if (ERROR_SUCCESS == error)
-		error = rail_send_pdu(rail, s, TS_RAIL_ORDER_COMPARTMENTINFO);
-
-	Stream_Free(s, TRUE);
-	return error;
+	if (ERROR_SUCCESS != error)
+	{
+		Stream_Free(s, TRUE);
+		return error;
+	}
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_COMPARTMENTINFO);
 }
 
 UINT rail_send_client_cloak_order(railPlugin* rail, const RAIL_CLOAK* cloak)
 {
-	wStream* s = NULL;
-	UINT error = 0;
-
 	if (!rail || !cloak)
 		return ERROR_INVALID_PARAMETER;
 
-	s = rail_pdu_init(5);
+	wStream* s = rail_pdu_init(5);
 
 	if (!s)
 	{
@@ -1520,16 +1538,11 @@ UINT rail_send_client_cloak_order(railPlugin* rail, const RAIL_CLOAK* cloak)
 
 	Stream_Write_UINT32(s, cloak->windowId);
 	Stream_Write_UINT8(s, cloak->cloak ? 1 : 0);
-	error = rail_send_pdu(rail, s, TS_RAIL_ORDER_CLOAK);
-	Stream_Free(s, TRUE);
-	return error;
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_CLOAK);
 }
 
 UINT rail_send_client_snap_arrange_order(railPlugin* rail, const RAIL_SNAP_ARRANGE* snap)
 {
-	wStream* s = NULL;
-	UINT error = 0;
-
 	if (!rail)
 		return ERROR_INVALID_PARAMETER;
 
@@ -1545,7 +1558,7 @@ UINT rail_send_client_snap_arrange_order(railPlugin* rail, const RAIL_SNAP_ARRAN
 		return rail_send_client_window_move_order(rail, &move);
 	}
 
-	s = rail_pdu_init(12);
+	wStream* s = rail_pdu_init(12);
 
 	if (!s)
 	{
@@ -1558,7 +1571,5 @@ UINT rail_send_client_snap_arrange_order(railPlugin* rail, const RAIL_SNAP_ARRAN
 	Stream_Write_INT16(s, snap->top);
 	Stream_Write_INT16(s, snap->right);
 	Stream_Write_INT16(s, snap->bottom);
-	error = rail_send_pdu(rail, s, TS_RAIL_ORDER_SNAP_ARRANGE);
-	Stream_Free(s, TRUE);
-	return error;
+	return rail_send_pdu(rail, s, TS_RAIL_ORDER_SNAP_ARRANGE);
 }
