@@ -41,7 +41,7 @@
 static UINT rail_send(RailServerContext* context, wStream* s, ULONG length)
 {
 	UINT status = CHANNEL_RC_OK;
-	ULONG written;
+	ULONG written = 0;
 
 	if (!context)
 		return CHANNEL_RC_BAD_INIT_HANDLE;
@@ -64,7 +64,7 @@ static UINT rail_send(RailServerContext* context, wStream* s, ULONG length)
 static UINT rail_server_send_pdu(RailServerContext* context, wStream* s, UINT16 orderType)
 {
 	char buffer[128] = { 0 };
-	UINT16 orderLength;
+	UINT16 orderLength = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -265,8 +265,8 @@ static UINT rail_write_get_appid_resp_ex_order(wStream* s,
 static UINT rail_send_server_handshake(RailServerContext* context,
                                        const RAIL_HANDSHAKE_ORDER* handshake)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !handshake)
 		return ERROR_INVALID_PARAMETER;
@@ -293,8 +293,8 @@ static UINT rail_send_server_handshake(RailServerContext* context,
 static UINT rail_send_server_handshake_ex(RailServerContext* context,
                                           const RAIL_HANDSHAKE_EX_ORDER* handshakeEx)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !handshakeEx || !context->priv)
 		return ERROR_INVALID_PARAMETER;
@@ -323,10 +323,10 @@ static UINT rail_send_server_handshake_ex(RailServerContext* context,
 static UINT rail_send_server_sysparam(RailServerContext* context,
                                       const RAIL_SYSPARAM_ORDER* sysparam)
 {
-	wStream* s;
-	UINT error;
-	RailServerPrivate* priv;
-	BOOL extendedSpiSupported;
+	wStream* s = NULL;
+	UINT error = 0;
+	RailServerPrivate* priv = NULL;
+	BOOL extendedSpiSupported = 0;
 
 	if (!context || !sysparam)
 		return ERROR_INVALID_PARAMETER;
@@ -359,8 +359,8 @@ static UINT rail_send_server_sysparam(RailServerContext* context,
 static UINT rail_send_server_local_move_size(RailServerContext* context,
                                              const RAIL_LOCALMOVESIZE_ORDER* localMoveSize)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !localMoveSize)
 		return ERROR_INVALID_PARAMETER;
@@ -387,8 +387,8 @@ static UINT rail_send_server_local_move_size(RailServerContext* context,
 static UINT rail_send_server_min_max_info(RailServerContext* context,
                                           const RAIL_MINMAXINFO_ORDER* minMaxInfo)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !minMaxInfo)
 		return ERROR_INVALID_PARAMETER;
@@ -415,8 +415,8 @@ static UINT rail_send_server_min_max_info(RailServerContext* context,
 static UINT rail_send_server_taskbar_info(RailServerContext* context,
                                           const RAIL_TASKBAR_INFO_ORDER* taskbarInfo)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !taskbarInfo)
 		return ERROR_INVALID_PARAMETER;
@@ -443,8 +443,8 @@ static UINT rail_send_server_taskbar_info(RailServerContext* context,
 static UINT rail_send_server_langbar_info(RailServerContext* context,
                                           const RAIL_LANGBAR_INFO_ORDER* langbarInfo)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !langbarInfo)
 		return ERROR_INVALID_PARAMETER;
@@ -471,8 +471,8 @@ static UINT rail_send_server_langbar_info(RailServerContext* context,
 static UINT rail_send_server_exec_result(RailServerContext* context,
                                          const RAIL_EXEC_RESULT_ORDER* execResult)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !execResult)
 		return ERROR_INVALID_PARAMETER;
@@ -499,8 +499,8 @@ static UINT rail_send_server_exec_result(RailServerContext* context,
 static UINT rail_send_server_z_order_sync(RailServerContext* context,
                                           const RAIL_ZORDER_SYNC* zOrderSync)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !zOrderSync)
 		return ERROR_INVALID_PARAMETER;
@@ -526,8 +526,8 @@ static UINT rail_send_server_z_order_sync(RailServerContext* context,
  */
 static UINT rail_send_server_cloak(RailServerContext* context, const RAIL_CLOAK* cloak)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !cloak)
 		return ERROR_INVALID_PARAMETER;
@@ -555,8 +555,8 @@ static UINT
 rail_send_server_power_display_request(RailServerContext* context,
                                        const RAIL_POWER_DISPLAY_REQUEST* powerDisplayRequest)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !powerDisplayRequest)
 		return ERROR_INVALID_PARAMETER;
@@ -583,8 +583,8 @@ rail_send_server_power_display_request(RailServerContext* context,
 static UINT rail_send_server_get_app_id_resp(RailServerContext* context,
                                              const RAIL_GET_APPID_RESP_ORDER* getAppidResp)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !getAppidResp)
 		return ERROR_INVALID_PARAMETER;
@@ -611,8 +611,8 @@ static UINT rail_send_server_get_app_id_resp(RailServerContext* context,
 static UINT rail_send_server_get_appid_resp_ex(RailServerContext* context,
                                                const RAIL_GET_APPID_RESP_EX* getAppidRespEx)
 {
-	wStream* s;
-	UINT error;
+	wStream* s = NULL;
+	UINT error = 0;
 
 	if (!context || !getAppidRespEx)
 		return ERROR_INVALID_PARAMETER;
@@ -650,10 +650,12 @@ static UINT rail_read_client_status_order(wStream* s, RAIL_CLIENT_STATUS_ORDER*
  *
  * @return 0 on success, otherwise a Win32 error code
  */
-static UINT rail_read_exec_order(wStream* s, RAIL_EXEC_ORDER* exec)
+static UINT rail_read_exec_order(wStream* s, RAIL_EXEC_ORDER* exec, char* args[])
 {
 	RAIL_EXEC_ORDER order = { 0 };
-	UINT16 exeLen, workLen, argLen;
+	UINT16 exeLen = 0;
+	UINT16 workLen = 0;
+	UINT16 argLen = 0;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, RAIL_EXEC_ORDER_LENGTH))
 		return ERROR_INVALID_DATA;
@@ -668,31 +670,32 @@ static UINT rail_read_exec_order(wStream* s, RAIL_EXEC_ORDER* exec)
 
 	if (exeLen > 0)
 	{
-		const SSIZE_T len = exeLen / sizeof(WCHAR);
-		exec->RemoteApplicationProgram = Stream_Read_UTF16_String_As_UTF8(s, len, NULL);
+		const size_t len = exeLen / sizeof(WCHAR);
+		exec->RemoteApplicationProgram = args[0] = Stream_Read_UTF16_String_As_UTF8(s, len, NULL);
 		if (!exec->RemoteApplicationProgram)
 			goto fail;
 	}
 	if (workLen > 0)
 	{
-		const SSIZE_T len = workLen / sizeof(WCHAR);
-		exec->RemoteApplicationWorkingDir = Stream_Read_UTF16_String_As_UTF8(s, len, NULL);
+		const size_t len = workLen / sizeof(WCHAR);
+		exec->RemoteApplicationWorkingDir = args[1] =
+		    Stream_Read_UTF16_String_As_UTF8(s, len, NULL);
 		if (!exec->RemoteApplicationWorkingDir)
 			goto fail;
 	}
 	if (argLen > 0)
 	{
-		const SSIZE_T len = argLen / sizeof(WCHAR);
-		exec->RemoteApplicationArguments = Stream_Read_UTF16_String_As_UTF8(s, len, NULL);
+		const size_t len = argLen / sizeof(WCHAR);
+		exec->RemoteApplicationArguments = args[2] = Stream_Read_UTF16_String_As_UTF8(s, len, NULL);
 		if (!exec->RemoteApplicationArguments)
 			goto fail;
 	}
 
 	return CHANNEL_RC_OK;
 fail:
-	free(exec->RemoteApplicationProgram);
-	free(exec->RemoteApplicationArguments);
-	free(exec->RemoteApplicationWorkingDir);
+	free(args[0]);
+	free(args[1]);
+	free(args[2]);
 	*exec = order;
 	return ERROR_INTERNAL_ERROR;
 }
@@ -704,7 +707,7 @@ fail:
  */
 static UINT rail_read_activate_order(wStream* s, RAIL_ACTIVATE_ORDER* activate)
 {
-	BYTE enabled;
+	BYTE enabled = 0;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, RAIL_ACTIVATE_ORDER_LENGTH))
 		return ERROR_INVALID_DATA;
@@ -873,7 +876,7 @@ static UINT rail_read_compartment_info_order(wStream* s,
  */
 static UINT rail_read_cloak_order(wStream* s, RAIL_CLOAK* cloak)
 {
-	BYTE cloaked;
+	BYTE cloaked = 0;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, RAIL_CLOAK_ORDER_LENGTH))
 		return ERROR_INVALID_DATA;
@@ -892,7 +895,7 @@ static UINT rail_read_cloak_order(wStream* s, RAIL_CLOAK* cloak)
 static UINT rail_recv_client_handshake_order(RailServerContext* context,
                                              RAIL_HANDSHAKE_ORDER* handshake, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !handshake || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -919,7 +922,7 @@ static UINT rail_recv_client_handshake_order(RailServerContext* context,
 static UINT rail_recv_client_client_status_order(RailServerContext* context,
                                                  RAIL_CLIENT_STATUS_ORDER* clientStatus, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !clientStatus || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -945,13 +948,15 @@ static UINT rail_recv_client_client_status_order(RailServerContext* context,
  */
 static UINT rail_recv_client_exec_order(RailServerContext* context, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
+	char* args[3] = { 0 };
 	RAIL_EXEC_ORDER exec = { 0 };
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
 
-	if ((error = rail_read_exec_order(s, &exec)))
+	error = rail_read_exec_order(s, &exec, args);
+	if (error)
 	{
 		WLog_ERR(TAG, "rail_read_client_status_order failed with error %" PRIu32 "!", error);
 		return error;
@@ -962,9 +967,9 @@ static UINT rail_recv_client_exec_order(RailServerContext* context, wStream* s)
 	if (error)
 		WLog_ERR(TAG, "context.Exec failed with error %" PRIu32 "", error);
 
-	free(exec.RemoteApplicationProgram);
-	free(exec.RemoteApplicationArguments);
-	free(exec.RemoteApplicationWorkingDir);
+	free(args[0]);
+	free(args[1]);
+	free(args[2]);
 	return error;
 }
 
@@ -976,8 +981,8 @@ static UINT rail_recv_client_exec_order(RailServerContext* context, wStream* s)
 static UINT rail_recv_client_sysparam_order(RailServerContext* context,
                                             RAIL_SYSPARAM_ORDER* sysparam, wStream* s)
 {
-	UINT error;
-	BOOL extendedSpiSupported;
+	UINT error = 0;
+	BOOL extendedSpiSupported = 0;
 
 	if (!context || !sysparam || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1005,7 +1010,7 @@ static UINT rail_recv_client_sysparam_order(RailServerContext* context,
 static UINT rail_recv_client_activate_order(RailServerContext* context,
                                             RAIL_ACTIVATE_ORDER* activate, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !activate || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1032,7 +1037,7 @@ static UINT rail_recv_client_activate_order(RailServerContext* context,
 static UINT rail_recv_client_sysmenu_order(RailServerContext* context, RAIL_SYSMENU_ORDER* sysmenu,
                                            wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !sysmenu || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1059,7 +1064,7 @@ static UINT rail_recv_client_sysmenu_order(RailServerContext* context, RAIL_SYSM
 static UINT rail_recv_client_syscommand_order(RailServerContext* context,
                                               RAIL_SYSCOMMAND_ORDER* syscommand, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !syscommand || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1086,7 +1091,7 @@ static UINT rail_recv_client_syscommand_order(RailServerContext* context,
 static UINT rail_recv_client_notify_event_order(RailServerContext* context,
                                                 RAIL_NOTIFY_EVENT_ORDER* notifyEvent, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !notifyEvent || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1113,7 +1118,7 @@ static UINT rail_recv_client_notify_event_order(RailServerContext* context,
 static UINT rail_recv_client_window_move_order(RailServerContext* context,
                                                RAIL_WINDOW_MOVE_ORDER* windowMove, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !windowMove || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1140,7 +1145,7 @@ static UINT rail_recv_client_window_move_order(RailServerContext* context,
 static UINT rail_recv_client_snap_arrange_order(RailServerContext* context,
                                                 RAIL_SNAP_ARRANGE* snapArrange, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !snapArrange || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1167,7 +1172,7 @@ static UINT rail_recv_client_snap_arrange_order(RailServerContext* context,
 static UINT rail_recv_client_get_appid_req_order(RailServerContext* context,
                                                  RAIL_GET_APPID_REQ_ORDER* getAppidReq, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !getAppidReq || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1194,7 +1199,7 @@ static UINT rail_recv_client_get_appid_req_order(RailServerContext* context,
 static UINT rail_recv_client_langbar_info_order(RailServerContext* context,
                                                 RAIL_LANGBAR_INFO_ORDER* langbarInfo, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !langbarInfo || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1222,7 +1227,7 @@ static UINT rail_recv_client_language_ime_info_order(RailServerContext* context,
                                                      RAIL_LANGUAGEIME_INFO_ORDER* languageImeInfo,
                                                      wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !languageImeInfo || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1250,7 +1255,7 @@ static UINT rail_recv_client_compartment_info(RailServerContext* context,
                                               RAIL_COMPARTMENT_INFO_ORDER* compartmentInfo,
                                               wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !compartmentInfo || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1276,7 +1281,7 @@ static UINT rail_recv_client_compartment_info(RailServerContext* context,
  */
 static UINT rail_recv_client_cloak_order(RailServerContext* context, RAIL_CLOAK* cloak, wStream* s)
 {
-	UINT error;
+	UINT error = 0;
 
 	if (!context || !cloak || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1298,7 +1303,7 @@ static UINT rail_recv_client_cloak_order(RailServerContext* context, RAIL_CLOAK*
 static UINT rail_recv_client_text_scale_order(RailServerContext* context, wStream* s)
 {
 	UINT error = CHANNEL_RC_OK;
-	UINT32 TextScaleFactor;
+	UINT32 TextScaleFactor = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1318,7 +1323,7 @@ static UINT rail_recv_client_text_scale_order(RailServerContext* context, wStrea
 static UINT rail_recv_client_caret_blink(RailServerContext* context, wStream* s)
 {
 	UINT error = CHANNEL_RC_OK;
-	UINT32 CaretBlinkRate;
+	UINT32 CaretBlinkRate = 0;
 
 	if (!context || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -1339,7 +1344,7 @@ static DWORD WINAPI rail_server_thread(LPVOID arg)
 {
 	RailServerContext* context = (RailServerContext*)arg;
 	RailServerPrivate* priv = context->priv;
-	DWORD status;
+	DWORD status = 0;
 	DWORD nCount = 0;
 	HANDLE events[8];
 	UINT error = CHANNEL_RC_OK;
@@ -1407,7 +1412,7 @@ static DWORD WINAPI rail_server_thread(LPVOID arg)
 static UINT rail_server_start(RailServerContext* context)
 {
 	void* buffer = NULL;
-	DWORD bytesReturned;
+	DWORD bytesReturned = 0;
 	RailServerPrivate* priv = context->priv;
 	UINT error = ERROR_INTERNAL_ERROR;
 	priv->rail_channel =
@@ -1464,7 +1469,7 @@ out_close:
 
 static BOOL rail_server_stop(RailServerContext* context)
 {
-	RailServerPrivate* priv = (RailServerPrivate*)context->priv;
+	RailServerPrivate* priv = context->priv;
 
 	if (priv->thread)
 	{
@@ -1494,8 +1499,8 @@ static BOOL rail_server_stop(RailServerContext* context)
 
 RailServerContext* rail_server_context_new(HANDLE vcm)
 {
-	RailServerContext* context;
-	RailServerPrivate* priv;
+	RailServerContext* context = NULL;
+	RailServerPrivate* priv = NULL;
 	context = (RailServerContext*)calloc(1, sizeof(RailServerContext));
 
 	if (!context)
@@ -1556,7 +1561,7 @@ void rail_server_context_free(RailServerContext* context)
 
 void rail_server_set_handshake_ex_flags(RailServerContext* context, DWORD flags)
 {
-	RailServerPrivate* priv;
+	RailServerPrivate* priv = NULL;
 
 	if (!context || !context->priv)
 		return;
@@ -1569,9 +1574,9 @@ UINT rail_server_handle_messages(RailServerContext* context)
 {
 	char buffer[128] = { 0 };
 	UINT status = CHANNEL_RC_OK;
-	DWORD bytesReturned;
-	UINT16 orderType;
-	UINT16 orderLength;
+	DWORD bytesReturned = 0;
+	UINT16 orderType = 0;
+	UINT16 orderLength = 0;
 	RailServerPrivate* priv = context->priv;
 	wStream* s = priv->input_stream;
 
