@@ -114,6 +114,7 @@ struct rdpsnd_plugin
 
 	size_t references;
 	BOOL OnOpenCalled;
+	BOOL async;
 };
 
 static const char* rdpsnd_is_dyn_str(BOOL dynamic)
@@ -139,7 +140,7 @@ static UINT rdpsnd_virtual_channel_write(rdpsndPlugin* rdpsnd, wStream* s);
  */
 static UINT rdpsnd_send_quality_mode_pdu(rdpsndPlugin* rdpsnd)
 {
-	wStream* pdu;
+	wStream* pdu = NULL;
 	WINPR_ASSERT(rdpsnd);
 	pdu = Stream_New(NULL, 8);
 
@@ -161,7 +162,6 @@ static UINT rdpsnd_send_quality_mode_pdu(rdpsndPlugin* rdpsnd)
 
 static void rdpsnd_select_supported_audio_formats(rdpsndPlugin* rdpsnd)
 {
-	UINT16 index;
 	WINPR_ASSERT(rdpsnd);
 	audio_formats_free(rdpsnd->ClientFormats, rdpsnd->NumberOfClientFormats);
 	rdpsnd->NumberOfClientFormats = 0;
@@ -175,7 +175,7 @@ static void rdpsnd_select_supported_audio_formats(rdpsndPlugin* rdpsnd)
 	if (!rdpsnd->ClientFormats || !rdpsnd->device)
 		return;
 
-	for (index = 0; index < rdpsnd->NumberOfServerFormats; index++)
+	for (UINT16 index = 0; index < rdpsnd->NumberOfServerFormats; index++)
 	{
 		const AUDIO_FORMAT* serverFormat = &rdpsnd->ServerFormats[index];
 
@@ -199,11 +199,10 @@ static void rdpsnd_select_supported_audio_formats(rdpsndPlugin* rdpsnd)
  */
 static UINT rdpsnd_send_client_audio_formats(rdpsndPlugin* rdpsnd)
 {
-	UINT16 index;
-	wStream* pdu;
-	UINT16 length;
-	UINT32 dwVolume;
-	UINT16 wNumberOfFormats;
+	wStream* pdu = NULL;
+	UINT16 length = 0;
+	UINT32 dwVolume = 0;
+	UINT16 wNumberOfFormats = 0;
 	WINPR_ASSERT(rdpsnd);
 
 	if (!rdpsnd->device || (!rdpsnd->dynamic && (rdpsnd->OpenHandle == 0)))
@@ -213,7 +212,7 @@ static UINT rdpsnd_send_client_audio_formats(rdpsndPlugin* rdpsnd)
 	wNumberOfFormats = rdpsnd->NumberOfClientFormats;
 	length = 4 + 20;
 
-	for (index = 0; index < wNumberOfFormats; index++)
+	for (UINT16 index = 0; index < wNumberOfFormats; index++)
 		length += (18 + rdpsnd->ClientFormats[index].cbSize);
 
 	pdu = Stream_New(NULL, length);
@@ -236,7 +235,7 @@ static UINT rdpsnd_send_client_audio_formats(rdpsndPlugin* rdpsnd)
 	Stream_Write_UINT16(pdu, CHANNEL_VERSION_WIN_MAX);            /* wVersion */
 	Stream_Write_UINT8(pdu, 0);                                   /* bPad */
 
-	for (index = 0; index < wNumberOfFormats; index++)
+	for (UINT16 index = 0; index < wNumberOfFormats; index++)
 	{
 		const AUDIO_FORMAT* clientFormat = &rdpsnd->ClientFormats[index];
 
@@ -259,8 +258,7 @@ static UINT rdpsnd_send_client_audio_formats(rdpsndPlugin* rdpsnd)
  */
 static UINT rdpsnd_recv_server_audio_formats_pdu(rdpsndPlugin* rdpsnd, wStream* s)
 {
-	UINT16 index;
-	UINT16 wNumberOfFormats;
+	UINT16 wNumberOfFormats = 0;
 	UINT ret = ERROR_BAD_LENGTH;
 
 	WINPR_ASSERT(rdpsnd);
@@ -292,7 +290,7 @@ static UINT rdpsnd_recv_server_audio_formats_pdu(rdpsndPlugin* rdpsnd, wStream*
 		if (!rdpsnd->ServerFormats)
 			return CHANNEL_RC_NO_MEMORY;
 
-		for (index = 0; index < wNumberOfFormats; index++)
+		for (UINT16 index = 0; index < wNumberOfFormats; index++)
 		{
 			AUDIO_FORMAT* format = &rdpsnd->ServerFormats[index];
 
@@ -304,6 +302,8 @@ static UINT rdpsnd_recv_server_audio_formats_pdu(rdpsndPlugin* rdpsnd, wStream*
 	WINPR_ASSERT(rdpsnd->device);
 	ret = IFCALLRESULT(CHANNEL_RC_OK, rdpsnd->device->ServerFormatAnnounce, rdpsnd->device,
 	                   rdpsnd->ServerFormats, rdpsnd->NumberOfServerFormats);
+	if (ret != CHANNEL_RC_OK)
+		goto out_fail;
 
 	rdpsnd_select_supported_audio_formats(rdpsnd);
 	WLog_Print(rdpsnd->log, WLOG_DEBUG, "%s Server Audio Formats",
@@ -332,7 +332,7 @@ out_fail:
 static UINT rdpsnd_send_training_confirm_pdu(rdpsndPlugin* rdpsnd, UINT16 wTimeStamp,
                                              UINT16 wPackSize)
 {
-	wStream* pdu;
+	wStream* pdu = NULL;
 	WINPR_ASSERT(rdpsnd);
 	pdu = Stream_New(NULL, 8);
 
@@ -360,8 +360,8 @@ static UINT rdpsnd_send_training_confirm_pdu(rdpsndPlugin* rdpsnd, UINT16 wTimeS
  */
 static UINT rdpsnd_recv_training_pdu(rdpsndPlugin* rdpsnd, wStream* s)
 {
-	UINT16 wTimeStamp;
-	UINT16 wPackSize;
+	UINT16 wTimeStamp = 0;
+	UINT16 wPackSize = 0;
 	WINPR_ASSERT(rdpsnd);
 	WINPR_ASSERT(s);
 
@@ -399,8 +399,8 @@ static BOOL rdpsnd_ensure_device_is_open(rdpsndPlugin* rdpsnd, UINT32 wFormatNo,
 
 	if (!rdpsnd->isOpen || (wFormatNo != rdpsnd->wCurrentFormatNo))
 	{
-		BOOL rc;
-		BOOL supported;
+		BOOL rc = 0;
+		BOOL supported = 0;
 		AUDIO_FORMAT deviceFormat = *format;
 
 		IFCALL(rdpsnd->device->Close, rdpsnd->device);
@@ -449,8 +449,8 @@ static BOOL rdpsnd_ensure_device_is_open(rdpsndPlugin* rdpsnd, UINT32 wFormatNo,
  */
 static UINT rdpsnd_recv_wave_info_pdu(rdpsndPlugin* rdpsnd, wStream* s, UINT16 BodySize)
 {
-	UINT16 wFormatNo;
-	const AUDIO_FORMAT* format;
+	UINT16 wFormatNo = 0;
+	const AUDIO_FORMAT* format = NULL;
 	WINPR_ASSERT(rdpsnd);
 	WINPR_ASSERT(s);
 
@@ -489,7 +489,7 @@ static UINT rdpsnd_recv_wave_info_pdu(rdpsndPlugin* rdpsnd, wStream* s, UINT16 B
 static UINT rdpsnd_send_wave_confirm_pdu(rdpsndPlugin* rdpsnd, UINT16 wTimeStamp,
                                          BYTE cConfirmedBlockNo)
 {
-	wStream* pdu;
+	wStream* pdu = NULL;
 	WINPR_ASSERT(rdpsnd);
 	pdu = Stream_New(NULL, 8);
 
@@ -510,12 +510,12 @@ static UINT rdpsnd_send_wave_confirm_pdu(rdpsndPlugin* rdpsnd, UINT16 wTimeStamp
 
 static BOOL rdpsnd_detect_overrun(rdpsndPlugin* rdpsnd, const AUDIO_FORMAT* format, size_t size)
 {
-	UINT32 bpf;
-	UINT32 now;
-	UINT32 duration;
-	UINT32 totalDuration;
-	UINT32 remainingDuration;
-	UINT32 maxDuration;
+	UINT32 bpf = 0;
+	UINT32 now = 0;
+	UINT32 duration = 0;
+	UINT32 totalDuration = 0;
+	UINT32 remainingDuration = 0;
+	UINT32 maxDuration = 0;
 
 	if (!rdpsnd || !format)
 		return FALSE;
@@ -598,11 +598,12 @@ static BOOL rdpsnd_detect_overrun(rdpsndPlugin* rdpsnd, const AUDIO_FORMAT* form
 
 static UINT rdpsnd_treat_wave(rdpsndPlugin* rdpsnd, wStream* s, size_t size)
 {
-	AUDIO_FORMAT* format;
-	UINT64 end;
-	UINT64 diffMS, ts;
+	AUDIO_FORMAT* format = NULL;
+	UINT64 end = 0;
+	UINT64 diffMS = 0;
+	UINT64 ts = 0;
 	UINT latency = 0;
-	UINT error;
+	UINT error = 0;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, size))
 		return ERROR_BAD_LENGTH;
@@ -693,9 +694,9 @@ static UINT rdpsnd_recv_wave_pdu(rdpsndPlugin* rdpsnd, wStream* s)
 
 static UINT rdpsnd_recv_wave2_pdu(rdpsndPlugin* rdpsnd, wStream* s, UINT16 BodySize)
 {
-	UINT16 wFormatNo;
-	AUDIO_FORMAT* format;
-	UINT32 dwAudioTimeStamp;
+	UINT16 wFormatNo = 0;
+	AUDIO_FORMAT* format = NULL;
+	UINT32 dwAudioTimeStamp = 0;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, 12))
 		return ERROR_BAD_LENGTH;
@@ -741,7 +742,7 @@ static void rdpsnd_recv_close_pdu(rdpsndPlugin* rdpsnd)
 static UINT rdpsnd_recv_volume_pdu(rdpsndPlugin* rdpsnd, wStream* s)
 {
 	BOOL rc = TRUE;
-	UINT32 dwVolume;
+	UINT32 dwVolume = 0;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, 4))
 		return ERROR_BAD_LENGTH;
@@ -770,8 +771,8 @@ static UINT rdpsnd_recv_volume_pdu(rdpsndPlugin* rdpsnd, wStream* s)
  */
 static UINT rdpsnd_recv_pdu(rdpsndPlugin* rdpsnd, wStream* s)
 {
-	BYTE msgType;
-	UINT16 BodySize;
+	BYTE msgType = 0;
+	UINT16 BodySize = 0;
 	UINT status = CHANNEL_RC_OK;
 
 	if (rdpsnd->expectingWave)
@@ -847,9 +848,9 @@ static void rdpsnd_register_device_plugin(rdpsndPlugin* rdpsnd, rdpsndDevicePlug
 static UINT rdpsnd_load_device_plugin(rdpsndPlugin* rdpsnd, const char* name,
                                       const ADDIN_ARGV* args)
 {
-	PFREERDP_RDPSND_DEVICE_ENTRY entry;
+	PFREERDP_RDPSND_DEVICE_ENTRY entry = NULL;
 	FREERDP_RDPSND_DEVICE_ENTRY_POINTS entryPoints;
-	UINT error;
+	UINT error = 0;
 	DWORD flags = FREERDP_ADDIN_CHANNEL_STATIC | FREERDP_ADDIN_CHANNEL_ENTRYEX;
 	if (rdpsnd->dynamic)
 		flags = FREERDP_ADDIN_CHANNEL_DYNAMIC;
@@ -892,9 +893,9 @@ static BOOL rdpsnd_set_device_name(rdpsndPlugin* rdpsnd, const char* device_name
  */
 static UINT rdpsnd_process_addin_args(rdpsndPlugin* rdpsnd, const ADDIN_ARGV* args)
 {
-	int status;
-	DWORD flags;
-	const COMMAND_LINE_ARGUMENT_A* arg;
+	int status = 0;
+	DWORD flags = 0;
+	const COMMAND_LINE_ARGUMENT_A* arg = NULL;
 	COMMAND_LINE_ARGUMENT_A rdpsnd_args[] = {
 		{ "sys", COMMAND_LINE_VALUE_REQUIRED, "<subsystem>", NULL, NULL, -1, NULL, "subsystem" },
 		{ "dev", COMMAND_LINE_VALUE_REQUIRED, "<device>", NULL, NULL, -1, NULL, "device" },
@@ -1042,7 +1043,7 @@ static UINT rdpsnd_process_connect(rdpsndPlugin* rdpsnd)
 #endif
 		{ "fake", "" }
 	};
-	const ADDIN_ARGV* args;
+	const ADDIN_ARGV* args = NULL;
 	UINT status = ERROR_INTERNAL_ERROR;
 	WINPR_ASSERT(rdpsnd);
 	rdpsnd->latency = 0;
@@ -1068,9 +1069,7 @@ static UINT rdpsnd_process_connect(rdpsndPlugin* rdpsnd)
 	}
 	else
 	{
-		size_t x;
-
-		for (x = 0; x < ARRAYSIZE(backends); x++)
+		for (size_t x = 0; x < ARRAYSIZE(backends); x++)
 		{
 			const char* subsystem_name = backends[x].subsystem;
 			const char* device_name = backends[x].device;
@@ -1111,7 +1110,7 @@ UINT rdpsnd_virtual_channel_write(rdpsndPlugin* rdpsnd, wStream* s)
 	{
 		if (rdpsnd->dynamic)
 		{
-			IWTSVirtualChannel* channel;
+			IWTSVirtualChannel* channel = NULL;
 			if (rdpsnd->listener_callback)
 			{
 				channel = rdpsnd->listener_callback->channel_callback->channel;
@@ -1167,10 +1166,19 @@ static UINT rdpsnd_virtual_channel_event_data_received(rdpsndPlugin* plugin, voi
 		Stream_SealLength(plugin->data_in);
 		Stream_SetPosition(plugin->data_in, 0);
 
-		if (!MessageQueue_Post(plugin->queue, NULL, 0, plugin->data_in, NULL))
-			return ERROR_INTERNAL_ERROR;
-
-		plugin->data_in = NULL;
+		if (plugin->async)
+		{
+			if (!MessageQueue_Post(plugin->queue, NULL, 0, plugin->data_in, NULL))
+				return ERROR_INTERNAL_ERROR;
+			plugin->data_in = NULL;
+		}
+		else
+		{
+			UINT error = rdpsnd_recv_pdu(plugin, plugin->data_in);
+			plugin->data_in = NULL;
+			if (error)
+				return error;
+		}
 	}
 
 	return CHANNEL_RC_OK;
@@ -1221,9 +1229,9 @@ static VOID VCAPITYPE rdpsnd_virtual_channel_open_event_ex(LPVOID lpUserParam, D
 	if (error && rdpsnd && rdpsnd->rdpcontext)
 	{
 		char buffer[8192];
-		_snprintf(buffer, sizeof(buffer),
-		          "%s rdpsnd_virtual_channel_open_event_ex reported an error",
-		          rdpsnd_is_dyn_str(rdpsnd->dynamic));
+		(void)_snprintf(buffer, sizeof(buffer),
+		                "%s rdpsnd_virtual_channel_open_event_ex reported an error",
+		                rdpsnd_is_dyn_str(rdpsnd->dynamic));
 		setChannelError(rdpsnd->rdpcontext, error, buffer);
 	}
 }
@@ -1236,7 +1244,7 @@ static VOID VCAPITYPE rdpsnd_virtual_channel_open_event_ex(LPVOID lpUserParam, D
 static UINT rdpsnd_virtual_channel_event_connected(rdpsndPlugin* rdpsnd, LPVOID pData,
                                                    UINT32 dataLength)
 {
-	UINT32 status;
+	UINT32 status = 0;
 	DWORD opened = 0;
 	WINPR_UNUSED(pData);
 	WINPR_UNUSED(dataLength);
@@ -1291,7 +1299,7 @@ static void cleanup_internals(rdpsndPlugin* rdpsnd)
  */
 static UINT rdpsnd_virtual_channel_event_disconnected(rdpsndPlugin* rdpsnd)
 {
-	UINT error;
+	UINT error = 0;
 
 	WINPR_ASSERT(rdpsnd);
 	WINPR_ASSERT(!rdpsnd->dynamic);
@@ -1323,7 +1331,7 @@ static UINT rdpsnd_virtual_channel_event_disconnected(rdpsndPlugin* rdpsnd)
 	return CHANNEL_RC_OK;
 }
 
-static void _queue_free(void* obj)
+static void queue_free(void* obj)
 {
 	wMessage* msg = obj;
 	if (!msg)
@@ -1420,19 +1428,22 @@ static DWORD WINAPI play_thread(LPVOID arg)
 
 static UINT rdpsnd_virtual_channel_event_initialized(rdpsndPlugin* rdpsnd)
 {
-	wObject obj = { 0 };
-
 	if (!rdpsnd)
 		return ERROR_INVALID_PARAMETER;
 
-	obj.fnObjectFree = _queue_free;
-	rdpsnd->queue = MessageQueue_New(&obj);
-	if (!rdpsnd->queue)
-		return CHANNEL_RC_NO_MEMORY;
+	if (rdpsnd->async)
+	{
+		wObject obj = { 0 };
 
-	rdpsnd->thread = CreateThread(NULL, 0, play_thread, rdpsnd, 0, NULL);
-	if (!rdpsnd->thread)
-		return CHANNEL_RC_INITIALIZATION_ERROR;
+		obj.fnObjectFree = queue_free;
+		rdpsnd->queue = MessageQueue_New(&obj);
+		if (!rdpsnd->queue)
+			return CHANNEL_RC_NO_MEMORY;
+
+		rdpsnd->thread = CreateThread(NULL, 0, play_thread, rdpsnd, 0, NULL);
+		if (!rdpsnd->thread)
+			return CHANNEL_RC_INITIALIZATION_ERROR;
+	}
 
 	if (!allocate_internals(rdpsnd))
 		return CHANNEL_RC_NO_MEMORY;
@@ -1514,8 +1525,8 @@ static VOID VCAPITYPE rdpsnd_virtual_channel_init_event_ex(LPVOID lpUserParam, L
 	if (error && plugin && plugin->rdpcontext)
 	{
 		char buffer[8192];
-		_snprintf(buffer, sizeof(buffer), "%s reported an error",
-		          rdpsnd_is_dyn_str(plugin->dynamic));
+		(void)_snprintf(buffer, sizeof(buffer), "%s reported an error",
+		                rdpsnd_is_dyn_str(plugin->dynamic));
 		setChannelError(plugin->rdpcontext, error, buffer);
 	}
 }
@@ -1547,15 +1558,16 @@ static rdpsndPlugin* allocatePlugin(void)
 fail:
 	if (rdpsnd)
 		audio_format_free(rdpsnd->fixed_format);
+	free(rdpsnd);
 	return NULL;
 }
 /* rdpsnd is always built-in */
 FREERDP_ENTRY_POINT(BOOL VCAPITYPE rdpsnd_VirtualChannelEntryEx(PCHANNEL_ENTRY_POINTS pEntryPoints,
                                                                 PVOID pInitHandle))
 {
-	UINT rc;
-	rdpsndPlugin* rdpsnd;
-	CHANNEL_ENTRY_POINTS_FREERDP_EX* pEntryPointsEx;
+	UINT rc = 0;
+	rdpsndPlugin* rdpsnd = NULL;
+	CHANNEL_ENTRY_POINTS_FREERDP_EX* pEntryPointsEx = NULL;
 
 	if (!pEntryPoints)
 		return FALSE;
@@ -1566,13 +1578,17 @@ FREERDP_ENTRY_POINT(BOOL VCAPITYPE rdpsnd_VirtualChannelEntryEx(PCHANNEL_ENTRY_P
 		return FALSE;
 
 	rdpsnd->channelDef.options = CHANNEL_OPTION_INITIALIZED | CHANNEL_OPTION_ENCRYPT_RDP;
-	sprintf_s(rdpsnd->channelDef.name, ARRAYSIZE(rdpsnd->channelDef.name), RDPSND_CHANNEL_NAME);
+	(void)sprintf_s(rdpsnd->channelDef.name, ARRAYSIZE(rdpsnd->channelDef.name),
+	                RDPSND_CHANNEL_NAME);
 	pEntryPointsEx = (CHANNEL_ENTRY_POINTS_FREERDP_EX*)pEntryPoints;
 
 	if ((pEntryPointsEx->cbSize >= sizeof(CHANNEL_ENTRY_POINTS_FREERDP_EX)) &&
 	    (pEntryPointsEx->MagicNumber == FREERDP_CHANNEL_MAGIC_NUMBER))
 	{
 		rdpsnd->rdpcontext = pEntryPointsEx->context;
+		if (!freerdp_settings_get_bool(rdpsnd->rdpcontext->settings,
+		                               FreeRDP_SynchronousStaticChannels))
+			rdpsnd->async = TRUE;
 	}
 
 	CopyMemory(&(rdpsnd->channelEntryPoints), pEntryPoints,
@@ -1598,7 +1614,7 @@ FREERDP_ENTRY_POINT(BOOL VCAPITYPE rdpsnd_VirtualChannelEntryEx(PCHANNEL_ENTRY_P
 static UINT rdpsnd_on_open(IWTSVirtualChannelCallback* pChannelCallback)
 {
 	GENERIC_CHANNEL_CALLBACK* callback = (GENERIC_CHANNEL_CALLBACK*)pChannelCallback;
-	rdpsndPlugin* rdpsnd;
+	rdpsndPlugin* rdpsnd = NULL;
 
 	WINPR_ASSERT(callback);
 
@@ -1618,9 +1634,9 @@ static UINT rdpsnd_on_open(IWTSVirtualChannelCallback* pChannelCallback)
 static UINT rdpsnd_on_data_received(IWTSVirtualChannelCallback* pChannelCallback, wStream* data)
 {
 	GENERIC_CHANNEL_CALLBACK* callback = (GENERIC_CHANNEL_CALLBACK*)pChannelCallback;
-	rdpsndPlugin* plugin;
-	wStream* copy;
-	size_t len;
+	rdpsndPlugin* plugin = NULL;
+	wStream* copy = NULL;
+	size_t len = 0;
 
 	len = Stream_GetRemainingLength(data);
 
@@ -1636,10 +1652,19 @@ static UINT rdpsnd_on_data_received(IWTSVirtualChannelCallback* pChannelCallback
 	Stream_SealLength(copy);
 	Stream_SetPosition(copy, 0);
 
-	if (!MessageQueue_Post(plugin->queue, NULL, 0, copy, NULL))
+	if (plugin->async)
 	{
-		Stream_Release(copy);
-		return ERROR_INTERNAL_ERROR;
+		if (!MessageQueue_Post(plugin->queue, NULL, 0, copy, NULL))
+		{
+			Stream_Release(copy);
+			return ERROR_INTERNAL_ERROR;
+		}
+	}
+	else
+	{
+		UINT error = rdpsnd_recv_pdu(plugin, copy);
+		if (error)
+			return error;
 	}
 
 	return CHANNEL_RC_OK;
@@ -1648,7 +1673,7 @@ static UINT rdpsnd_on_data_received(IWTSVirtualChannelCallback* pChannelCallback
 static UINT rdpsnd_on_close(IWTSVirtualChannelCallback* pChannelCallback)
 {
 	GENERIC_CHANNEL_CALLBACK* callback = (GENERIC_CHANNEL_CALLBACK*)pChannelCallback;
-	rdpsndPlugin* rdpsnd;
+	rdpsndPlugin* rdpsnd = NULL;
 
 	WINPR_ASSERT(callback);
 
@@ -1677,7 +1702,7 @@ static UINT rdpsnd_on_new_channel_connection(IWTSListenerCallback* pListenerCall
                                              BOOL* pbAccept,
                                              IWTSVirtualChannelCallback** ppCallback)
 {
-	GENERIC_CHANNEL_CALLBACK* callback;
+	GENERIC_CHANNEL_CALLBACK* callback = NULL;
 	GENERIC_LISTENER_CALLBACK* listener_callback = (GENERIC_LISTENER_CALLBACK*)pListenerCallback;
 	WINPR_ASSERT(listener_callback);
 	WINPR_ASSERT(pChannel);
@@ -1706,7 +1731,7 @@ static UINT rdpsnd_on_new_channel_connection(IWTSListenerCallback* pListenerCall
 
 static UINT rdpsnd_plugin_initialize(IWTSPlugin* pPlugin, IWTSVirtualChannelManager* pChannelMgr)
 {
-	UINT status;
+	UINT status = 0;
 	rdpsndPlugin* rdpsnd = (rdpsndPlugin*)pPlugin;
 	WINPR_ASSERT(rdpsnd);
 	WINPR_ASSERT(pChannelMgr);
@@ -1773,7 +1798,7 @@ static UINT rdpsnd_plugin_terminated(IWTSPlugin* pPlugin)
 FREERDP_ENTRY_POINT(UINT rdpsnd_DVCPluginEntry(IDRDYNVC_ENTRY_POINTS* pEntryPoints))
 {
 	UINT error = CHANNEL_RC_OK;
-	rdpsndPlugin* rdpsnd;
+	rdpsndPlugin* rdpsnd = NULL;
 
 	WINPR_ASSERT(pEntryPoints);
 	WINPR_ASSERT(pEntryPoints->GetPlugin);
@@ -1782,7 +1807,7 @@ FREERDP_ENTRY_POINT(UINT rdpsnd_DVCPluginEntry(IDRDYNVC_ENTRY_POINTS* pEntryPoin
 
 	if (!rdpsnd)
 	{
-		IWTSPlugin* iface;
+		IWTSPlugin* iface = NULL;
 		union
 		{
 			const void* cev;
@@ -1807,6 +1832,10 @@ FREERDP_ENTRY_POINT(UINT rdpsnd_DVCPluginEntry(IDRDYNVC_ENTRY_POINTS* pEntryPoin
 		WINPR_ASSERT(pEntryPoints->GetRdpContext);
 		rdpsnd->rdpcontext = pEntryPoints->GetRdpContext(pEntryPoints);
 
+		if (!freerdp_settings_get_bool(rdpsnd->rdpcontext->settings,
+		                               FreeRDP_SynchronousDynamicChannels))
+			rdpsnd->async = TRUE;
+
 		/* user data pointer is not const, cast to avoid warning. */
 		cnv.cev = pEntryPoints->GetPluginData(pEntryPoints);
 		WINPR_ASSERT(pEntryPoints->GetPluginData);
