@@ -21,7 +21,6 @@
 
 #include <freerdp/config.h>
 
-#include <winpr/assert.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdint.h>
@@ -35,6 +34,7 @@
 #include <winpr/synch.h>
 #include <winpr/thread.h>
 #include <winpr/wlog.h>
+#include <winpr/assert.h>
 
 #include <freerdp/freerdp.h>
 #include <freerdp/channels/rdpdr.h>
@@ -43,11 +43,6 @@
 
 #define TAG CHANNELS_TAG("serial.client")
 
-/* TODO: all #ifdef __linux__ could be removed once only some generic
- * functions will be used. Replace CommReadFile by ReadFile,
- * CommWriteFile by WriteFile etc..  */
-#if defined __linux__ && !defined ANDROID
-
 #define MAX_IRP_THREADS 5
 
 typedef struct
@@ -63,7 +58,6 @@ typedef struct
 
 	/* one thread per pending IRP and indexed according their CompletionId */
 	wListDictionary* IrpThreads;
-	UINT32 IrpThreadToBeTerminatedCount;
 	CRITICAL_SECTION TerminatingIrpThreadsLock;
 	rdpContext* rdpcontext;
 } SERIAL_DEVICE;
@@ -74,7 +68,8 @@ typedef struct
 	IRP* irp;
 } IRP_THREAD_DATA;
 
-static UINT32 _GetLastErrorToIoStatus(SERIAL_DEVICE* serial)
+static void close_terminated_irp_thread_handles(SERIAL_DEVICE* serial, BOOL forceClose);
+static UINT32 GetLastErrorToIoStatus(SERIAL_DEVICE* serial)
 {
 	/* http://msdn.microsoft.com/en-us/library/ff547466%28v=vs.85%29.aspx#generic_status_values_for_serial_device_control_requests
 	 */
@@ -126,7 +121,10 @@ static UINT serial_process_irp_create(SERIAL_DEVICE* serial, IRP* irp)
 	DWORD CreateDisposition = 0;
 	UINT32 PathLength = 0;
 
-	if (!Stream_CheckAndLogRequiredLength(TAG, irp->input, 32))
+	WINPR_ASSERT(serial);
+	WINPR_ASSERT(irp);
+
+	if (!Stream_CheckAndLogRequiredLengthWLog(serial->log, irp->input, 32))
 		return ERROR_INVALID_DATA;
 
 	Stream_Read_UINT32(irp->input, DesiredAccess);     /* DesiredAccess (4 bytes) */
@@ -202,11 +200,16 @@ error_handle:
 
 static UINT serial_process_irp_close(SERIAL_DEVICE* serial, IRP* irp)
 {
-	if (!Stream_CheckAndLogRequiredLength(TAG, irp->input, 32))
+	WINPR_ASSERT(serial);
+	WINPR_ASSERT(irp);
+
+	if (!Stream_CheckAndLogRequiredLengthWLog(serial->log, irp->input, 32))
 		return ERROR_INVALID_DATA;
 
 	Stream_Seek(irp->input, 32); /* Padding (32 bytes) */
 
+	close_terminated_irp_thread_handles(serial, TRUE);
+
 	if (!CloseHandle(serial->hComm))
 	{
 		WLog_Print(serial->log, WLOG_WARN, "CloseHandle failure: %s (%" PRIu32 ") closed.",
@@ -217,9 +220,9 @@ static UINT serial_process_irp_close(SERIAL_DEVICE* serial, IRP* irp)
 
 	WLog_Print(serial->log, WLOG_DEBUG, "%s (DeviceId: %" PRIu32 ", FileId: %" PRIu32 ") closed.",
 	           serial->device.name, irp->device->id, irp->FileId);
-	serial->hComm = NULL;
 	irp->IoStatus = STATUS_SUCCESS;
 error_handle:
+	serial->hComm = NULL;
 	Stream_Zero(irp->output, 5); /* Padding (5 bytes) */
 	return CHANNEL_RC_OK;
 }
@@ -236,7 +239,10 @@ static UINT serial_process_irp_read(SERIAL_DEVICE* serial, IRP* irp)
 	BYTE* buffer = NULL;
 	DWORD nbRead = 0;
 
-	if (!Stream_CheckAndLogRequiredLength(TAG, irp->input, 32))
+	WINPR_ASSERT(serial);
+	WINPR_ASSERT(irp);
+
+	if (!Stream_CheckAndLogRequiredLengthWLog(serial->log, irp->input, 32))
 		return ERROR_INVALID_DATA;
 
 	Stream_Read_UINT32(irp->input, Length); /* Length (4 bytes) */
@@ -268,7 +274,7 @@ static UINT serial_process_irp_read(SERIAL_DEVICE* serial, IRP* irp)
 		WLog_Print(serial->log, WLOG_DEBUG,
 		           "read failure to %s, nbRead=%" PRIu32 ", last-error: 0x%08" PRIX32 "",
 		           serial->device.name, nbRead, GetLastError());
-		irp->IoStatus = _GetLastErrorToIoStatus(serial);
+		irp->IoStatus = GetLastErrorToIoStatus(serial);
 	}
 
 	WLog_Print(serial->log, WLOG_DEBUG, "%" PRIu32 " bytes read from %s", nbRead,
@@ -280,7 +286,7 @@ error_handle:
 	{
 		if (!Stream_EnsureRemainingCapacity(irp->output, nbRead))
 		{
-			WLog_ERR(TAG, "Stream_EnsureRemainingCapacity failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "Stream_EnsureRemainingCapacity failed!");
 			free(buffer);
 			return CHANNEL_RC_NO_MEMORY;
 		}
@@ -298,7 +304,10 @@ static UINT serial_process_irp_write(SERIAL_DEVICE* serial, IRP* irp)
 	UINT64 Offset = 0;
 	DWORD nbWritten = 0;
 
-	if (!Stream_CheckAndLogRequiredLength(TAG, irp->input, 32))
+	WINPR_ASSERT(serial);
+	WINPR_ASSERT(irp);
+
+	if (!Stream_CheckAndLogRequiredLengthWLog(serial->log, irp->input, 32))
 		return ERROR_INVALID_DATA;
 
 	Stream_Read_UINT32(irp->input, Length); /* Length (4 bytes) */
@@ -330,7 +339,7 @@ static UINT serial_process_irp_write(SERIAL_DEVICE* serial, IRP* irp)
 		WLog_Print(serial->log, WLOG_DEBUG,
 		           "write failure to %s, nbWritten=%" PRIu32 ", last-error: 0x%08" PRIX32 "",
 		           serial->device.name, nbWritten, GetLastError());
-		irp->IoStatus = _GetLastErrorToIoStatus(serial);
+		irp->IoStatus = GetLastErrorToIoStatus(serial);
 	}
 
 	WLog_Print(serial->log, WLOG_DEBUG, "%" PRIu32 " bytes written to %s", nbWritten,
@@ -354,7 +363,10 @@ static UINT serial_process_irp_device_control(SERIAL_DEVICE* serial, IRP* irp)
 	BYTE* OutputBuffer = NULL;
 	DWORD BytesReturned = 0;
 
-	if (!Stream_CheckAndLogRequiredLength(TAG, irp->input, 32))
+	WINPR_ASSERT(serial);
+	WINPR_ASSERT(irp);
+
+	if (!Stream_CheckAndLogRequiredLengthWLog(serial->log, irp->input, 32))
 		return ERROR_INVALID_DATA;
 
 	Stream_Read_UINT32(irp->input, OutputBufferLength); /* OutputBufferLength (4 bytes) */
@@ -362,7 +374,7 @@ static UINT serial_process_irp_device_control(SERIAL_DEVICE* serial, IRP* irp)
 	Stream_Read_UINT32(irp->input, IoControlCode);      /* IoControlCode (4 bytes) */
 	Stream_Seek(irp->input, 20);                        /* Padding (20 bytes) */
 
-	if (!Stream_CheckAndLogRequiredLength(TAG, irp->input, InputBufferLength))
+	if (!Stream_CheckAndLogRequiredLengthWLog(serial->log, irp->input, InputBufferLength))
 		return ERROR_INVALID_DATA;
 
 	OutputBuffer = (BYTE*)calloc(OutputBufferLength, sizeof(BYTE));
@@ -401,7 +413,7 @@ static UINT serial_process_irp_device_control(SERIAL_DEVICE* serial, IRP* irp)
 		           "CommDeviceIoControl failure: IoControlCode=[0x%" PRIX32
 		           "] %s, last-error: 0x%08" PRIX32 "",
 		           IoControlCode, _comm_serial_ioctl_name(IoControlCode), GetLastError());
-		irp->IoStatus = _GetLastErrorToIoStatus(serial);
+		irp->IoStatus = GetLastErrorToIoStatus(serial);
 	}
 
 error_handle:
@@ -415,7 +427,7 @@ error_handle:
 	{
 		if (!Stream_EnsureRemainingCapacity(irp->output, BytesReturned))
 		{
-			WLog_ERR(TAG, "Stream_EnsureRemainingCapacity failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "Stream_EnsureRemainingCapacity failed!");
 			free(InputBuffer);
 			free(OutputBuffer);
 			return CHANNEL_RC_NO_MEMORY;
@@ -445,7 +457,11 @@ error_handle:
 static UINT serial_process_irp(SERIAL_DEVICE* serial, IRP* irp)
 {
 	UINT error = CHANNEL_RC_OK;
-	WLog_Print(serial->log, WLOG_DEBUG, "IRP MajorFunction: s, MinorFunction: 0x%08" PRIX32 "\n",
+
+	WINPR_ASSERT(serial);
+	WINPR_ASSERT(irp);
+
+	WLog_Print(serial->log, WLOG_DEBUG, "IRP MajorFunction: %s, MinorFunction: 0x%08" PRIX32 "\n",
 	           rdpdr_irp_string(irp->MajorFunction), irp->MinorFunction);
 
 	switch (irp->MajorFunction)
@@ -459,9 +475,7 @@ static UINT serial_process_irp(SERIAL_DEVICE* serial, IRP* irp)
 			break;
 
 		case IRP_MJ_READ:
-			if ((error = serial_process_irp_read(serial, irp)))
-				WLog_ERR(TAG, "serial_process_irp_read failed with error %" PRIu32 "!", error);
-
+			error = serial_process_irp_read(serial, irp);
 			break;
 
 		case IRP_MJ_WRITE:
@@ -469,10 +483,7 @@ static UINT serial_process_irp(SERIAL_DEVICE* serial, IRP* irp)
 			break;
 
 		case IRP_MJ_DEVICE_CONTROL:
-			if ((error = serial_process_irp_device_control(serial, irp)))
-				WLog_ERR(TAG, "serial_process_irp_device_control failed with error %" PRIu32 "!",
-				         error);
-
+			error = serial_process_irp_device_control(serial, irp);
 			break;
 
 		default:
@@ -480,6 +491,16 @@ static UINT serial_process_irp(SERIAL_DEVICE* serial, IRP* irp)
 			break;
 	}
 
+	DWORD level = WLOG_TRACE;
+	if (error)
+		level = WLOG_WARN;
+
+	WLog_Print(serial->log, level,
+	           "[%s|0x%08" PRIx32 "] completed with %s [0x%08" PRIx32 "] (IoStatus %s [0x%08" PRIx32
+	           "])",
+	           rdpdr_irp_string(irp->MajorFunction), irp->MajorFunction, WTSErrorToString(error),
+	           error, NtStatus2Tag(irp->IoStatus), irp->IoStatus);
+
 	return error;
 }
 
@@ -488,15 +509,19 @@ static DWORD WINAPI irp_thread_func(LPVOID arg)
 	IRP_THREAD_DATA* data = (IRP_THREAD_DATA*)arg;
 	UINT error = 0;
 
+	WINPR_ASSERT(data);
+	WINPR_ASSERT(data->serial);
+	WINPR_ASSERT(data->irp);
+
 	/* blocks until the end of the request */
 	if ((error = serial_process_irp(data->serial, data->irp)))
 	{
-		WLog_ERR(TAG, "serial_process_irp failed with error %" PRIu32 "", error);
+		WLog_Print(data->serial->log, WLOG_ERROR,
+		           "serial_process_irp failed with error %" PRIu32 "", error);
 		goto error_out;
 	}
 
 	EnterCriticalSection(&data->serial->TerminatingIrpThreadsLock);
-	data->serial->IrpThreadToBeTerminatedCount++;
 	error = data->irp->Complete(data->irp);
 	LeaveCriticalSection(&data->serial->TerminatingIrpThreadsLock);
 error_out:
@@ -512,74 +537,71 @@ error_out:
 	return error;
 }
 
+static void close_unterminated_irp_thread(wListDictionary* list, wLog* log, ULONG_PTR id)
+{
+	WINPR_ASSERT(list);
+	HANDLE self = _GetCurrentThread();
+	HANDLE cirpThread = ListDictionary_GetItemValue(list, (void*)id);
+	if (self == cirpThread)
+		WLog_Print(log, WLOG_DEBUG, "Skipping termination of own IRP thread");
+	else
+		ListDictionary_Remove(list, (void*)id);
+}
+
+static void close_terminated_irp_thread(wListDictionary* list, wLog* log, ULONG_PTR id)
+{
+	WINPR_ASSERT(list);
+
+	HANDLE cirpThread = ListDictionary_GetItemValue(list, (void*)id);
+	/* FIXME: not quite sure a zero timeout is a good thing to check whether a thread is
+	 * stil alived or not */
+	const DWORD waitResult = WaitForSingleObject(cirpThread, 0);
+
+	if (waitResult == WAIT_OBJECT_0)
+		ListDictionary_Remove(list, (void*)id);
+	else if (waitResult != WAIT_TIMEOUT)
+	{
+		/* unexpected thread state */
+		WLog_Print(log, WLOG_WARN, "WaitForSingleObject, got an unexpected result=0x%" PRIX32 "\n",
+		           waitResult);
+	}
+}
+
+void close_terminated_irp_thread_handles(SERIAL_DEVICE* serial, BOOL forceClose)
+{
+	WINPR_ASSERT(serial);
+
+	EnterCriticalSection(&serial->TerminatingIrpThreadsLock);
+
+	ULONG_PTR* ids = NULL;
+	const size_t nbIds = ListDictionary_GetKeys(serial->IrpThreads, &ids);
+
+	for (size_t i = 0; i < nbIds; i++)
+	{
+		ULONG_PTR id = ids[i];
+		if (forceClose)
+			close_unterminated_irp_thread(serial->IrpThreads, serial->log, id);
+		else
+			close_terminated_irp_thread(serial->IrpThreads, serial->log, id);
+	}
+
+	free(ids);
+
+	LeaveCriticalSection(&serial->TerminatingIrpThreadsLock);
+}
+
 static void create_irp_thread(SERIAL_DEVICE* serial, IRP* irp)
 {
 	IRP_THREAD_DATA* data = NULL;
 	HANDLE irpThread = NULL;
 	HANDLE previousIrpThread = NULL;
 	uintptr_t key = 0;
-	/* for a test/debug purpose, uncomment the code below to get a
-	 * single thread for all IRPs. NB: two IRPs could not be
-	 * processed at the same time, typically two concurent
-	 * Read/Write operations could block each other. */
-	/* serial_process_irp(serial, irp); */
-	/* irp->Complete(irp); */
-	/* return; */
-	/* NOTE: for good or bad, this implementation relies on the
-	 * server to avoid a flooding of requests. see also _purge().
-	 */
-	EnterCriticalSection(&serial->TerminatingIrpThreadsLock);
 
-	while (serial->IrpThreadToBeTerminatedCount > 0)
-	{
-		/* Cleaning up termitating and pending irp
-		 * threads. See also: irp_thread_func() */
-		HANDLE cirpThread = NULL;
-		ULONG_PTR* ids = NULL;
-		const size_t nbIds = ListDictionary_GetKeys(serial->IrpThreads, &ids);
+	WINPR_ASSERT(serial);
+	WINPR_ASSERT(irp);
 
-		for (size_t i = 0; i < nbIds; i++)
-		{
-			/* Checking if ids[i] is terminating or pending */
-			DWORD waitResult = 0;
-			ULONG_PTR id = ids[i];
-			cirpThread = ListDictionary_GetItemValue(serial->IrpThreads, (void*)id);
-			/* FIXME: not quite sure a zero timeout is a good thing to check whether a thread is
-			 * stil alived or not */
-			waitResult = WaitForSingleObject(cirpThread, 0);
+	close_terminated_irp_thread_handles(serial, FALSE);
 
-			if (waitResult == WAIT_OBJECT_0)
-			{
-				/* terminating thread */
-				/* WLog_Print(serial->log, WLOG_DEBUG, "IRP thread with CompletionId=%"PRIuz"
-				 * naturally died", id); */
-				CloseHandle(cirpThread);
-				ListDictionary_Remove(serial->IrpThreads, (void*)id);
-				serial->IrpThreadToBeTerminatedCount--;
-			}
-			else if (waitResult != WAIT_TIMEOUT)
-			{
-				/* unexpected thread state */
-				WLog_Print(serial->log, WLOG_WARN,
-				           "WaitForSingleObject, got an unexpected result=0x%" PRIX32 "\n",
-				           waitResult);
-				WINPR_ASSERT(FALSE);
-			}
-
-			/* pending thread (but not yet terminating thread) if waitResult == WAIT_TIMEOUT */
-		}
-
-		if (serial->IrpThreadToBeTerminatedCount > 0)
-		{
-			WLog_Print(serial->log, WLOG_DEBUG, "%" PRIu32 " IRP thread(s) not yet terminated",
-			           serial->IrpThreadToBeTerminatedCount);
-			Sleep(1); /* 1 ms */
-		}
-
-		free(ids);
-	}
-
-	LeaveCriticalSection(&serial->TerminatingIrpThreadsLock);
 	/* NB: At this point and thanks to the synchronization we're
 	 * sure that the incoming IRP uses well a recycled
 	 * CompletionId or the server sent again an IRP already posted
@@ -642,7 +664,7 @@ static void create_irp_thread(SERIAL_DEVICE* serial, IRP* irp)
 	data->serial = serial;
 	data->irp = irp;
 	/* data freed by irp_thread_func */
-	irpThread = CreateThread(NULL, 0, irp_thread_func, (void*)data, 0, NULL);
+	irpThread = CreateThread(NULL, 0, irp_thread_func, (void*)data, CREATE_SUSPENDED, NULL);
 
 	if (irpThread == INVALID_HANDLE_VALUE)
 	{
@@ -654,45 +676,21 @@ static void create_irp_thread(SERIAL_DEVICE* serial, IRP* irp)
 
 	if (!ListDictionary_Add(serial->IrpThreads, (void*)key, irpThread))
 	{
-		WLog_ERR(TAG, "ListDictionary_Add failed!");
+		WLog_Print(serial->log, WLOG_ERROR, "ListDictionary_Add failed!");
 		goto error_handle;
 	}
 
+	ResumeThread(irpThread);
+
 	return;
 error_handle:
+	if (irpThread)
+		CloseHandle(irpThread);
 	irp->IoStatus = STATUS_NO_MEMORY;
 	irp->Complete(irp);
 	free(data);
 }
 
-static void terminate_pending_irp_threads(SERIAL_DEVICE* serial)
-{
-	WINPR_ASSERT(serial);
-
-	ULONG_PTR* ids = NULL;
-	const size_t nbIds = ListDictionary_GetKeys(serial->IrpThreads, &ids);
-	WLog_Print(serial->log, WLOG_DEBUG, "Terminating %" PRIuz " IRP thread(s)", nbIds);
-
-	for (size_t i = 0; i < nbIds; i++)
-	{
-		HANDLE irpThread = NULL;
-		ULONG_PTR id = ids[i];
-		irpThread = ListDictionary_GetItemValue(serial->IrpThreads, (void*)id);
-		TerminateThread(irpThread, 0);
-		if (WaitForSingleObject(irpThread, INFINITE) == WAIT_FAILED)
-		{
-			WLog_ERR(TAG, "WaitForSingleObject failed!");
-			continue;
-		}
-
-		CloseHandle(irpThread);
-		WLog_Print(serial->log, WLOG_DEBUG, "IRP thread terminated, CompletionId %p", (void*)id);
-	}
-
-	ListDictionary_Clear(serial->IrpThreads);
-	free(ids);
-}
-
 static DWORD WINAPI serial_thread_func(LPVOID arg)
 {
 	IRP* irp = NULL;
@@ -700,27 +698,26 @@ static DWORD WINAPI serial_thread_func(LPVOID arg)
 	SERIAL_DEVICE* serial = (SERIAL_DEVICE*)arg;
 	UINT error = CHANNEL_RC_OK;
 
+	WINPR_ASSERT(serial);
+
 	while (1)
 	{
 		if (!MessageQueue_Wait(serial->MainIrpQueue))
 		{
-			WLog_ERR(TAG, "MessageQueue_Wait failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "MessageQueue_Wait failed!");
 			error = ERROR_INTERNAL_ERROR;
 			break;
 		}
 
 		if (!MessageQueue_Peek(serial->MainIrpQueue, &message, TRUE))
 		{
-			WLog_ERR(TAG, "MessageQueue_Peek failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "MessageQueue_Peek failed!");
 			error = ERROR_INTERNAL_ERROR;
 			break;
 		}
 
 		if (message.id == WMQ_QUIT)
-		{
-			terminate_pending_irp_threads(serial);
 			break;
-		}
 
 		irp = (IRP*)message.wParam;
 
@@ -728,6 +725,7 @@ static DWORD WINAPI serial_thread_func(LPVOID arg)
 			create_irp_thread(serial, irp);
 	}
 
+	ListDictionary_Clear(serial->IrpThreads);
 	if (error && serial->rdpcontext)
 		setChannelError(serial->rdpcontext, error, "serial_thread_func reported an error");
 
@@ -744,6 +742,7 @@ static UINT serial_irp_request(DEVICE* device, IRP* irp)
 {
 	SERIAL_DEVICE* serial = (SERIAL_DEVICE*)device;
 	WINPR_ASSERT(irp != NULL);
+	WINPR_ASSERT(serial);
 
 	if (irp == NULL)
 		return CHANNEL_RC_OK;
@@ -755,7 +754,7 @@ static UINT serial_irp_request(DEVICE* device, IRP* irp)
 
 	if (!MessageQueue_Post(serial->MainIrpQueue, NULL, 0, (void*)irp, NULL))
 	{
-		WLog_ERR(TAG, "MessageQueue_Post failed!");
+		WLog_Print(serial->log, WLOG_ERROR, "MessageQueue_Post failed!");
 		return ERROR_INTERNAL_ERROR;
 	}
 
@@ -771,18 +770,24 @@ static UINT serial_free(DEVICE* device)
 {
 	UINT error = 0;
 	SERIAL_DEVICE* serial = (SERIAL_DEVICE*)device;
+	if (!serial)
+		return CHANNEL_RC_OK;
+
 	WLog_Print(serial->log, WLOG_DEBUG, "freeing");
-	MessageQueue_PostQuit(serial->MainIrpQueue, 0);
+	if (serial->MainIrpQueue)
+		MessageQueue_PostQuit(serial->MainIrpQueue, 0);
 
-	if (WaitForSingleObject(serial->MainThread, INFINITE) == WAIT_FAILED)
+	if (serial->MainThread)
 	{
-		error = GetLastError();
-		WLog_ERR(TAG, "WaitForSingleObject failed with error %" PRIu32 "!", error);
-		return error;
+		if (WaitForSingleObject(serial->MainThread, INFINITE) == WAIT_FAILED)
+		{
+			error = GetLastError();
+			WLog_Print(serial->log, WLOG_ERROR,
+			           "WaitForSingleObject failed with error %" PRIu32 "!", error);
+		}
+		CloseHandle(serial->MainThread);
 	}
 
-	CloseHandle(serial->MainThread);
-
 	if (serial->hComm)
 		CloseHandle(serial->hComm);
 
@@ -795,8 +800,6 @@ static UINT serial_free(DEVICE* device)
 	return CHANNEL_RC_OK;
 }
 
-#endif /* __linux__ */
-
 static void serial_message_free(void* obj)
 {
 	wMessage* msg = obj;
@@ -812,6 +815,23 @@ static void serial_message_free(void* obj)
 	irp->Discard(irp);
 }
 
+static void irp_thread_close(void* arg)
+{
+	HANDLE hdl = arg;
+	if (hdl)
+	{
+		HANDLE thz = _GetCurrentThread();
+		if (thz == hdl)
+			WLog_WARN(TAG, "closing self, ignoring...");
+		else
+		{
+			TerminateThread(hdl, 0);
+			WaitForSingleObject(hdl, INFINITE);
+			CloseHandle(hdl);
+		}
+	}
+}
+
 /**
  * Function description
  *
@@ -819,46 +839,36 @@ static void serial_message_free(void* obj)
  */
 FREERDP_ENTRY_POINT(UINT serial_DeviceServiceEntry(PDEVICE_SERVICE_ENTRY_POINTS pEntryPoints))
 {
-	char* name = NULL;
-	char* path = NULL;
-	char* driver = NULL;
-	RDPDR_SERIAL* device = NULL;
-#if defined __linux__ && !defined ANDROID
 	size_t len = 0;
 	SERIAL_DEVICE* serial = NULL;
-#endif /* __linux__ */
 	UINT error = CHANNEL_RC_OK;
 
 	WINPR_ASSERT(pEntryPoints);
 
-	device = (RDPDR_SERIAL*)pEntryPoints->device;
+	RDPDR_SERIAL* device = (RDPDR_SERIAL*)pEntryPoints->device;
 	WINPR_ASSERT(device);
 
-	name = device->device.Name;
-	path = device->Path;
-	driver = device->Driver;
+	wLog* log = WLog_Get(TAG);
+	const char* name = device->device.Name;
+	const char* path = device->Path;
+	const char* driver = device->Driver;
 
 	if (!name || (name[0] == '*'))
 	{
 		/* TODO: implement auto detection of serial ports */
+		WLog_Print(log, WLOG_WARN,
+		           "Serial port autodetection not implemented, nothing will be redirected!");
 		return CHANNEL_RC_OK;
 	}
 
 	if ((name && name[0]) && (path && path[0]))
 	{
-		wLog* log = NULL;
-		log = WLog_Get("com.freerdp.channel.serial.client");
-		WLog_Print(log, WLOG_DEBUG, "initializing");
-#ifndef __linux__ /* to be removed */
-		WLog_Print(log, WLOG_WARN, "Serial ports redirection not supported on this platform.");
-		return CHANNEL_RC_INITIALIZATION_ERROR;
-#else /* __linux __ */
 		WLog_Print(log, WLOG_DEBUG, "Defining %s as %s", name, path);
 
 		if (!DefineCommDevice(name /* eg: COM1 */, path /* eg: /dev/ttyS0 */))
 		{
 			DWORD status = GetLastError();
-			WLog_ERR(TAG, "DefineCommDevice failed with %08" PRIx32, status);
+			WLog_Print(log, WLOG_ERROR, "DefineCommDevice failed with %08" PRIx32, status);
 			return ERROR_INTERNAL_ERROR;
 		}
 
@@ -866,7 +876,7 @@ FREERDP_ENTRY_POINT(UINT serial_DeviceServiceEntry(PDEVICE_SERVICE_ENTRY_POINTS
 
 		if (!serial)
 		{
-			WLog_ERR(TAG, "calloc failed!");
+			WLog_Print(log, WLOG_ERROR, "calloc failed!");
 			return CHANNEL_RC_NO_MEMORY;
 		}
 
@@ -881,7 +891,7 @@ FREERDP_ENTRY_POINT(UINT serial_DeviceServiceEntry(PDEVICE_SERVICE_ENTRY_POINTS
 
 		if (!serial->device.data)
 		{
-			WLog_ERR(TAG, "calloc failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "calloc failed!");
 			error = CHANNEL_RC_NO_MEMORY;
 			goto error_out;
 		}
@@ -899,10 +909,10 @@ FREERDP_ENTRY_POINT(UINT serial_DeviceServiceEntry(PDEVICE_SERVICE_ENTRY_POINTS
 				serial->ServerSerialDriverId = SerialDriverSerCx2Sys;
 			else
 			{
-				WINPR_ASSERT(FALSE);
-				WLog_Print(serial->log, WLOG_DEBUG,
-				           "Unknown server's serial driver: %s. SerCx2 will be used", driver);
-				serial->ServerSerialDriverId = SerialDriverSerialSys;
+				WLog_Print(serial->log, WLOG_WARN, "Unknown server's serial driver: %s.", driver);
+				WLog_Print(serial->log, WLOG_WARN,
+				           "Valid options are: 'Serial' (default), 'SerCx' and 'SerCx2'");
+				goto error_out;
 			}
 		}
 		else
@@ -919,64 +929,67 @@ FREERDP_ENTRY_POINT(UINT serial_DeviceServiceEntry(PDEVICE_SERVICE_ENTRY_POINTS
 			}
 			else
 			{
-				WLog_Print(serial->log, WLOG_DEBUG, "Unknown flag: %s", device->Permissive);
-				WINPR_ASSERT(FALSE);
+				WLog_Print(serial->log, WLOG_WARN, "Unknown flag: %s", device->Permissive);
+				goto error_out;
 			}
 		}
 
 		WLog_Print(serial->log, WLOG_DEBUG, "Server's serial driver: %s (id: %d)", driver,
 		           serial->ServerSerialDriverId);
-		/* TODO: implement auto detection of the server's serial driver */
+
 		serial->MainIrpQueue = MessageQueue_New(NULL);
 
 		if (!serial->MainIrpQueue)
 		{
-			WLog_ERR(TAG, "MessageQueue_New failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "MessageQueue_New failed!");
 			error = CHANNEL_RC_NO_MEMORY;
 			goto error_out;
 		}
 
-		wObject* obj = MessageQueue_Object(serial->MainIrpQueue);
-		WINPR_ASSERT(obj);
-		obj->fnObjectFree = serial_message_free;
+		{
+			wObject* obj = MessageQueue_Object(serial->MainIrpQueue);
+			WINPR_ASSERT(obj);
+			obj->fnObjectFree = serial_message_free;
+		}
 
 		/* IrpThreads content only modified by create_irp_thread() */
 		serial->IrpThreads = ListDictionary_New(FALSE);
 
 		if (!serial->IrpThreads)
 		{
-			WLog_ERR(TAG, "ListDictionary_New failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "ListDictionary_New failed!");
 			error = CHANNEL_RC_NO_MEMORY;
 			goto error_out;
 		}
 
-		serial->IrpThreadToBeTerminatedCount = 0;
+		{
+			wObject* obj = ListDictionary_ValueObject(serial->IrpThreads);
+			WINPR_ASSERT(obj);
+			obj->fnObjectFree = irp_thread_close;
+		}
+
 		InitializeCriticalSection(&serial->TerminatingIrpThreadsLock);
 
-		if ((error = pEntryPoints->RegisterDevice(pEntryPoints->devman, (DEVICE*)serial)))
+		error = pEntryPoints->RegisterDevice(pEntryPoints->devman, &serial->device);
+		if (error != CHANNEL_RC_OK)
 		{
-			WLog_ERR(TAG, "EntryPoints->RegisterDevice failed with error %" PRIu32 "!", error);
+			WLog_Print(serial->log, WLOG_ERROR,
+			           "EntryPoints->RegisterDevice failed with error %" PRIu32 "!", error);
 			goto error_out;
 		}
 
-		if (!(serial->MainThread =
-		          CreateThread(NULL, 0, serial_thread_func, (void*)serial, 0, NULL)))
+		serial->MainThread = CreateThread(NULL, 0, serial_thread_func, serial, 0, NULL);
+		if (!serial->MainThread)
 		{
-			WLog_ERR(TAG, "CreateThread failed!");
+			WLog_Print(serial->log, WLOG_ERROR, "CreateThread failed!");
 			error = ERROR_INTERNAL_ERROR;
 			goto error_out;
 		}
-
-#endif /* __linux __ */
 	}
 
 	return error;
 error_out:
-#ifdef __linux__ /* to be removed */
-	ListDictionary_Free(serial->IrpThreads);
-	MessageQueue_Free(serial->MainIrpQueue);
-	Stream_Free(serial->device.data, TRUE);
-	free(serial);
-#endif /* __linux __ */
+	if (serial)
+		serial_free(&serial->device);
 	return error;
 }
