@@ -52,7 +52,7 @@
 #define AUDIO_TOLERANCE 10000000LL
 
 /* 1 second = 10,000,000 100ns units*/
-#define VIDEO_ADJUST_MAX 10 * 1000 * 1000
+#define VIDEO_ADJUST_MAX (10ULL * 1000ULL * 1000ULL)
 
 #define MAX_ACK_TIME 666667
 
@@ -154,8 +154,8 @@ struct S_TSMF_SAMPLE
 static wArrayList* presentation_list = NULL;
 static int TERMINATING = 0;
 
-static void _tsmf_presentation_free(void* obj);
-static void _tsmf_stream_free(void* obj);
+static void s_tsmf_presentation_free(void* obj);
+static void s_tsmf_stream_free(void* obj);
 
 static UINT64 get_current_time(void)
 {
@@ -166,10 +166,9 @@ static UINT64 get_current_time(void)
 
 static TSMF_SAMPLE* tsmf_stream_pop_sample(TSMF_STREAM* stream, int sync)
 {
-	UINT32 index;
-	UINT32 count;
-	TSMF_STREAM* s;
-	TSMF_SAMPLE* sample;
+	UINT32 count = 0;
+	TSMF_STREAM* s = NULL;
+	TSMF_SAMPLE* sample = NULL;
 	BOOL pending = FALSE;
 	TSMF_PRESENTATION* presentation = NULL;
 
@@ -199,7 +198,7 @@ static TSMF_SAMPLE* tsmf_stream_pop_sample(TSMF_STREAM* stream, int sync)
 						ArrayList_Lock(presentation->stream_list);
 						count = ArrayList_Count(presentation->stream_list);
 
-						for (index = 0; index < count; index++)
+						for (UINT32 index = 0; index < count; index++)
 						{
 							s = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 
@@ -288,8 +287,8 @@ static BOOL tsmf_sample_queue_ack(TSMF_SAMPLE* sample)
 static BOOL tsmf_stream_process_ack(void* arg, BOOL force)
 {
 	TSMF_STREAM* stream = arg;
-	TSMF_SAMPLE* sample;
-	UINT64 ack_time;
+	TSMF_SAMPLE* sample = NULL;
+	UINT64 ack_time = 0;
 	BOOL rc = FALSE;
 
 	if (!stream)
@@ -341,8 +340,8 @@ finally:
 TSMF_PRESENTATION* tsmf_presentation_new(const BYTE* guid,
                                          IWTSVirtualChannelCallback* pChannelCallback)
 {
-	wObject* obj;
-	TSMF_PRESENTATION* presentation;
+	wObject* obj = NULL;
+	TSMF_PRESENTATION* presentation = NULL;
 
 	if (!guid || !pChannelCallback)
 		return NULL;
@@ -366,7 +365,7 @@ TSMF_PRESENTATION* tsmf_presentation_new(const BYTE* guid,
 	obj = ArrayList_Object(presentation->stream_list);
 	if (!obj)
 		goto error_add;
-	obj->fnObjectFree = _tsmf_stream_free;
+	obj->fnObjectFree = s_tsmf_stream_free;
 
 	if (!ArrayList_Append(presentation_list, presentation))
 		goto error_add;
@@ -381,28 +380,25 @@ error_stream_list:
 
 static char* guid_to_string(const BYTE* guid, char* str, size_t len)
 {
-	size_t i;
-
 	if (!guid || !str)
 		return NULL;
 
-	for (i = 0; i < GUID_SIZE && (len > 2 * i); i++)
-		sprintf_s(str + (2 * i), len - 2 * i, "%02" PRIX8 "", guid[i]);
+	for (size_t i = 0; i < GUID_SIZE && (len > 2 * i); i++)
+		(void)sprintf_s(str + (2 * i), len - 2 * i, "%02" PRIX8 "", guid[i]);
 
 	return str;
 }
 
 TSMF_PRESENTATION* tsmf_presentation_find_by_id(const BYTE* guid)
 {
-	UINT32 index;
-	UINT32 count;
+	UINT32 count = 0;
 	BOOL found = FALSE;
 	char guid_str[GUID_SIZE * 2 + 1] = { 0 };
 	TSMF_PRESENTATION* presentation = NULL;
 	ArrayList_Lock(presentation_list);
 	count = ArrayList_Count(presentation_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		presentation = (TSMF_PRESENTATION*)ArrayList_GetItem(presentation_list, index);
 
@@ -424,7 +420,7 @@ TSMF_PRESENTATION* tsmf_presentation_find_by_id(const BYTE* guid)
 
 static BOOL tsmf_sample_playback_video(TSMF_SAMPLE* sample)
 {
-	UINT64 t;
+	UINT64 t = 0;
 	TSMF_VIDEO_FRAME_EVENT event;
 	TSMF_STREAM* stream = sample->stream;
 	TSMF_PRESENTATION* presentation = stream->presentation;
@@ -521,7 +517,7 @@ static BOOL tsmf_sample_playback_audio(TSMF_SAMPLE* sample)
 {
 	UINT64 latency = 0;
 	TSMF_STREAM* stream = sample->stream;
-	BOOL ret;
+	BOOL ret = 0;
 	DEBUG_TSMF("MessageId %" PRIu32 " EndTime %" PRIu64 " consumed.", sample->sample_id,
 	           sample->end_time);
 
@@ -559,8 +555,8 @@ static BOOL tsmf_sample_playback_audio(TSMF_SAMPLE* sample)
 static BOOL tsmf_sample_playback(TSMF_SAMPLE* sample)
 {
 	BOOL ret = FALSE;
-	UINT32 width;
-	UINT32 height;
+	UINT32 width = 0;
+	UINT32 height = 0;
 	UINT32 pixfmt = 0;
 	TSMF_STREAM* stream = sample->stream;
 
@@ -579,19 +575,17 @@ static BOOL tsmf_sample_playback(TSMF_SAMPLE* sample)
 				TSMF_PRESENTATION* presentation = stream->presentation;
 				ArrayList_Lock(presentation->stream_list);
 				int count = ArrayList_Count(presentation->stream_list);
-				int index = 0;
 
-				for (index = 0; index < count; index++)
+				for (size_t index = 0; index < count; index++)
 				{
-					UINT64 time_diff;
+					UINT64 time_diff = 0;
 					temp_stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 
 					if (temp_stream->major_type == TSMF_MAJOR_TYPE_AUDIO)
 					{
-						UINT64 video_time =
-						    (UINT64)stream->decoder->GetRunningTime(stream->decoder);
+						UINT64 video_time = stream->decoder->GetRunningTime(stream->decoder);
 						UINT64 audio_time =
-						    (UINT64)temp_stream->decoder->GetRunningTime(temp_stream->decoder);
+						    temp_stream->decoder->GetRunningTime(temp_stream->decoder);
 						UINT64 max_adjust = VIDEO_ADJUST_MAX;
 
 						if (video_time < audio_time)
@@ -817,7 +811,7 @@ static DWORD WINAPI tsmf_stream_playback_func(LPVOID arg)
 	TSMF_STREAM* stream = (TSMF_STREAM*)arg;
 	TSMF_PRESENTATION* presentation = stream->presentation;
 	UINT error = CHANNEL_RC_OK;
-	DWORD status;
+	DWORD status = 0;
 	DEBUG_TSMF("in %" PRIu32 "", stream->stream_id);
 
 	if (stream->major_type == TSMF_MAJOR_TYPE_AUDIO && stream->sample_rate && stream->channels &&
@@ -971,16 +965,14 @@ static BOOL tsmf_stream_change_volume(TSMF_STREAM* stream, UINT32 newVolume, UIN
 BOOL tsmf_presentation_volume_changed(TSMF_PRESENTATION* presentation, UINT32 newVolume,
                                       UINT32 muted)
 {
-	UINT32 index;
-	UINT32 count;
-	TSMF_STREAM* stream;
+	TSMF_STREAM* stream = NULL;
 	BOOL ret = TRUE;
 	presentation->volume = newVolume;
 	presentation->muted = muted;
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 		ret &= tsmf_stream_change_volume(stream, newVolume, muted);
@@ -992,14 +984,12 @@ BOOL tsmf_presentation_volume_changed(TSMF_PRESENTATION* presentation, UINT32 ne
 
 BOOL tsmf_presentation_paused(TSMF_PRESENTATION* presentation)
 {
-	UINT32 index;
-	UINT32 count;
-	TSMF_STREAM* stream;
+	TSMF_STREAM* stream = NULL;
 	BOOL ret = TRUE;
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 		ret &= tsmf_stream_pause(stream);
@@ -1011,14 +1001,12 @@ BOOL tsmf_presentation_paused(TSMF_PRESENTATION* presentation)
 
 BOOL tsmf_presentation_restarted(TSMF_PRESENTATION* presentation)
 {
-	UINT32 index;
-	UINT32 count;
-	TSMF_STREAM* stream;
+	TSMF_STREAM* stream = NULL;
 	BOOL ret = TRUE;
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 		ret &= tsmf_stream_restart(stream);
@@ -1030,14 +1018,12 @@ BOOL tsmf_presentation_restarted(TSMF_PRESENTATION* presentation)
 
 BOOL tsmf_presentation_start(TSMF_PRESENTATION* presentation)
 {
-	UINT32 index;
-	UINT32 count;
-	TSMF_STREAM* stream;
+	TSMF_STREAM* stream = NULL;
 	BOOL ret = TRUE;
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 		ret &= tsmf_stream_start(stream);
@@ -1054,13 +1040,11 @@ BOOL tsmf_presentation_start(TSMF_PRESENTATION* presentation)
  */
 UINT tsmf_presentation_sync(TSMF_PRESENTATION* presentation)
 {
-	UINT32 index;
-	UINT32 count;
-	UINT error;
+	UINT error = 0;
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		TSMF_STREAM* stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 
@@ -1078,14 +1062,12 @@ UINT tsmf_presentation_sync(TSMF_PRESENTATION* presentation)
 
 BOOL tsmf_presentation_stop(TSMF_PRESENTATION* presentation)
 {
-	UINT32 index;
-	UINT32 count;
-	TSMF_STREAM* stream;
+	TSMF_STREAM* stream = NULL;
 	BOOL ret = TRUE;
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 		ret &= tsmf_stream_stop(stream);
@@ -1101,9 +1083,7 @@ BOOL tsmf_presentation_set_geometry_info(TSMF_PRESENTATION* presentation, UINT32
                                          UINT32 width, UINT32 height, int num_rects,
                                          RDP_RECT* rects)
 {
-	UINT32 index;
-	UINT32 count;
-	TSMF_STREAM* stream;
+	TSMF_STREAM* stream = NULL;
 	void* tmp_rects = NULL;
 	BOOL ret = TRUE;
 
@@ -1131,9 +1111,9 @@ BOOL tsmf_presentation_set_geometry_info(TSMF_PRESENTATION* presentation, UINT32
 	if (presentation->rects)
 		CopyMemory(presentation->rects, rects, sizeof(RDP_RECT) * num_rects);
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 
@@ -1180,10 +1160,10 @@ BOOL tsmf_stream_flush(TSMF_STREAM* stream)
 		stream->presentation->audio_end_time = 0;
 	}
 
-	return TRUE;
+	return ret;
 }
 
-void _tsmf_presentation_free(void* obj)
+void s_tsmf_presentation_free(void* obj)
 {
 	TSMF_PRESENTATION* presentation = (TSMF_PRESENTATION*)obj;
 
@@ -1206,8 +1186,8 @@ void tsmf_presentation_free(TSMF_PRESENTATION* presentation)
 TSMF_STREAM* tsmf_stream_new(TSMF_PRESENTATION* presentation, UINT32 stream_id,
                              rdpContext* rdpcontext)
 {
-	wObject* obj;
-	TSMF_STREAM* stream;
+	wObject* obj = NULL;
+	TSMF_STREAM* stream = NULL;
 	stream = tsmf_stream_find_by_id(presentation, stream_id);
 
 	if (stream)
@@ -1313,14 +1293,12 @@ void tsmf_stream_start_threads(TSMF_STREAM* stream)
 
 TSMF_STREAM* tsmf_stream_find_by_id(TSMF_PRESENTATION* presentation, UINT32 stream_id)
 {
-	UINT32 index;
-	UINT32 count;
 	BOOL found = FALSE;
 	TSMF_STREAM* stream = NULL;
 	ArrayList_Lock(presentation->stream_list);
-	count = ArrayList_Count(presentation->stream_list);
+	size_t count = ArrayList_Count(presentation->stream_list);
 
-	for (index = 0; index < count; index++)
+	for (size_t index = 0; index < count; index++)
 	{
 		stream = (TSMF_STREAM*)ArrayList_GetItem(presentation->stream_list, index);
 
@@ -1416,7 +1394,7 @@ void tsmf_stream_end(TSMF_STREAM* stream, UINT32 message_id,
 	stream->eos_channel_callback = pChannelCallback;
 }
 
-void _tsmf_stream_free(void* obj)
+void s_tsmf_stream_free(void* obj)
 {
 	TSMF_STREAM* stream = (TSMF_STREAM*)obj;
 
@@ -1475,7 +1453,7 @@ BOOL tsmf_stream_push_sample(TSMF_STREAM* stream, IWTSVirtualChannelCallback* pC
                              UINT32 sample_id, UINT64 start_time, UINT64 end_time, UINT64 duration,
                              UINT32 extensions, UINT32 data_size, BYTE* data)
 {
-	TSMF_SAMPLE* sample;
+	TSMF_SAMPLE* sample = NULL;
 	SetEvent(stream->ready);
 
 	if (TERMINATING)
@@ -1506,14 +1484,19 @@ BOOL tsmf_stream_push_sample(TSMF_STREAM* stream, IWTSVirtualChannelCallback* pC
 	sample->data = calloc(1, data_size + TSMF_BUFFER_PADDING_SIZE);
 
 	if (!sample->data)
-	{
-		WLog_ERR(TAG, "calloc sample->data failed!");
-		free(sample);
-		return FALSE;
-	}
+		goto fail;
 
 	CopyMemory(sample->data, data, data_size);
-	return Queue_Enqueue(stream->sample_list, sample);
+	if (!Queue_Enqueue(stream->sample_list, sample))
+		goto fail;
+
+	return TRUE;
+
+fail:
+	if (sample)
+		free(sample->data);
+	free(sample);
+	return FALSE;
 }
 
 #ifndef _WIN32
@@ -1525,12 +1508,12 @@ static void tsmf_signal_handler(int s)
 
 	if (s == SIGINT)
 	{
-		signal(s, SIG_DFL);
+		(void)signal(s, SIG_DFL);
 		kill(getpid(), s);
 	}
 	else if (s == SIGUSR1)
 	{
-		signal(s, SIG_DFL);
+		(void)signal(s, SIG_DFL);
 	}
 }
 
@@ -1538,7 +1521,7 @@ static void tsmf_signal_handler(int s)
 
 BOOL tsmf_media_init(void)
 {
-	wObject* obj;
+	wObject* obj = NULL;
 #ifndef _WIN32
 	struct sigaction sigtrap;
 	sigtrap.sa_handler = tsmf_signal_handler;
@@ -1558,7 +1541,7 @@ BOOL tsmf_media_init(void)
 		obj = ArrayList_Object(presentation_list);
 		if (!obj)
 			return FALSE;
-		obj->fnObjectFree = _tsmf_presentation_free;
+		obj->fnObjectFree = s_tsmf_presentation_free;
 	}
 
 	return TRUE;
