@@ -54,7 +54,7 @@
 
 #define BASIC_STATE_FUNC_REGISTER(_arg, _man)    \
 	_man->iface.get_##_arg = udevman_get_##_arg; \
-	_man->iface.set_##_arg = udevman_set_##_arg
+	(_man)->iface.set_##_arg = udevman_set_##_arg
 
 typedef struct
 {
@@ -106,7 +106,7 @@ static BOOL udevman_has_next(IUDEVMAN* idevman)
 static IUDEVICE* udevman_get_next(IUDEVMAN* idevman)
 {
 	UDEVMAN* udevman = (UDEVMAN*)idevman;
-	IUDEVICE* pdev;
+	IUDEVICE* pdev = NULL;
 	pdev = udevman->idev;
 	udevman->idev = (IUDEVICE*)((UDEVICE*)udevman->idev)->next;
 	return pdev;
@@ -143,22 +143,23 @@ static size_t udevman_register_udevice(IUDEVMAN* idevman, BYTE bus_number, BYTE
 {
 	UDEVMAN* udevman = (UDEVMAN*)idevman;
 	IUDEVICE* pdev = NULL;
-	IUDEVICE** devArray;
-	URBDRC_PLUGIN* urbdrc;
-	size_t i, num, addnum = 0;
+	IUDEVICE** devArray = NULL;
+	URBDRC_PLUGIN* urbdrc = NULL;
+	size_t num = 0;
+	size_t addnum = 0;
 
 	if (!idevman || !idevman->plugin)
 		return 0;
 
 	urbdrc = (URBDRC_PLUGIN*)idevman->plugin;
-	pdev = (IUDEVICE*)udevman_get_udevice_by_addr(idevman, bus_number, dev_number);
+	pdev = udevman_get_udevice_by_addr(idevman, bus_number, dev_number);
 
 	if (pdev != NULL)
 		return 0;
 
 	if (flag & UDEVMAN_FLAG_ADD_BY_ADDR)
 	{
-		UINT32 id;
+		UINT32 id = 0;
 		IUDEVICE* tdev = udev_new_by_addr(urbdrc, udevman->context, bus_number, dev_number);
 
 		if (tdev == NULL)
@@ -198,9 +199,9 @@ static size_t udevman_register_udevice(IUDEVMAN* idevman, BYTE bus_number, BYTE
 			           idProduct);
 		}
 
-		for (i = 0; i < num; i++)
+		for (size_t i = 0; i < num; i++)
 		{
-			UINT32 id;
+			UINT32 id = 0;
 			IUDEVICE* tdev = devArray[i];
 
 			if (udevman_get_udevice_by_addr(idevman, tdev->get_bus_number(tdev),
@@ -250,7 +251,7 @@ static size_t udevman_register_udevice(IUDEVMAN* idevman, BYTE bus_number, BYTE
 static BOOL udevman_unregister_udevice(IUDEVMAN* idevman, BYTE bus_number, BYTE dev_number)
 {
 	UDEVMAN* udevman = (UDEVMAN*)idevman;
-	UDEVICE* pdev;
+	UDEVICE* pdev = NULL;
 	UDEVICE* dev = (UDEVICE*)udevman_get_udevice_by_addr(idevman, bus_number, dev_number);
 
 	if (!dev || !idevman)
@@ -373,8 +374,8 @@ static int udevman_is_auto_add(IUDEVMAN* idevman)
 
 static IUDEVICE* udevman_get_udevice_by_UsbDevice(IUDEVMAN* idevman, UINT32 UsbDevice)
 {
-	UDEVICE* pdev;
-	URBDRC_PLUGIN* urbdrc;
+	UDEVICE* pdev = NULL;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!idevman || !idevman->plugin)
 		return NULL;
@@ -404,8 +405,8 @@ static IUDEVICE* udevman_get_udevice_by_UsbDevice(IUDEVMAN* idevman, UINT32 UsbD
 
 static IUDEVICE* udevman_get_udevice_by_ChannelID(IUDEVMAN* idevman, UINT32 channelID)
 {
-	UDEVICE* pdev;
-	URBDRC_PLUGIN* urbdrc;
+	UDEVICE* pdev = NULL;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!idevman || !idevman->plugin)
 		return NULL;
@@ -516,7 +517,7 @@ static BOOL device_is_filtered(struct libusb_device* dev,
                                libusb_hotplug_event event)
 {
 	char buffer[8192] = { 0 };
-	char* what;
+	char* what = NULL;
 	BOOL filtered = FALSE;
 	append(buffer, sizeof(buffer), usb_interface_class_to_string(desc->bDeviceClass));
 	if (filter_by_class(desc->bDeviceClass, desc->bDeviceSubClass))
@@ -530,13 +531,10 @@ static BOOL device_is_filtered(struct libusb_device* dev,
 			int rc = libusb_get_active_config_descriptor(dev, &config);
 			if (rc == LIBUSB_SUCCESS)
 			{
-				uint8_t x;
-
-				for (x = 0; x < config->bNumInterfaces; x++)
+				for (uint8_t x = 0; x < config->bNumInterfaces; x++)
 				{
-					int y;
 					const struct libusb_interface* ifc = &config->interface[x];
-					for (y = 0; y < ifc->num_altsetting; y++)
+					for (int y = 0; y < ifc->num_altsetting; y++)
 					{
 						const struct libusb_interface_descriptor* const alt = &ifc->altsetting[y];
 						if (filter_by_class(alt->bInterfaceClass, alt->bInterfaceSubClass))
@@ -642,9 +640,9 @@ static BOOL udevman_vid_pid_pair_equals(const void* objA, const void* objB)
 static BOOL udevman_parse_device_id_addr(const char** str, UINT16* id1, UINT16* id2, UINT16 max,
                                          char split_sign, char delimiter)
 {
-	char* mid;
-	char* end;
-	unsigned long rc;
+	char* mid = NULL;
+	char* end = NULL;
+	unsigned long rc = 0;
 
 	rc = strtoul(*str, &mid, 16);
 
@@ -674,8 +672,9 @@ static BOOL udevman_parse_device_id_addr(const char** str, UINT16* id1, UINT16*
 static BOOL urbdrc_udevman_register_devices(UDEVMAN* udevman, const char* devices, BOOL add_by_addr)
 {
 	const char* pos = devices;
-	VID_PID_PAIR* idpair;
-	UINT16 id1, id2;
+	VID_PID_PAIR* idpair = NULL;
+	UINT16 id1 = 0;
+	UINT16 id2 = 0;
 
 	while (*pos != '\0')
 	{
@@ -709,15 +708,15 @@ static BOOL urbdrc_udevman_register_devices(UDEVMAN* udevman, const char* device
 		}
 	}
 
+	// NOLINTNEXTLINE(clang-analyzer-unix.Malloc): ArrayList_Append owns idpair
 	return CHANNEL_RC_OK;
 }
 
 static UINT urbdrc_udevman_parse_addin_args(UDEVMAN* udevman, const ADDIN_ARGV* args)
 {
-	int x;
 	LPCSTR devices = NULL;
 
-	for (x = 0; x < args->argc; x++)
+	for (int x = 0; x < args->argc; x++)
 	{
 		const char* arg = args->argv[x];
 		if (strcmp(arg, "dbg") == 0)
@@ -788,7 +787,7 @@ static UINT urbdrc_udevman_parse_addin_args(UDEVMAN* udevman, const ADDIN_ARGV*
 
 static UINT udevman_listener_created_callback(IUDEVMAN* iudevman)
 {
-	UINT status;
+	UINT status = 0;
 	UDEVMAN* udevman = (UDEVMAN*)iudevman;
 
 	if (udevman->devices_vid_pid)
@@ -898,10 +897,10 @@ static DWORD WINAPI poll_thread(LPVOID lpThreadParameter)
 FREERDP_ENTRY_POINT(UINT libusb_freerdp_urbdrc_client_subsystem_entry(
     PFREERDP_URBDRC_SERVICE_ENTRY_POINTS pEntryPoints))
 {
-	wObject* obj;
-	UINT rc;
-	UINT status;
-	UDEVMAN* udevman;
+	wObject* obj = NULL;
+	UINT rc = 0;
+	UINT status = 0;
+	UDEVMAN* udevman = NULL;
 	const ADDIN_ARGV* args = pEntryPoints->args;
 	udevman = (PUDEVMAN)calloc(1, sizeof(UDEVMAN));
 
