@@ -45,8 +45,8 @@
 
 static IWTSVirtualChannel* get_channel(IUDEVMAN* idevman)
 {
-	IWTSVirtualChannelManager* channel_mgr;
-	URBDRC_PLUGIN* urbdrc;
+	IWTSVirtualChannelManager* channel_mgr = NULL;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!idevman)
 		return NULL;
@@ -66,9 +66,11 @@ static IWTSVirtualChannel* get_channel(IUDEVMAN* idevman)
 
 static int func_container_id_generate(IUDEVICE* pdev, char* strContainerId)
 {
-	char *p, *path;
+	char* p = NULL;
+	char* path = NULL;
 	UINT8 containerId[17] = { 0 };
-	UINT16 idVendor, idProduct;
+	UINT16 idVendor = 0;
+	UINT16 idProduct = 0;
 	idVendor = (UINT16)pdev->query_device_descriptor(pdev, ID_VENDOR);
 	idProduct = (UINT16)pdev->query_device_descriptor(pdev, ID_PRODUCT);
 	path = pdev->getPath(pdev);
@@ -78,33 +80,33 @@ static int func_container_id_generate(IUDEVICE* pdev, char* strContainerId)
 	else
 		p = path;
 
-	sprintf_s((char*)containerId, sizeof(containerId), "%04" PRIX16 "%04" PRIX16 "%s", idVendor,
-	          idProduct, p);
+	(void)sprintf_s((char*)containerId, sizeof(containerId), "%04" PRIX16 "%04" PRIX16 "%s",
+	                idVendor, idProduct, p);
 	/* format */
-	sprintf_s(strContainerId, DEVICE_CONTAINER_STR_SIZE,
-	          "{%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8
-	          "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8
-	          "%02" PRIx8 "%02" PRIx8 "}",
-	          containerId[0], containerId[1], containerId[2], containerId[3], containerId[4],
-	          containerId[5], containerId[6], containerId[7], containerId[8], containerId[9],
-	          containerId[10], containerId[11], containerId[12], containerId[13], containerId[14],
-	          containerId[15]);
+	(void)sprintf_s(strContainerId, DEVICE_CONTAINER_STR_SIZE,
+	                "{%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8
+	                "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8
+	                "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "}",
+	                containerId[0], containerId[1], containerId[2], containerId[3], containerId[4],
+	                containerId[5], containerId[6], containerId[7], containerId[8], containerId[9],
+	                containerId[10], containerId[11], containerId[12], containerId[13],
+	                containerId[14], containerId[15]);
 	return 0;
 }
 
 static int func_instance_id_generate(IUDEVICE* pdev, char* strInstanceId, size_t len)
 {
 	char instanceId[17] = { 0 };
-	sprintf_s(instanceId, sizeof(instanceId), "\\%s", pdev->getPath(pdev));
+	(void)sprintf_s(instanceId, sizeof(instanceId), "\\%s", pdev->getPath(pdev));
 	/* format */
-	sprintf_s(strInstanceId, len,
-	          "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8
-	          "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8
-	          "%02" PRIx8 "%02" PRIx8 "",
-	          instanceId[0], instanceId[1], instanceId[2], instanceId[3], instanceId[4],
-	          instanceId[5], instanceId[6], instanceId[7], instanceId[8], instanceId[9],
-	          instanceId[10], instanceId[11], instanceId[12], instanceId[13], instanceId[14],
-	          instanceId[15]);
+	(void)sprintf_s(strInstanceId, len,
+	                "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8
+	                "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8 "-%02" PRIx8 "%02" PRIx8
+	                "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "%02" PRIx8 "",
+	                instanceId[0], instanceId[1], instanceId[2], instanceId[3], instanceId[4],
+	                instanceId[5], instanceId[6], instanceId[7], instanceId[8], instanceId[9],
+	                instanceId[10], instanceId[11], instanceId[12], instanceId[13], instanceId[14],
+	                instanceId[15]);
 	return 0;
 }
 
@@ -116,10 +118,10 @@ static int func_instance_id_generate(IUDEVICE* pdev, char* strInstanceId, size_t
 static UINT urbdrc_process_capability_request(GENERIC_CHANNEL_CALLBACK* callback, wStream* s,
                                               UINT32 MessageId)
 {
-	UINT32 InterfaceId;
-	UINT32 Version;
-	UINT32 out_size;
-	wStream* out;
+	UINT32 InterfaceId = 0;
+	UINT32 Version = 0;
+	UINT32 out_size = 0;
+	wStream* out = NULL;
 
 	if (!callback || !s)
 		return ERROR_INVALID_PARAMETER;
@@ -154,13 +156,13 @@ static UINT urbdrc_process_capability_request(GENERIC_CHANNEL_CALLBACK* callback
 static UINT urbdrc_process_channel_create(GENERIC_CHANNEL_CALLBACK* callback, wStream* s,
                                           UINT32 MessageId)
 {
-	UINT32 InterfaceId;
-	UINT32 out_size;
-	UINT32 MajorVersion;
-	UINT32 MinorVersion;
-	UINT32 Capabilities;
-	wStream* out;
-	URBDRC_PLUGIN* urbdrc;
+	UINT32 InterfaceId = 0;
+	UINT32 out_size = 0;
+	UINT32 MajorVersion = 0;
+	UINT32 MinorVersion = 0;
+	UINT32 Capabilities = 0;
+	wStream* out = NULL;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!callback || !s || !callback->plugin)
 		return ERROR_INVALID_PARAMETER;
@@ -222,20 +224,21 @@ static UINT urdbrc_send_virtual_channel_add(IWTSPlugin* plugin, IWTSVirtualChann
  */
 static UINT urdbrc_send_usb_device_add(GENERIC_CHANNEL_CALLBACK* callback, IUDEVICE* pdev)
 {
-	wStream* out;
-	UINT32 InterfaceId;
+	wStream* out = NULL;
+	UINT32 InterfaceId = 0;
 	char HardwareIds[2][DEVICE_HARDWARE_ID_SIZE] = { { 0 } };
 	char CompatibilityIds[3][DEVICE_COMPATIBILITY_ID_SIZE] = { { 0 } };
 	char strContainerId[DEVICE_CONTAINER_STR_SIZE] = { 0 };
 	char strInstanceId[DEVICE_INSTANCE_STR_SIZE] = { 0 };
 	const char* composite_str = "USB\\COMPOSITE";
 	const size_t composite_len = 13;
-	size_t size;
+	size_t size = 0;
 	size_t CompatibilityIdLen[3];
 	size_t HardwareIdsLen[2];
-	size_t ContainerIdLen, InstanceIdLen;
-	size_t cchCompatIds;
-	UINT32 bcdUSB;
+	size_t ContainerIdLen = 0;
+	size_t InstanceIdLen = 0;
+	size_t cchCompatIds = 0;
+	UINT32 bcdUSB = 0;
 	InterfaceId = ((STREAM_ID_PROXY << 30) | CLIENT_DEVICE_SINK);
 	/* USB kernel driver detach!! */
 	pdev->detach_kernel_driver(pdev);
@@ -243,11 +246,11 @@ static UINT urdbrc_send_usb_device_add(GENERIC_CHANNEL_CALLBACK* callback, IUDEV
 		const UINT16 idVendor = (UINT16)pdev->query_device_descriptor(pdev, ID_VENDOR);
 		const UINT16 idProduct = (UINT16)pdev->query_device_descriptor(pdev, ID_PRODUCT);
 		const UINT16 bcdDevice = (UINT16)pdev->query_device_descriptor(pdev, BCD_DEVICE);
-		sprintf_s(HardwareIds[1], DEVICE_HARDWARE_ID_SIZE,
-		          "USB\\VID_%04" PRIX16 "&PID_%04" PRIX16 "", idVendor, idProduct);
-		sprintf_s(HardwareIds[0], DEVICE_HARDWARE_ID_SIZE,
-		          "USB\\VID_%04" PRIX16 "&PID_%04" PRIX16 "&REV_%04" PRIX16 "", idVendor, idProduct,
-		          bcdDevice);
+		(void)sprintf_s(HardwareIds[1], DEVICE_HARDWARE_ID_SIZE,
+		                "USB\\VID_%04" PRIX16 "&PID_%04" PRIX16 "", idVendor, idProduct);
+		(void)sprintf_s(HardwareIds[0], DEVICE_HARDWARE_ID_SIZE,
+		                "USB\\VID_%04" PRIX16 "&PID_%04" PRIX16 "&REV_%04" PRIX16 "", idVendor,
+		                idProduct, bcdDevice);
 	}
 	{
 		const UINT8 bDeviceClass = (UINT8)pdev->query_device_descriptor(pdev, B_DEVICE_CLASS);
@@ -256,22 +259,22 @@ static UINT urdbrc_send_usb_device_add(GENERIC_CHANNEL_CALLBACK* callback, IUDEV
 
 		if (!(pdev->isCompositeDevice(pdev)))
 		{
-			sprintf_s(CompatibilityIds[2], DEVICE_COMPATIBILITY_ID_SIZE, "USB\\Class_%02" PRIX8 "",
-			          bDeviceClass);
-			sprintf_s(CompatibilityIds[1], DEVICE_COMPATIBILITY_ID_SIZE,
-			          "USB\\Class_%02" PRIX8 "&SubClass_%02" PRIX8 "", bDeviceClass,
-			          bDeviceSubClass);
-			sprintf_s(CompatibilityIds[0], DEVICE_COMPATIBILITY_ID_SIZE,
-			          "USB\\Class_%02" PRIX8 "&SubClass_%02" PRIX8 "&Prot_%02" PRIX8 "",
-			          bDeviceClass, bDeviceSubClass, bDeviceProtocol);
+			(void)sprintf_s(CompatibilityIds[2], DEVICE_COMPATIBILITY_ID_SIZE,
+			                "USB\\Class_%02" PRIX8 "", bDeviceClass);
+			(void)sprintf_s(CompatibilityIds[1], DEVICE_COMPATIBILITY_ID_SIZE,
+			                "USB\\Class_%02" PRIX8 "&SubClass_%02" PRIX8 "", bDeviceClass,
+			                bDeviceSubClass);
+			(void)sprintf_s(CompatibilityIds[0], DEVICE_COMPATIBILITY_ID_SIZE,
+			                "USB\\Class_%02" PRIX8 "&SubClass_%02" PRIX8 "&Prot_%02" PRIX8 "",
+			                bDeviceClass, bDeviceSubClass, bDeviceProtocol);
 		}
 		else
 		{
-			sprintf_s(CompatibilityIds[2], DEVICE_COMPATIBILITY_ID_SIZE, "USB\\DevClass_00");
-			sprintf_s(CompatibilityIds[1], DEVICE_COMPATIBILITY_ID_SIZE,
-			          "USB\\DevClass_00&SubClass_00");
-			sprintf_s(CompatibilityIds[0], DEVICE_COMPATIBILITY_ID_SIZE,
-			          "USB\\DevClass_00&SubClass_00&Prot_00");
+			(void)sprintf_s(CompatibilityIds[2], DEVICE_COMPATIBILITY_ID_SIZE, "USB\\DevClass_00");
+			(void)sprintf_s(CompatibilityIds[1], DEVICE_COMPATIBILITY_ID_SIZE,
+			                "USB\\DevClass_00&SubClass_00");
+			(void)sprintf_s(CompatibilityIds[0], DEVICE_COMPATIBILITY_ID_SIZE,
+			                "USB\\DevClass_00&SubClass_00&Prot_00");
 		}
 	}
 	func_instance_id_generate(pdev, strInstanceId, DEVICE_INSTANCE_STR_SIZE);
@@ -378,9 +381,9 @@ fail:
  */
 static UINT urbdrc_exchange_capabilities(GENERIC_CHANNEL_CALLBACK* callback, wStream* data)
 {
-	UINT32 MessageId;
-	UINT32 FunctionId;
-	UINT32 InterfaceId;
+	UINT32 MessageId = 0;
+	UINT32 FunctionId = 0;
+	UINT32 InterfaceId = 0;
 	UINT error = CHANNEL_RC_OK;
 
 	if (!data)
@@ -507,11 +510,11 @@ fail:
  */
 static UINT urbdrc_process_channel_notification(GENERIC_CHANNEL_CALLBACK* callback, wStream* data)
 {
-	UINT32 MessageId;
-	UINT32 FunctionId;
-	UINT32 InterfaceId;
+	UINT32 MessageId = 0;
+	UINT32 FunctionId = 0;
+	UINT32 InterfaceId = 0;
 	UINT error = CHANNEL_RC_OK;
-	URBDRC_PLUGIN* urbdrc;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!callback || !data)
 		return ERROR_INVALID_PARAMETER;
@@ -558,9 +561,9 @@ static UINT urbdrc_process_channel_notification(GENERIC_CHANNEL_CALLBACK* callba
 static UINT urbdrc_on_data_received(IWTSVirtualChannelCallback* pChannelCallback, wStream* data)
 {
 	GENERIC_CHANNEL_CALLBACK* callback = (GENERIC_CHANNEL_CALLBACK*)pChannelCallback;
-	URBDRC_PLUGIN* urbdrc;
-	IUDEVMAN* udevman;
-	UINT32 InterfaceId;
+	URBDRC_PLUGIN* urbdrc = NULL;
+	IUDEVMAN* udevman = NULL;
+	UINT32 InterfaceId = 0;
 	UINT error = ERROR_INTERNAL_ERROR;
 
 	if (callback == NULL)
@@ -574,7 +577,7 @@ static UINT urbdrc_on_data_received(IWTSVirtualChannelCallback* pChannelCallback
 	if (urbdrc->udevman == NULL)
 		return error;
 
-	udevman = (IUDEVMAN*)urbdrc->udevman;
+	udevman = urbdrc->udevman;
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, data, 12))
 		return ERROR_INVALID_DATA;
@@ -646,7 +649,7 @@ static UINT urbdrc_on_new_channel_connection(IWTSListenerCallback* pListenerCall
                                              IWTSVirtualChannelCallback** ppCallback)
 {
 	GENERIC_LISTENER_CALLBACK* listener_callback = (GENERIC_LISTENER_CALLBACK*)pListenerCallback;
-	GENERIC_CHANNEL_CALLBACK* callback;
+	GENERIC_CHANNEL_CALLBACK* callback = NULL;
 
 	if (!ppCallback)
 		return ERROR_INVALID_PARAMETER;
@@ -672,9 +675,9 @@ static UINT urbdrc_on_new_channel_connection(IWTSListenerCallback* pListenerCall
  */
 static UINT urbdrc_plugin_initialize(IWTSPlugin* pPlugin, IWTSVirtualChannelManager* pChannelMgr)
 {
-	UINT status;
+	UINT status = 0;
 	URBDRC_PLUGIN* urbdrc = (URBDRC_PLUGIN*)pPlugin;
-	IUDEVMAN* udevman;
+	IUDEVMAN* udevman = NULL;
 	char channelName[sizeof(URBDRC_CHANNEL_NAME)] = { URBDRC_CHANNEL_NAME };
 
 	if (!urbdrc || !urbdrc->udevman)
@@ -719,7 +722,7 @@ static UINT urbdrc_plugin_initialize(IWTSPlugin* pPlugin, IWTSVirtualChannelMana
 static UINT urbdrc_plugin_terminated(IWTSPlugin* pPlugin)
 {
 	URBDRC_PLUGIN* urbdrc = (URBDRC_PLUGIN*)pPlugin;
-	IUDEVMAN* udevman;
+	IUDEVMAN* udevman = NULL;
 
 	if (!urbdrc)
 		return ERROR_INVALID_DATA;
@@ -766,7 +769,7 @@ static BOOL urbdrc_register_udevman_addin(IWTSPlugin* pPlugin, IUDEVMAN* udevman
 static UINT urbdrc_load_udevman_addin(IWTSPlugin* pPlugin, LPCSTR name, const ADDIN_ARGV* args)
 {
 	URBDRC_PLUGIN* urbdrc = (URBDRC_PLUGIN*)pPlugin;
-	PFREERDP_URBDRC_DEVICE_ENTRY entry;
+	PFREERDP_URBDRC_DEVICE_ENTRY entry = NULL;
 	FREERDP_URBDRC_SERVICE_ENTRY_POINTS entryPoints;
 	entry = (PFREERDP_URBDRC_DEVICE_ENTRY)freerdp_load_channel_addin_entry(URBDRC_CHANNEL_NAME,
 	                                                                       name, NULL, 0);
@@ -801,7 +804,7 @@ static BOOL urbdrc_set_subsystem(URBDRC_PLUGIN* urbdrc, const char* subsystem)
  */
 static UINT urbdrc_process_addin_args(URBDRC_PLUGIN* urbdrc, const ADDIN_ARGV* args)
 {
-	int status;
+	int status = 0;
 	COMMAND_LINE_ARGUMENT_A urbdrc_args[] = {
 		{ "dbg", COMMAND_LINE_VALUE_FLAG, "", NULL, BoolValueFalse, -1, NULL, "debug" },
 		{ "sys", COMMAND_LINE_VALUE_REQUIRED, "<subsystem>", NULL, NULL, -1, NULL, "subsystem" },
@@ -814,7 +817,7 @@ static UINT urbdrc_process_addin_args(URBDRC_PLUGIN* urbdrc, const ADDIN_ARGV* a
 
 	const DWORD flags =
 	    COMMAND_LINE_SIGIL_NONE | COMMAND_LINE_SEPARATOR_COLON | COMMAND_LINE_IGN_UNKNOWN_KEYWORD;
-	const COMMAND_LINE_ARGUMENT_A* arg;
+	const COMMAND_LINE_ARGUMENT_A* arg = NULL;
 	status =
 	    CommandLineParseArgumentsA(args->argc, args->argv, urbdrc_args, flags, urbdrc, NULL, NULL);
 
@@ -850,8 +853,9 @@ BOOL add_device(IUDEVMAN* idevman, UINT32 flags, BYTE busnum, BYTE devnum, UINT1
                 UINT16 idProduct)
 {
 	size_t success = 0;
-	URBDRC_PLUGIN* urbdrc;
-	UINT32 mask, regflags = 0;
+	URBDRC_PLUGIN* urbdrc = NULL;
+	UINT32 mask = 0;
+	UINT32 regflags = 0;
 
 	if (!idevman)
 		return FALSE;
@@ -883,7 +887,7 @@ BOOL del_device(IUDEVMAN* idevman, UINT32 flags, BYTE busnum, BYTE devnum, UINT1
                 UINT16 idProduct)
 {
 	IUDEVICE* pdev = NULL;
-	URBDRC_PLUGIN* urbdrc;
+	URBDRC_PLUGIN* urbdrc = NULL;
 
 	if (!idevman)
 		return FALSE;
@@ -949,8 +953,8 @@ BOOL del_device(IUDEVMAN* idevman, UINT32 flags, BYTE busnum, BYTE devnum, UINT1
 FREERDP_ENTRY_POINT(UINT urbdrc_DVCPluginEntry(IDRDYNVC_ENTRY_POINTS* pEntryPoints))
 {
 	UINT status = 0;
-	const ADDIN_ARGV* args;
-	URBDRC_PLUGIN* urbdrc;
+	const ADDIN_ARGV* args = NULL;
+	URBDRC_PLUGIN* urbdrc = NULL;
 	urbdrc = (URBDRC_PLUGIN*)pEntryPoints->GetPlugin(pEntryPoints, URBDRC_CHANNEL_NAME);
 	args = pEntryPoints->GetPluginData(pEntryPoints);
 
@@ -994,7 +998,7 @@ fail:
 
 UINT stream_write_and_free(IWTSPlugin* plugin, IWTSVirtualChannel* channel, wStream* out)
 {
-	UINT rc;
+	UINT rc = 0;
 	URBDRC_PLUGIN* urbdrc = (URBDRC_PLUGIN*)plugin;
 
 	if (!out)
