@@ -54,7 +54,7 @@ int mac_cliprdr_send_client_format_list(CliprdrClientContext *cliprdr)
 			formats[index].formatName = _strdup(formatName);
 	}
 
-	formatList.common.msgFlags = CB_RESPONSE_OK;
+	formatList.common.msgFlags = 0;
 	formatList.numFormats = numFormats;
 	formatList.formats = formats;
 	formatList.common.msgType = CB_FORMAT_LIST;
