@@ -211,9 +211,9 @@ static const struct sdl_exit_code_map_t sdl_exit_code_map[] = {
 
 static const struct sdl_exit_code_map_t* sdl_map_entry_by_code(int exit_code)
 {
-	for (size_t x = 0; x < ARRAYSIZE(sdl_exit_code_map); x++)
+	for (const auto& x : sdl_exit_code_map)
 	{
-		const struct sdl_exit_code_map_t* cur = &sdl_exit_code_map[x];
+		const struct sdl_exit_code_map_t* cur = &x;
 		if (cur->code == exit_code)
 			return cur;
 	}
@@ -230,9 +230,9 @@ static void sdl_hide_connection_dialog(SdlContext* sdl)
 
 static const struct sdl_exit_code_map_t* sdl_map_entry_by_error(DWORD error)
 {
-	for (size_t x = 0; x < ARRAYSIZE(sdl_exit_code_map); x++)
+	for (const auto& x : sdl_exit_code_map)
 	{
-		const struct sdl_exit_code_map_t* cur = &sdl_exit_code_map[x];
+		const struct sdl_exit_code_map_t* cur = &x;
 		if (cur->error == error)
 			return cur;
 	}
@@ -335,7 +335,7 @@ class SdlEventUpdateTriggerGuard
 };
 
 static bool sdl_draw_to_window_rect(SdlContext* sdl, SdlWindow& window, SDL_Surface* surface,
-                                    SDL_Point offset, const SDL_Rect& srcRect)
+                                    SDL_Point offset, SDL_Rect srcRect)
 {
 	SDL_Rect dstRect = { offset.x + srcRect.x, offset.y + srcRect.y, srcRect.w, srcRect.h };
 	return window.blit(surface, srcRect, dstRect);
@@ -358,7 +358,7 @@ static bool sdl_draw_to_window_rect(SdlContext* sdl, SdlWindow& window, SDL_Surf
 }
 
 static bool sdl_draw_to_window_scaled_rect(SdlContext* sdl, SdlWindow& window, SDL_Surface* surface,
-                                           const SDL_Rect& srcRect)
+                                           SDL_Rect srcRect)
 {
 	SDL_Rect dstRect = srcRect;
 	sdl_scale_coordinates(sdl, window.id(), &dstRect.x, &dstRect.y, FALSE, TRUE);
@@ -573,6 +573,9 @@ static BOOL sdl_pre_connect(freerdp* instance)
 	auto settings = instance->context->settings;
 	WINPR_ASSERT(settings);
 
+	if (!freerdp_settings_set_bool(settings, FreeRDP_CertificateCallbackPreferPEM, TRUE))
+		return FALSE;
+
 	/* Optional OS identifier sent to server */
 	if (!freerdp_settings_set_uint32(settings, FreeRDP_OsMajorType, OSMAJORTYPE_UNIX))
 		return FALSE;
@@ -660,9 +663,9 @@ static const char* sdl_window_get_title(rdpSettings* settings)
 	char buffer[MAX_PATH + 64] = { 0 };
 
 	if (!addPort)
-		sprintf_s(buffer, sizeof(buffer), "%s %s", prefix, name);
+		(void)sprintf_s(buffer, sizeof(buffer), "%s %s", prefix, name);
 	else
-		sprintf_s(buffer, sizeof(buffer), "%s %s:%" PRIu32, prefix, name, port);
+		(void)sprintf_s(buffer, sizeof(buffer), "%s %s:%" PRIu32, prefix, name, port);
 
 	if (!freerdp_settings_set_string(settings, FreeRDP_WindowTitle, buffer))
 		return nullptr;
@@ -702,6 +705,9 @@ static BOOL sdl_create_windows(SdlContext* sdl)
 
 	for (UINT32 x = 0; x < windowCount; x++)
 	{
+		auto id = sdl_monitor_id_for_index(sdl, x);
+		if (id < 0)
+			return FALSE;
 		auto monitor = static_cast<rdpMonitor*>(
 		    freerdp_settings_get_pointer_array_writable(settings, FreeRDP_MonitorDefArray, x));
 
@@ -715,8 +721,8 @@ static BOOL sdl_create_windows(SdlContext* sdl)
 		}
 
 		Uint32 flags = SDL_WINDOW_SHOWN;
-		Uint32 startupX = SDL_WINDOWPOS_CENTERED_DISPLAY(x);
-		Uint32 startupY = SDL_WINDOWPOS_CENTERED_DISPLAY(x);
+		Uint32 startupX = SDL_WINDOWPOS_CENTERED_DISPLAY(id);
+		Uint32 startupY = SDL_WINDOWPOS_CENTERED_DISPLAY(id);
 
 		if (monitor->attributes.desktopScaleFactor > 100)
 		{
@@ -1341,7 +1347,7 @@ terminate:
 /* Optional global initializer.
  * Here we just register a signal handler to print out stack traces
  * if available. */
-static BOOL sdl_client_global_init(void)
+static BOOL sdl_client_global_init()
 {
 #if defined(_WIN32)
 	WSADATA wsaData = { 0 };
@@ -1361,7 +1367,7 @@ static BOOL sdl_client_global_init(void)
 }
 
 /* Optional global tear down */
-static void sdl_client_global_uninit(void)
+static void sdl_client_global_uninit()
 {
 #if defined(_WIN32)
 	WSACleanup();
