@@ -28,7 +28,7 @@
 class SdlSelectWidget : public SdlWidget
 {
   public:
-	SdlSelectWidget(SDL_Renderer* renderer, const std::string& label, const SDL_FRect& rect);
+	SdlSelectWidget(SDL_Renderer* renderer, std::string label, const SDL_FRect& rect);
 	SdlSelectWidget(SdlSelectWidget&& other) noexcept;
 	~SdlSelectWidget() override = default;
 
@@ -39,7 +39,6 @@ class SdlSelectWidget : public SdlWidget
   private:
 	SdlSelectWidget(const SdlSelectWidget& other) = delete;
 
-  private:
 	std::string _text;
 	bool _mouseover;
 	bool _highlight;
