@@ -106,8 +106,6 @@ void xf_rail_send_activate(xfContext* xfc, Window xwindow, BOOL enabled)
 
 	if (enabled)
 		xf_SetWindowStyle(xfc, appWindow, appWindow->dwStyle, appWindow->dwExStyle);
-	else
-		xf_SetWindowStyle(xfc, appWindow, 0, 0);
 
 	activate.windowId = appWindow->windowId;
 	activate.enabled = enabled;
@@ -155,13 +153,14 @@ void xf_rail_adjust_position(xfContext* xfc, xfAppWindow* appWindow)
 
 void xf_rail_end_local_move(xfContext* xfc, xfAppWindow* appWindow)
 {
-	int x, y;
-	int child_x;
-	int child_y;
-	unsigned int mask;
-	Window root_window;
-	Window child_window;
-	rdpInput* input;
+	int x = 0;
+	int y = 0;
+	int child_x = 0;
+	int child_y = 0;
+	unsigned int mask = 0;
+	Window root_window = 0;
+	Window child_window = 0;
+	rdpInput* input = NULL;
 
 	WINPR_ASSERT(xfc);
 
@@ -549,6 +548,13 @@ static BOOL xf_rail_window_common(rdpContext* context, const WINDOW_ORDER_INFO*
 			                            visibilityRectsOffsetY, appWindow->visibilityRects,
 			                            appWindow->numVisibilityRects);
 		}
+
+		if (appWindow->rail_state == WINDOW_SHOW_MAXIMIZED)
+		{
+			xf_SendClientEvent(xfc, appWindow->handle, xfc->_NET_WM_STATE, 4, _NET_WM_STATE_ADD,
+			                   xfc->_NET_WM_STATE_MAXIMIZED_VERT, xfc->_NET_WM_STATE_MAXIMIZED_HORZ,
+			                   0, 0);
+		}
 	}
 
 	/* We should only be using the visibility rects for shaping the window */
@@ -567,7 +573,7 @@ static BOOL xf_rail_window_delete(rdpContext* context, const WINDOW_ORDER_INFO*
 
 static xfRailIconCache* RailIconCache_New(rdpSettings* settings)
 {
-	xfRailIconCache* cache;
+	xfRailIconCache* cache = NULL;
 	cache = calloc(1, sizeof(xfRailIconCache));
 
 	if (!cache)
@@ -591,11 +597,9 @@ static xfRailIconCache* RailIconCache_New(rdpSettings* settings)
 
 static void RailIconCache_Free(xfRailIconCache* cache)
 {
-	UINT32 i;
-
 	if (cache)
 	{
-		for (i = 0; i < cache->numCaches * cache->numCacheEntries; i++)
+		for (UINT32 i = 0; i < cache->numCaches * cache->numCacheEntries; i++)
 		{
 			free(cache->entries[i].data);
 		}
@@ -642,10 +646,9 @@ static xfRailIcon* RailIconCache_Lookup(xfRailIconCache* cache, UINT8 cacheId, U
 static BOOL convert_rail_icon(const ICON_INFO* iconInfo, xfRailIcon* railIcon)
 {
 	BYTE* argbPixels = NULL;
-	BYTE* nextPixel;
-	long* pixels;
-	int i;
-	int nelements;
+	BYTE* nextPixel = NULL;
+	long* pixels = NULL;
+	int nelements = 0;
 	argbPixels = calloc(1ull * iconInfo->width * iconInfo->height, 4);
 
 	if (!argbPixels)
@@ -669,7 +672,7 @@ static BOOL convert_rail_icon(const ICON_INFO* iconInfo, xfRailIcon* railIcon)
 	pixels[1] = iconInfo->height;
 	nextPixel = argbPixels;
 
-	for (i = 2; i < nelements; i++)
+	for (int i = 2; i < nelements; i++)
 	{
 		pixels[i] = FreeRDPReadColor(nextPixel, PIXEL_FORMAT_BGRA32);
 		nextPixel += 4;
@@ -697,9 +700,9 @@ static BOOL xf_rail_window_icon(rdpContext* context, const WINDOW_ORDER_INFO* or
                                 const WINDOW_ICON_ORDER* windowIcon)
 {
 	xfContext* xfc = (xfContext*)context;
-	xfAppWindow* railWindow;
-	xfRailIcon* icon;
-	BOOL replaceIcon;
+	xfAppWindow* railWindow = NULL;
+	xfRailIcon* icon = NULL;
+	BOOL replaceIcon = 0;
 	railWindow = xf_rail_get_window(xfc, orderInfo->windowId);
 
 	if (!railWindow)
@@ -730,9 +733,9 @@ static BOOL xf_rail_window_cached_icon(rdpContext* context, const WINDOW_ORDER_I
                                        const WINDOW_CACHED_ICON_ORDER* windowCachedIcon)
 {
 	xfContext* xfc = (xfContext*)context;
-	xfAppWindow* railWindow;
-	xfRailIcon* icon;
-	BOOL replaceIcon;
+	xfAppWindow* railWindow = NULL;
+	xfRailIcon* icon = NULL;
+	BOOL replaceIcon = 0;
 	railWindow = xf_rail_get_window(xfc, orderInfo->windowId);
 
 	if (!railWindow)
@@ -838,7 +841,7 @@ static void xf_rail_register_update_callbacks(rdpUpdate* update)
 static UINT xf_rail_server_execute_result(RailClientContext* context,
                                           const RAIL_EXEC_RESULT_ORDER* execResult)
 {
-	xfContext* xfc;
+	xfContext* xfc = NULL;
 
 	WINPR_ASSERT(context);
 	WINPR_ASSERT(execResult);
@@ -902,9 +905,10 @@ static UINT xf_rail_server_handshake_ex(RailClientContext* context,
 static UINT xf_rail_server_local_move_size(RailClientContext* context,
                                            const RAIL_LOCALMOVESIZE_ORDER* localMoveSize)
 {
-	int x = 0, y = 0;
+	int x = 0;
+	int y = 0;
 	int direction = 0;
-	Window child_window;
+	Window child_window = 0;
 	xfContext* xfc = (xfContext*)context->custom;
 	xfAppWindow* appWindow = xf_rail_get_window(xfc, localMoveSize->windowId);
 
@@ -1134,7 +1138,7 @@ int xf_rail_uninit(xfContext* xfc, RailClientContext* rail)
 xfAppWindow* xf_rail_add_window(xfContext* xfc, UINT64 id, UINT32 x, UINT32 y, UINT32 width,
                                 UINT32 height, UINT32 surfaceId)
 {
-	xfAppWindow* appWindow;
+	xfAppWindow* appWindow = NULL;
 
 	if (!xfc)
 		return NULL;
