@@ -458,7 +458,7 @@ static BOOL client_cli_authenticate_raw(freerdp* instance, rdp_auth_reason reaso
 	{
 		size_t username_size = 0;
 		printf("%s", prompt[0]);
-		fflush(stdout);
+		(void)fflush(stdout);
 
 		if (freerdp_interruptible_get_line(instance->context, username, &username_size, stdin) < 0)
 		{
@@ -479,7 +479,7 @@ static BOOL client_cli_authenticate_raw(freerdp* instance, rdp_auth_reason reaso
 	{
 		size_t domain_size = 0;
 		printf("%s", prompt[1]);
-		fflush(stdout);
+		(void)fflush(stdout);
 
 		if (freerdp_interruptible_get_line(instance->context, domain, &domain_size, stdin) < 0)
 		{
@@ -579,7 +579,7 @@ BOOL client_cli_choose_smartcard(freerdp* instance, SmartcardCertInfo** cert_lis
 
 		printf("\nChoose a smartcard to use for %s (0 - %" PRIu32 "): ",
 		       gateway ? "gateway authentication" : "logon", count - 1);
-		fflush(stdout);
+		(void)fflush(stdout);
 		if (!fgets(input, 10, stdin))
 		{
 			WLog_ERR(TAG, "could not read from stdin");
@@ -631,17 +631,12 @@ static DWORD client_cli_accept_certificate(freerdp* instance)
 	while (1)
 	{
 		printf("Do you trust the above certificate? (Y/T/N) ");
-		fflush(stdout);
+		(void)fflush(stdout);
 		answer = freerdp_interruptible_getc(instance->context, stdin);
 
 		if ((answer == EOF) || feof(stdin))
 		{
-			printf("\nError: Could not read answer from stdin.");
-
-			if (fromStdin)
-				printf(" - Run without parameter \"--from-stdin\" to set trust.");
-
-			printf("\n");
+			printf("\nError: Could not read answer from stdin.\n");
 			return 0;
 		}
 
@@ -708,6 +703,30 @@ DWORD client_cli_verify_certificate(freerdp* instance, const char* common_name,
 }
 #endif
 
+static char* client_cli_pem_cert(const char* pem)
+{
+	rdpCertificate* cert = freerdp_certificate_new_from_pem(pem);
+	if (!cert)
+		return NULL;
+
+	char* fp = freerdp_certificate_get_fingerprint(cert);
+	char* start = freerdp_certificate_get_validity(cert, TRUE);
+	char* end = freerdp_certificate_get_validity(cert, FALSE);
+	freerdp_certificate_free(cert);
+
+	char* str = NULL;
+	size_t slen = 0;
+	winpr_asprintf(&str, &slen,
+	               "\tValid from:  %s\n"
+	               "\tValid to:    %s\n"
+	               "\tThumbprint:  %s\n",
+	               start, end, fp);
+	free(fp);
+	free(start);
+	free(end);
+	return str;
+}
+
 /** Callback set in the rdp_freerdp structure, and used to make a certificate validation
  *  when the connection requires it.
  *  This function will actually be called by tls_verify_certificate().
@@ -748,9 +767,9 @@ DWORD client_cli_verify_certificate_ex(freerdp* instance, const char* host, UINT
 	 */
 	if (flags & VERIFY_CERT_FLAG_FP_IS_PEM)
 	{
-		printf("\t----------- Certificate --------------\n");
-		printf("%s\n", fingerprint);
-		printf("\t--------------------------------------\n");
+		char* str = client_cli_pem_cert(fingerprint);
+		printf("%s", str);
+		free(str);
 	}
 	else
 		printf("\tThumbprint:  %s\n", fingerprint);
@@ -854,9 +873,9 @@ DWORD client_cli_verify_changed_certificate_ex(freerdp* instance, const char* ho
 	 */
 	if (flags & VERIFY_CERT_FLAG_FP_IS_PEM)
 	{
-		printf("\t----------- Certificate --------------\n");
-		printf("%s\n", fingerprint);
-		printf("\t--------------------------------------\n");
+		char* str = client_cli_pem_cert(fingerprint);
+		printf("%s", str);
+		free(str);
 	}
 	else
 		printf("\tThumbprint:  %s\n", fingerprint);
@@ -869,9 +888,9 @@ DWORD client_cli_verify_changed_certificate_ex(freerdp* instance, const char* ho
 	 */
 	if (flags & VERIFY_CERT_FLAG_FP_IS_PEM)
 	{
-		printf("\t----------- Certificate --------------\n");
-		printf("%s\n", old_fingerprint);
-		printf("\t--------------------------------------\n");
+		char* str = client_cli_pem_cert(old_fingerprint);
+		printf("%s", str);
+		free(str);
 	}
 	else
 		printf("\tThumbprint:  %s\n", old_fingerprint);
@@ -924,7 +943,7 @@ BOOL client_cli_present_gateway_message(freerdp* instance, UINT32 type, BOOL isD
 	while (isConsentMandatory)
 	{
 		printf("I understand and agree to the terms of this policy (Y/N) \n");
-		fflush(stdout);
+		(void)fflush(stdout);
 		answer = freerdp_interruptible_getc(instance->context, stdin);
 
 		if ((answer == EOF) || feof(stdin))
@@ -1574,8 +1593,9 @@ BOOL freerdp_client_send_button_event(rdpClientContext* cctx, BOOL relative, UIN
 
 	WINPR_ASSERT(cctx);
 
-	const BOOL relativeInput = freerdp_client_use_relative_mouse_events(cctx);
-	if (relative && relativeInput)
+	const BOOL haveRelative =
+	    freerdp_settings_get_bool(cctx->context.settings, FreeRDP_HasRelativeMouseEvent);
+	if (relative && haveRelative)
 	{
 		return freerdp_input_send_rel_mouse_event(cctx->context.input, mflags, x, y);
 	}
@@ -1585,7 +1605,7 @@ BOOL freerdp_client_send_button_event(rdpClientContext* cctx, BOOL relative, UIN
 	{
 		UINT64 flags = 0;
 
-		if (cctx->mouse_grabbed && relativeInput)
+		if (cctx->mouse_grabbed && freerdp_client_use_relative_mouse_events(cctx))
 			flags |= AINPUT_FLAGS_HAVE_REL;
 
 		if (relative)
@@ -1630,7 +1650,9 @@ BOOL freerdp_client_send_extended_button_event(rdpClientContext* cctx, BOOL rela
 	BOOL handled = FALSE;
 	WINPR_ASSERT(cctx);
 
-	if (relative && freerdp_client_use_relative_mouse_events(cctx))
+	const BOOL haveRelative =
+	    freerdp_settings_get_bool(cctx->context.settings, FreeRDP_HasRelativeMouseEvent);
+	if (relative && haveRelative)
 	{
 		return freerdp_input_send_rel_mouse_event(cctx->context.input, mflags, x, y);
 	}
@@ -2147,8 +2169,8 @@ BOOL freerdp_client_use_relative_mouse_events(rdpClientContext* ccontext)
 	const rdpSettings* settings = ccontext->context.settings;
 	const BOOL useRelative = freerdp_settings_get_bool(settings, FreeRDP_MouseUseRelativeMove);
 	const BOOL haveRelative = freerdp_settings_get_bool(settings, FreeRDP_HasRelativeMouseEvent);
-	BOOL ainput = false;
-#if defined(CHANNEL_AINPUT_SERVER)
+	BOOL ainput = FALSE;
+#if defined(CHANNEL_AINPUT_CLIENT)
 	ainput = ccontext->ainput != NULL;
 #endif
 
