@@ -353,7 +353,6 @@ static BOOL maybe_clear_fuse_request(const void* key, void* value, void* arg)
 
 	fuse_reply_err(fuse_request->fuse_req, EIO);
 	HashTable_Remove(file_context->request_table, key);
-	free(fuse_request);
 
 	return TRUE;
 }
@@ -505,16 +504,15 @@ static void clear_no_cdi_entry(CliprdrFileContext* file_context)
 {
 	WINPR_ASSERT(file_context);
 
-	if (!file_context->clip_data_entry_without_id)
-		return;
-
 	WINPR_ASSERT(file_context->inode_table);
-
 	HashTable_Lock(file_context->inode_table);
-	clear_entry_selection(file_context->clip_data_entry_without_id);
+	if (file_context->clip_data_entry_without_id)
+	{
+		clear_entry_selection(file_context->clip_data_entry_without_id);
 
-	clip_data_entry_free(file_context->clip_data_entry_without_id);
-	file_context->clip_data_entry_without_id = NULL;
+		clip_data_entry_free(file_context->clip_data_entry_without_id);
+		file_context->clip_data_entry_without_id = NULL;
+	}
 	HashTable_Unlock(file_context->inode_table);
 }
 
@@ -555,6 +553,7 @@ static UINT prepare_clip_data_entry_with_id(CliprdrFileContext* file_context)
 	{
 		WLog_Print(file_context->log, WLOG_ERROR, "Failed to insert clipDataEntry");
 		clip_data_entry_free(clip_data_entry);
+		HashTable_Unlock(file_context->inode_table);
 		return ERROR_INTERNAL_ERROR;
 	}
 	HashTable_Unlock(file_context->inode_table);
@@ -748,7 +747,6 @@ static BOOL request_file_size_async(CliprdrFileContext* file_context, CliprdrFus
 		           "Failed to send FileContentsRequest for file \"%s\"",
 		           fuse_file->filename_with_root);
 		HashTable_Remove(file_context->request_table, (void*)(UINT_PTR)fuse_request->stream_id);
-		free(fuse_request);
 		return FALSE;
 	}
 	DEBUG_CLIPRDR(file_context->log, "Requested file size for file \"%s\" with stream id %u",
@@ -981,7 +979,7 @@ static void cliprdr_file_fuse_read(fuse_req_t fuse_req, fuse_ino_t fuse_ino, siz
 		return;
 	}
 
-	size = MIN(size, 8 * 1024 * 1024);
+	size = MIN(size, 8ULL * 1024ULL * 1024ULL);
 
 	result = request_file_range_async(file_context, fuse_file, fuse_req, offset, size);
 	HashTable_Unlock(file_context->inode_table);
@@ -1191,18 +1189,17 @@ static UINT cliprdr_file_context_server_file_contents_response(
 		HashTable_Unlock(file_context->inode_table);
 		return CHANNEL_RC_OK;
 	}
-	HashTable_Remove(file_context->request_table,
-	                 (void*)(UINT_PTR)file_contents_response->streamId);
 
 	if (!(file_contents_response->common.msgFlags & CB_RESPONSE_OK))
 	{
 		WLog_Print(file_context->log, WLOG_WARN,
 		           "FileContentsRequests for file \"%s\" was unsuccessful",
 		           fuse_request->fuse_file->filename);
-		HashTable_Unlock(file_context->inode_table);
 
 		fuse_reply_err(fuse_request->fuse_req, EIO);
-		free(fuse_request);
+		HashTable_Remove(file_context->request_table,
+		                 (void*)(UINT_PTR)file_contents_response->streamId);
+		HashTable_Unlock(file_context->inode_table);
 		return CHANNEL_RC_OK;
 	}
 
@@ -1213,10 +1210,10 @@ static UINT cliprdr_file_context_server_file_contents_response(
 		WLog_Print(file_context->log, WLOG_WARN,
 		           "Received invalid file size for file \"%s\" from the client",
 		           fuse_request->fuse_file->filename);
-		HashTable_Unlock(file_context->inode_table);
-
 		fuse_reply_err(fuse_request->fuse_req, EIO);
-		free(fuse_request);
+		HashTable_Remove(file_context->request_table,
+		                 (void*)(UINT_PTR)file_contents_response->streamId);
+		HashTable_Unlock(file_context->inode_table);
 		return CHANNEL_RC_OK;
 	}
 
@@ -1258,7 +1255,8 @@ static UINT cliprdr_file_context_server_file_contents_response(
 			break;
 	}
 
-	free(fuse_request);
+	HashTable_Remove(file_context->request_table,
+	                 (void*)(UINT_PTR)file_contents_response->streamId);
 
 	return CHANNEL_RC_OK;
 }
@@ -1403,7 +1401,7 @@ static void cliprdr_local_file_try_close(CliprdrLocalFile* file, UINT res, UINT6
 		// TODO: for the time being just close again.
 	}
 	if (file->fp)
-		fclose(file->fp);
+		(void)fclose(file->fp);
 	file->fp = NULL;
 }
 
@@ -1707,9 +1705,11 @@ static CliprdrFuseFile* clip_data_dir_new(CliprdrFileContext* file_context, BOOL
 	}
 
 	if (has_clip_data_id)
-		_snprintf(clip_data_dir->filename_with_root, path_length, "/%u", (unsigned)clip_data_id);
+		(void)_snprintf(clip_data_dir->filename_with_root, path_length, "/%u",
+		                (unsigned)clip_data_id);
 	else
-		_snprintf(clip_data_dir->filename_with_root, path_length, "/%" PRIu64, NO_CLIP_DATA_ID);
+		(void)_snprintf(clip_data_dir->filename_with_root, path_length, "/%" PRIu64,
+		                NO_CLIP_DATA_ID);
 
 	clip_data_dir->filename = strrchr(clip_data_dir->filename_with_root, '/') + 1;
 
@@ -1806,7 +1806,7 @@ static CliprdrFuseFile* get_parent_directory(CliprdrFileContext* file_context, c
 
 static BOOL set_selection_for_clip_data_entry(CliprdrFileContext* file_context,
                                               CliprdrFuseClipDataEntry* clip_data_entry,
-                                              FILEDESCRIPTORW* files, UINT32 n_files)
+                                              const FILEDESCRIPTORW* files, UINT32 n_files)
 {
 	CliprdrFuseFile* clip_data_dir = NULL;
 
@@ -1826,7 +1826,7 @@ static BOOL set_selection_for_clip_data_entry(CliprdrFileContext* file_context,
 	// NOLINTBEGIN(clang-analyzer-unix.Malloc) HashTable_Insert owns fuse_file
 	for (UINT32 i = 0; i < n_files; ++i)
 	{
-		FILEDESCRIPTORW* file = &files[i];
+		const FILEDESCRIPTORW* file = &files[i];
 		CliprdrFuseFile* fuse_file = NULL;
 		char* filename = NULL;
 		size_t path_length = 0;
@@ -1865,8 +1865,8 @@ static BOOL set_selection_for_clip_data_entry(CliprdrFileContext* file_context,
 			return FALSE;
 		}
 
-		_snprintf(fuse_file->filename_with_root, path_length, "%s/%s",
-		          clip_data_dir->filename_with_root, filename);
+		(void)_snprintf(fuse_file->filename_with_root, path_length, "%s/%s",
+		                clip_data_dir->filename_with_root, filename);
 		free(filename);
 
 		fuse_file->filename = strrchr(fuse_file->filename_with_root, '/') + 1;
@@ -1910,7 +1910,7 @@ static BOOL set_selection_for_clip_data_entry(CliprdrFileContext* file_context,
 			filetime += file->ftLastWriteTime.dwLowDateTime;
 
 			fuse_file->last_write_time_unix =
-			    filetime / (10 * 1000 * 1000) - WIN32_FILETIME_TO_UNIX_EPOCH;
+			    1ULL * filetime / (10ULL * 1000ULL * 1000ULL) - WIN32_FILETIME_TO_UNIX_EPOCH;
 			fuse_file->has_last_write_time = TRUE;
 		}
 
@@ -2016,6 +2016,7 @@ BOOL cliprdr_file_context_update_server_data(CliprdrFileContext* file_context, w
 	}
 	HashTable_Unlock(file_context->inode_table);
 
+	free(files);
 	return TRUE;
 #else
 	return FALSE;
@@ -2099,7 +2100,8 @@ static BOOL create_base_path(CliprdrFileContext* file)
 	WINPR_ASSERT(file);
 
 	char base[64] = { 0 };
-	_snprintf(base, sizeof(base), "com.freerdp.client.cliprdr.%" PRIu32, GetCurrentProcessId());
+	(void)_snprintf(base, sizeof(base), "com.freerdp.client.cliprdr.%" PRIu32,
+	                GetCurrentProcessId());
 
 	file->path = GetKnownSubPath(KNOWN_PATH_TEMP, base);
 	if (!file->path)
@@ -2121,7 +2123,7 @@ static void cliprdr_local_file_free(CliprdrLocalFile* file)
 	if (file->fp)
 	{
 		WLog_Print(file->context->log, WLOG_DEBUG, "closing file %s, discarding entry", file->name);
-		fclose(file->fp);
+		(void)fclose(file->fp);
 	}
 	free(file->name);
 	*file = empty;
@@ -2367,7 +2369,7 @@ static CliprdrFuseFile* fuse_file_new_root(CliprdrFileContext* file_context)
 		return NULL;
 	}
 
-	_snprintf(root_dir->filename_with_root, 2, "/");
+	(void)_snprintf(root_dir->filename_with_root, 2, "/");
 	root_dir->filename = root_dir->filename_with_root;
 
 	root_dir->ino = FUSE_ROOT_ID;
@@ -2417,9 +2419,16 @@ CliprdrFileContext* cliprdr_file_context_new(void* context)
 	if (!file->inode_table || !file->clip_data_table || !file->request_table)
 		goto fail;
 
-	wObject* ctobj = HashTable_ValueObject(file->clip_data_table);
-	WINPR_ASSERT(ctobj);
-	ctobj->fnObjectFree = clip_data_entry_free;
+	{
+		wObject* ctobj = HashTable_ValueObject(file->request_table);
+		WINPR_ASSERT(ctobj);
+		ctobj->fnObjectFree = free;
+	}
+	{
+		wObject* ctobj = HashTable_ValueObject(file->clip_data_table);
+		WINPR_ASSERT(ctobj);
+		ctobj->fnObjectFree = clip_data_entry_free;
+	}
 
 	file->root_dir = fuse_file_new_root(file);
 	if (!file->root_dir)
