@@ -82,7 +82,7 @@ static const UINT32 CLEAR_LOG2_FLOOR[256] = {
 
 static const BYTE CLEAR_8BIT_MASKS[9] = { 0x00, 0x01, 0x03, 0x07, 0x0F, 0x1F, 0x3F, 0x7F, 0xFF };
 
-static void clear_reset_vbar_storage(CLEAR_CONTEXT* clear, BOOL zero)
+static void clear_reset_vbar_storage(CLEAR_CONTEXT* WINPR_RESTRICT clear, BOOL zero)
 {
 	if (zero)
 	{
@@ -105,7 +105,7 @@ static void clear_reset_vbar_storage(CLEAR_CONTEXT* clear, BOOL zero)
 	clear->ShortVBarStorageCursor = 0;
 }
 
-static void clear_reset_glyph_cache(CLEAR_CONTEXT* clear)
+static void clear_reset_glyph_cache(CLEAR_CONTEXT* WINPR_RESTRICT clear)
 {
 	for (size_t i = 0; i < ARRAYSIZE(clear->GlyphCache); i++)
 		winpr_aligned_free(clear->GlyphCache[i].pixels);
@@ -113,10 +113,11 @@ static void clear_reset_glyph_cache(CLEAR_CONTEXT* clear)
 	ZeroMemory(clear->GlyphCache, sizeof(clear->GlyphCache));
 }
 
-static BOOL convert_color(BYTE* dst, UINT32 nDstStep, UINT32 DstFormat, UINT32 nXDst, UINT32 nYDst,
-                          UINT32 nWidth, UINT32 nHeight, const BYTE* src, UINT32 nSrcStep,
-                          UINT32 SrcFormat, UINT32 nDstWidth, UINT32 nDstHeight,
-                          const gdiPalette* palette)
+static BOOL convert_color(BYTE* WINPR_RESTRICT dst, UINT32 nDstStep, UINT32 DstFormat, UINT32 nXDst,
+                          UINT32 nYDst, UINT32 nWidth, UINT32 nHeight,
+                          const BYTE* WINPR_RESTRICT src, UINT32 nSrcStep, UINT32 SrcFormat,
+                          UINT32 nDstWidth, UINT32 nDstHeight,
+                          const gdiPalette* WINPR_RESTRICT palette)
 {
 	if (nWidth + nXDst > nDstWidth)
 		nWidth = nDstWidth - nXDst;
@@ -124,12 +125,14 @@ static BOOL convert_color(BYTE* dst, UINT32 nDstStep, UINT32 DstFormat, UINT32 n
 	if (nHeight + nYDst > nDstHeight)
 		nHeight = nDstHeight - nYDst;
 
-	return freerdp_image_copy(dst, DstFormat, nDstStep, nXDst, nYDst, nWidth, nHeight, src,
-	                          SrcFormat, nSrcStep, 0, 0, palette, FREERDP_KEEP_DST_ALPHA);
+	return freerdp_image_copy_no_overlap(dst, DstFormat, nDstStep, nXDst, nYDst, nWidth, nHeight,
+	                                     src, SrcFormat, nSrcStep, 0, 0, palette,
+	                                     FREERDP_KEEP_DST_ALPHA);
 }
 
-static BOOL clear_decompress_nscodec(NSC_CONTEXT* nsc, UINT32 width, UINT32 height, wStream* s,
-                                     UINT32 bitmapDataByteCount, BYTE* pDstData, UINT32 DstFormat,
+static BOOL clear_decompress_nscodec(NSC_CONTEXT* WINPR_RESTRICT nsc, UINT32 width, UINT32 height,
+                                     wStream* WINPR_RESTRICT s, UINT32 bitmapDataByteCount,
+                                     BYTE* WINPR_RESTRICT pDstData, UINT32 DstFormat,
                                      UINT32 nDstStep, UINT32 nXDstRel, UINT32 nYDstRel)
 {
 	BOOL rc = 0;
@@ -144,8 +147,9 @@ static BOOL clear_decompress_nscodec(NSC_CONTEXT* nsc, UINT32 width, UINT32 heig
 	return rc;
 }
 
-static BOOL clear_decompress_subcode_rlex(wStream* s, UINT32 bitmapDataByteCount, UINT32 width,
-                                          UINT32 height, BYTE* pDstData, UINT32 DstFormat,
+static BOOL clear_decompress_subcode_rlex(wStream* WINPR_RESTRICT s, UINT32 bitmapDataByteCount,
+                                          UINT32 width, UINT32 height,
+                                          BYTE* WINPR_RESTRICT pDstData, UINT32 DstFormat,
                                           UINT32 nDstStep, UINT32 nXDstRel, UINT32 nYDstRel,
                                           UINT32 nDstWidth, UINT32 nDstHeight)
 {
@@ -322,7 +326,7 @@ static BOOL clear_decompress_subcode_rlex(wStream* s, UINT32 bitmapDataByteCount
 	return TRUE;
 }
 
-static BOOL clear_resize_buffer(CLEAR_CONTEXT* clear, UINT32 width, UINT32 height)
+static BOOL clear_resize_buffer(CLEAR_CONTEXT* WINPR_RESTRICT clear, UINT32 width, UINT32 height)
 {
 	UINT32 size = 0;
 
@@ -349,11 +353,13 @@ static BOOL clear_resize_buffer(CLEAR_CONTEXT* clear, UINT32 width, UINT32 heigh
 	return TRUE;
 }
 
-static BOOL clear_decompress_residual_data(CLEAR_CONTEXT* clear, wStream* s,
-                                           UINT32 residualByteCount, UINT32 nWidth, UINT32 nHeight,
-                                           BYTE* pDstData, UINT32 DstFormat, UINT32 nDstStep,
-                                           UINT32 nXDst, UINT32 nYDst, UINT32 nDstWidth,
-                                           UINT32 nDstHeight, const gdiPalette* palette)
+static BOOL clear_decompress_residual_data(CLEAR_CONTEXT* WINPR_RESTRICT clear,
+                                           wStream* WINPR_RESTRICT s, UINT32 residualByteCount,
+                                           UINT32 nWidth, UINT32 nHeight,
+                                           BYTE* WINPR_RESTRICT pDstData, UINT32 DstFormat,
+                                           UINT32 nDstStep, UINT32 nXDst, UINT32 nYDst,
+                                           UINT32 nDstWidth, UINT32 nDstHeight,
+                                           const gdiPalette* WINPR_RESTRICT palette)
 {
 	UINT32 nSrcStep = 0;
 	UINT32 suboffset = 0;
@@ -409,7 +415,7 @@ static BOOL clear_decompress_residual_data(CLEAR_CONTEXT* clear, wStream* s,
 			}
 		}
 
-		if ((pixelIndex + runLengthFactor) > pixelCount)
+		if ((pixelIndex >= pixelCount) || (runLengthFactor > (pixelCount - pixelIndex)))
 		{
 			WLog_ERR(TAG,
 			         "pixelIndex %" PRIu32 " + runLengthFactor %" PRIu32 " > pixelCount %" PRIu32
@@ -440,11 +446,13 @@ static BOOL clear_decompress_residual_data(CLEAR_CONTEXT* clear, wStream* s,
 	                     palette);
 }
 
-static BOOL clear_decompress_subcodecs_data(CLEAR_CONTEXT* clear, wStream* s,
-                                            UINT32 subcodecByteCount, UINT32 nWidth, UINT32 nHeight,
-                                            BYTE* pDstData, UINT32 DstFormat, UINT32 nDstStep,
-                                            UINT32 nXDst, UINT32 nYDst, UINT32 nDstWidth,
-                                            UINT32 nDstHeight, const gdiPalette* palette)
+static BOOL clear_decompress_subcodecs_data(CLEAR_CONTEXT* WINPR_RESTRICT clear,
+                                            wStream* WINPR_RESTRICT s, UINT32 subcodecByteCount,
+                                            UINT32 nWidth, UINT32 nHeight,
+                                            BYTE* WINPR_RESTRICT pDstData, UINT32 DstFormat,
+                                            UINT32 nDstStep, UINT32 nXDst, UINT32 nYDst,
+                                            UINT32 nDstWidth, UINT32 nDstHeight,
+                                            const gdiPalette* WINPR_RESTRICT palette)
 {
 	UINT16 xStart = 0;
 	UINT16 yStart = 0;
@@ -481,15 +489,16 @@ static BOOL clear_decompress_subcodecs_data(CLEAR_CONTEXT* clear, wStream* s,
 		nXDstRel = nXDst + xStart;
 		nYDstRel = nYDst + yStart;
 
-		if (width > nWidth)
+		if (1ull * xStart + width > nWidth)
 		{
-			WLog_ERR(TAG, "width %" PRIu16 " > nWidth %" PRIu32 "", width, nWidth);
+			WLog_ERR(TAG, "xStart %" PRIu16 " + width %" PRIu16 " > nWidth %" PRIu32 "", xStart,
+			         width, nWidth);
 			return FALSE;
 		}
-
-		if (height > nHeight)
+		if (1ull * yStart + height > nHeight)
 		{
-			WLog_ERR(TAG, "height %" PRIu16 " > nHeight %" PRIu32 "", height, nHeight);
+			WLog_ERR(TAG, "yStart %" PRIu16 " + height %" PRIu16 " > nHeight %" PRIu32 "", yStart,
+			         height, nHeight);
 			return FALSE;
 		}
 
@@ -500,12 +509,12 @@ static BOOL clear_decompress_subcodecs_data(CLEAR_CONTEXT* clear, wStream* s,
 		{
 			case 0: /* Uncompressed */
 			{
-				UINT32 nSrcStep = width * FreeRDPGetBytesPerPixel(PIXEL_FORMAT_BGR24);
-				UINT32 nSrcSize = nSrcStep * height;
+				const UINT32 nSrcStep = width * FreeRDPGetBytesPerPixel(PIXEL_FORMAT_BGR24);
+				const size_t nSrcSize = 1ull * nSrcStep * height;
 
 				if (bitmapDataByteCount != nSrcSize)
 				{
-					WLog_ERR(TAG, "bitmapDataByteCount %" PRIu32 " != nSrcSize %" PRIu32 "",
+					WLog_ERR(TAG, "bitmapDataByteCount %" PRIu32 " != nSrcSize %" PRIuz "",
 					         bitmapDataByteCount, nSrcSize);
 					return FALSE;
 				}
@@ -545,7 +554,8 @@ static BOOL clear_decompress_subcodecs_data(CLEAR_CONTEXT* clear, wStream* s,
 	return TRUE;
 }
 
-static BOOL resize_vbar_entry(CLEAR_CONTEXT* clear, CLEAR_VBAR_ENTRY* vBarEntry)
+static BOOL resize_vbar_entry(CLEAR_CONTEXT* WINPR_RESTRICT clear,
+                              CLEAR_VBAR_ENTRY* WINPR_RESTRICT vBarEntry)
 {
 	if (vBarEntry->count > vBarEntry->size)
 	{
@@ -578,10 +588,12 @@ static BOOL resize_vbar_entry(CLEAR_CONTEXT* clear, CLEAR_VBAR_ENTRY* vBarEntry)
 	return TRUE;
 }
 
-static BOOL clear_decompress_bands_data(CLEAR_CONTEXT* clear, wStream* s, UINT32 bandsByteCount,
-                                        UINT32 nWidth, UINT32 nHeight, BYTE* pDstData,
-                                        UINT32 DstFormat, UINT32 nDstStep, UINT32 nXDst,
-                                        UINT32 nYDst, UINT32 nDstWidth, UINT32 nDstHeight)
+static BOOL clear_decompress_bands_data(CLEAR_CONTEXT* WINPR_RESTRICT clear,
+                                        wStream* WINPR_RESTRICT s, UINT32 bandsByteCount,
+                                        UINT32 nWidth, UINT32 nHeight,
+                                        BYTE* WINPR_RESTRICT pDstData, UINT32 DstFormat,
+                                        UINT32 nDstStep, UINT32 nXDst, UINT32 nYDst,
+                                        UINT32 nDstWidth, UINT32 nDstHeight)
 {
 	UINT32 suboffset = 0;
 
@@ -709,7 +721,7 @@ static BOOL clear_decompress_bands_data(CLEAR_CONTEXT* clear, wStream* s, UINT32
 				if (!resize_vbar_entry(clear, vBarShortEntry))
 					return FALSE;
 
-				for (UINT32 y = 0; y < vBarShortPixelCount; y++)
+				for (size_t y = 0; y < vBarShortPixelCount; y++)
 				{
 					BYTE r = 0;
 					BYTE g = 0;
@@ -798,11 +810,17 @@ static BOOL clear_decompress_bands_data(CLEAR_CONTEXT* clear, wStream* s, UINT32
 					count = (vBarPixelCount > y) ? (vBarPixelCount - y) : 0;
 
 				if (count > 0)
-					pSrcPixel =
-					    &vBarShortEntry
-					         ->pixels[(y - vBarYOn) * FreeRDPGetBytesPerPixel(clear->format)];
-
-				for (UINT32 x = 0; x < count; x++)
+				{
+					const size_t offset =
+					    (1ull * y - vBarYOn) * FreeRDPGetBytesPerPixel(clear->format);
+					pSrcPixel = &vBarShortEntry->pixels[offset];
+					if (offset + count > vBarShortEntry->count)
+					{
+						WLog_ERR(TAG, "offset + count > vBarShortEntry->count");
+						return FALSE;
+					}
+				}
+				for (size_t x = 0; x < count; x++)
 				{
 					UINT32 color = 0;
 					color = FreeRDPReadColor(&pSrcPixel[x * FreeRDPGetBytesPerPixel(clear->format)],
@@ -877,11 +895,13 @@ static BOOL clear_decompress_bands_data(CLEAR_CONTEXT* clear, wStream* s, UINT32
 	return TRUE;
 }
 
-static BOOL clear_decompress_glyph_data(CLEAR_CONTEXT* clear, wStream* s, UINT32 glyphFlags,
-                                        UINT32 nWidth, UINT32 nHeight, BYTE* pDstData,
+static BOOL clear_decompress_glyph_data(CLEAR_CONTEXT* WINPR_RESTRICT clear,
+                                        wStream* WINPR_RESTRICT s, UINT32 glyphFlags, UINT32 nWidth,
+                                        UINT32 nHeight, BYTE* WINPR_RESTRICT pDstData,
                                         UINT32 DstFormat, UINT32 nDstStep, UINT32 nXDst,
                                         UINT32 nYDst, UINT32 nDstWidth, UINT32 nDstHeight,
-                                        const gdiPalette* palette, BYTE** ppGlyphData)
+                                        const gdiPalette* WINPR_RESTRICT palette,
+                                        BYTE** WINPR_RESTRICT ppGlyphData)
 {
 	UINT16 glyphIndex = 0;
 
@@ -984,7 +1004,7 @@ static BOOL clear_decompress_glyph_data(CLEAR_CONTEXT* clear, wStream* s, UINT32
 	return TRUE;
 }
 
-static INLINE BOOL updateContextFormat(CLEAR_CONTEXT* clear, UINT32 DstFormat)
+static INLINE BOOL updateContextFormat(CLEAR_CONTEXT* WINPR_RESTRICT clear, UINT32 DstFormat)
 {
 	if (!clear || !clear->nsc)
 		return FALSE;
@@ -993,10 +1013,11 @@ static INLINE BOOL updateContextFormat(CLEAR_CONTEXT* clear, UINT32 DstFormat)
 	return nsc_context_set_parameters(clear->nsc, NSC_COLOR_FORMAT, DstFormat);
 }
 
-INT32 clear_decompress(CLEAR_CONTEXT* clear, const BYTE* pSrcData, UINT32 SrcSize, UINT32 nWidth,
-                       UINT32 nHeight, BYTE* pDstData, UINT32 DstFormat, UINT32 nDstStep,
-                       UINT32 nXDst, UINT32 nYDst, UINT32 nDstWidth, UINT32 nDstHeight,
-                       const gdiPalette* palette)
+INT32 clear_decompress(CLEAR_CONTEXT* WINPR_RESTRICT clear, const BYTE* WINPR_RESTRICT pSrcData,
+                       UINT32 SrcSize, UINT32 nWidth, UINT32 nHeight, BYTE* WINPR_RESTRICT pDstData,
+                       UINT32 DstFormat, UINT32 nDstStep, UINT32 nXDst, UINT32 nYDst,
+                       UINT32 nDstWidth, UINT32 nDstHeight,
+                       const gdiPalette* WINPR_RESTRICT palette)
 {
 	INT32 rc = -1;
 	BYTE seqNumber = 0;
@@ -1111,8 +1132,9 @@ INT32 clear_decompress(CLEAR_CONTEXT* clear, const BYTE* pSrcData, UINT32 SrcSiz
 
 	if (glyphData)
 	{
-		if (!freerdp_image_copy(glyphData, clear->format, 0, 0, 0, nWidth, nHeight, pDstData,
-		                        DstFormat, nDstStep, nXDst, nYDst, palette, FREERDP_KEEP_DST_ALPHA))
+		if (!freerdp_image_copy_no_overlap(glyphData, clear->format, 0, 0, 0, nWidth, nHeight,
+		                                   pDstData, DstFormat, nDstStep, nXDst, nYDst, palette,
+		                                   FREERDP_KEEP_DST_ALPHA))
 			goto fail;
 	}
 
@@ -1122,14 +1144,14 @@ fail:
 	return rc;
 }
 
-int clear_compress(CLEAR_CONTEXT* clear, const BYTE* pSrcData, UINT32 SrcSize, BYTE** ppDstData,
-                   UINT32* pDstSize)
+int clear_compress(CLEAR_CONTEXT* WINPR_RESTRICT clear, const BYTE* WINPR_RESTRICT pSrcData,
+                   UINT32 SrcSize, BYTE** WINPR_RESTRICT ppDstData, UINT32* WINPR_RESTRICT pDstSize)
 {
 	WLog_ERR(TAG, "TODO: not implemented!");
 	return 1;
 }
 
-BOOL clear_context_reset(CLEAR_CONTEXT* clear)
+BOOL clear_context_reset(CLEAR_CONTEXT* WINPR_RESTRICT clear)
 {
 	if (!clear)
 		return FALSE;
@@ -1169,7 +1191,10 @@ CLEAR_CONTEXT* clear_context_new(BOOL Compressor)
 
 	return clear;
 error_nsc:
+	WINPR_PRAGMA_DIAG_PUSH
+	WINPR_PRAGMA_DIAG_IGNORED_MISMATCHED_DEALLOC
 	clear_context_free(clear);
+	WINPR_PRAGMA_DIAG_POP
 	return NULL;
 }
 
