@@ -44,10 +44,10 @@
 #define UNROLL_MULTIPLE(_condition, _exp, _count) \
 	do                                            \
 	{                                             \
-		while ((_condition) >= _count)            \
+		while ((_condition) >= (_count))          \
 		{                                         \
 			UNROLL_BODY(_exp, _count);            \
-			(_condition) -= _count;               \
+			(_condition) -= (_count);             \
 		}                                         \
 	} while (FALSE)
 
@@ -149,7 +149,7 @@ static const char* rle_code_str(UINT32 code)
 static const char* rle_code_str_buffer(UINT32 code, char* buffer, size_t size)
 {
 	const char* str = rle_code_str(code);
-	_snprintf(buffer, size, "%s [0x%08" PRIx32 "]", str, code);
+	(void)_snprintf(buffer, size, "%s [0x%08" PRIx32 "]", str, code);
 	return buffer;
 }
 
@@ -428,14 +428,14 @@ static INLINE void write_pixel_16(BYTE* _buf, UINT16 _pix)
 	do                             \
 	{                              \
 		write_pixel_8(_buf, _pix); \
-		_buf += 1;                 \
+		(_buf) += 1;               \
 	} while (0)
 #define DESTREADPIXEL(_pix, _buf) _pix = (_buf)[0]
 #define SRCREADPIXEL(_pix, _buf) \
 	do                           \
 	{                            \
-		_pix = (_buf)[0];        \
-		_buf += 1;               \
+		(_pix) = (_buf)[0];      \
+		(_buf) += 1;             \
 	} while (0)
 
 #define WRITEFGBGIMAGE WriteFgBgImage8to8
@@ -463,14 +463,14 @@ static INLINE void write_pixel_16(BYTE* _buf, UINT16 _pix)
 	do                              \
 	{                               \
 		write_pixel_16(_buf, _pix); \
-		_buf += 2;                  \
+		(_buf) += 2;                \
 	} while (0)
 #define DESTREADPIXEL(_pix, _buf) _pix = ((UINT16*)(_buf))[0]
-#define SRCREADPIXEL(_pix, _buf)             \
-	do                                       \
-	{                                        \
-		_pix = (_buf)[0] | ((_buf)[1] << 8); \
-		_buf += 2;                           \
+#define SRCREADPIXEL(_pix, _buf)               \
+	do                                         \
+	{                                          \
+		(_pix) = (_buf)[0] | ((_buf)[1] << 8); \
+		(_buf) += 2;                           \
 	} while (0)
 #define WRITEFGBGIMAGE WriteFgBgImage16to16
 #define WRITEFIRSTLINEFGBGIMAGE WriteFirstLineFgBgImage16to16
@@ -497,14 +497,14 @@ static INLINE void write_pixel_16(BYTE* _buf, UINT16 _pix)
 	do                              \
 	{                               \
 		write_pixel_24(_buf, _pix); \
-		_buf += 3;                  \
+		(_buf) += 3;                \
 	} while (0)
 #define DESTREADPIXEL(_pix, _buf) _pix = (_buf)[0] | ((_buf)[1] << 8) | ((_buf)[2] << 16)
-#define SRCREADPIXEL(_pix, _buf)                                 \
-	do                                                           \
-	{                                                            \
-		_pix = (_buf)[0] | ((_buf)[1] << 8) | ((_buf)[2] << 16); \
-		_buf += 3;                                               \
+#define SRCREADPIXEL(_pix, _buf)                                   \
+	do                                                             \
+	{                                                              \
+		(_pix) = (_buf)[0] | ((_buf)[1] << 8) | ((_buf)[2] << 16); \
+		(_buf) += 3;                                               \
 	} while (0)
 
 #define WRITEFGBGIMAGE WriteFgBgImage24to24
@@ -525,11 +525,12 @@ struct S_BITMAP_INTERLEAVED_CONTEXT
 	wStream* bts;
 };
 
-BOOL interleaved_decompress(BITMAP_INTERLEAVED_CONTEXT* interleaved, const BYTE* pSrcData,
-                            UINT32 SrcSize, UINT32 nSrcWidth, UINT32 nSrcHeight, UINT32 bpp,
-                            BYTE* pDstData, UINT32 DstFormat, UINT32 nDstStep, UINT32 nXDst,
-                            UINT32 nYDst, UINT32 nDstWidth, UINT32 nDstHeight,
-                            const gdiPalette* palette)
+BOOL interleaved_decompress(BITMAP_INTERLEAVED_CONTEXT* WINPR_RESTRICT interleaved,
+                            const BYTE* WINPR_RESTRICT pSrcData, UINT32 SrcSize, UINT32 nSrcWidth,
+                            UINT32 nSrcHeight, UINT32 bpp, BYTE* WINPR_RESTRICT pDstData,
+                            UINT32 DstFormat, UINT32 nDstStep, UINT32 nXDst, UINT32 nYDst,
+                            UINT32 nDstWidth, UINT32 nDstHeight,
+                            const gdiPalette* WINPR_RESTRICT palette)
 {
 	UINT32 scanline = 0;
 	UINT32 SrcFormat = 0;
@@ -622,9 +623,9 @@ BOOL interleaved_decompress(BITMAP_INTERLEAVED_CONTEXT* interleaved, const BYTE*
 			return FALSE;
 	}
 
-	if (!freerdp_image_copy(pDstData, DstFormat, nDstStep, nXDst, nYDst, nDstWidth, nDstHeight,
-	                        interleaved->TempBuffer, SrcFormat, scanline, 0, 0, palette,
-	                        FREERDP_FLIP_VERTICAL | FREERDP_KEEP_DST_ALPHA))
+	if (!freerdp_image_copy_no_overlap(pDstData, DstFormat, nDstStep, nXDst, nYDst, nDstWidth,
+	                                   nDstHeight, interleaved->TempBuffer, SrcFormat, scanline, 0,
+	                                   0, palette, FREERDP_FLIP_VERTICAL | FREERDP_KEEP_DST_ALPHA))
 	{
 		WLog_ERR(TAG, "freerdp_image_copy failed");
 		return FALSE;
@@ -632,10 +633,11 @@ BOOL interleaved_decompress(BITMAP_INTERLEAVED_CONTEXT* interleaved, const BYTE*
 	return TRUE;
 }
 
-BOOL interleaved_compress(BITMAP_INTERLEAVED_CONTEXT* interleaved, BYTE* pDstData, UINT32* pDstSize,
-                          UINT32 nWidth, UINT32 nHeight, const BYTE* pSrcData, UINT32 SrcFormat,
-                          UINT32 nSrcStep, UINT32 nXSrc, UINT32 nYSrc, const gdiPalette* palette,
-                          UINT32 bpp)
+BOOL interleaved_compress(BITMAP_INTERLEAVED_CONTEXT* WINPR_RESTRICT interleaved,
+                          BYTE* WINPR_RESTRICT pDstData, UINT32* pDstSize, UINT32 nWidth,
+                          UINT32 nHeight, const BYTE* WINPR_RESTRICT pSrcData, UINT32 SrcFormat,
+                          UINT32 nSrcStep, UINT32 nXSrc, UINT32 nYSrc,
+                          const gdiPalette* WINPR_RESTRICT palette, UINT32 bpp)
 {
 	BOOL status = 0;
 	wStream* s = NULL;
@@ -681,8 +683,9 @@ BOOL interleaved_compress(BITMAP_INTERLEAVED_CONTEXT* interleaved, BYTE* pDstDat
 			return FALSE;
 	}
 
-	if (!freerdp_image_copy(interleaved->TempBuffer, DstFormat, 0, 0, 0, nWidth, nHeight, pSrcData,
-	                        SrcFormat, nSrcStep, nXSrc, nYSrc, palette, FREERDP_KEEP_DST_ALPHA))
+	if (!freerdp_image_copy_no_overlap(interleaved->TempBuffer, DstFormat, 0, 0, 0, nWidth, nHeight,
+	                                   pSrcData, SrcFormat, nSrcStep, nXSrc, nYSrc, palette,
+	                                   FREERDP_KEEP_DST_ALPHA))
 		return FALSE;
 
 	s = Stream_New(pDstData, *pDstSize);
@@ -704,7 +707,7 @@ BOOL interleaved_compress(BITMAP_INTERLEAVED_CONTEXT* interleaved, BYTE* pDstDat
 	return status;
 }
 
-BOOL bitmap_interleaved_context_reset(BITMAP_INTERLEAVED_CONTEXT* interleaved)
+BOOL bitmap_interleaved_context_reset(BITMAP_INTERLEAVED_CONTEXT* WINPR_RESTRICT interleaved)
 {
 	if (!interleaved)
 		return FALSE;
@@ -742,7 +745,7 @@ fail:
 	return NULL;
 }
 
-void bitmap_interleaved_context_free(BITMAP_INTERLEAVED_CONTEXT* interleaved)
+void bitmap_interleaved_context_free(BITMAP_INTERLEAVED_CONTEXT* WINPR_RESTRICT interleaved)
 {
 	if (!interleaved)
 		return;
