@@ -146,7 +146,7 @@ int freerdp_addin_set_argument_value(ADDIN_ARGV* args, const char* option, const
 	if (!str)
 		return -1;
 
-	sprintf_s(str, length + 1, "%s:%s", option, value);
+	(void)sprintf_s(str, length + 1, "%s:%s", option, value);
 
 	for (int i = 0; i < args->argc; i++)
 	{
@@ -184,7 +184,7 @@ int freerdp_addin_replace_argument_value(ADDIN_ARGV* args, const char* previous,
 	if (!str)
 		return -1;
 
-	sprintf_s(str, length + 1, "%s:%s", option, value);
+	(void)sprintf_s(str, length + 1, "%s:%s", option, value);
 
 	for (int i = 0; i < args->argc; i++)
 	{
@@ -237,6 +237,33 @@ BOOL freerdp_device_collection_add(rdpSettings* settings, RDPDR_DEVICE* device)
 	return TRUE;
 }
 
+BOOL freerdp_device_collection_del(rdpSettings* settings, const RDPDR_DEVICE* device)
+{
+	WINPR_ASSERT(settings);
+
+	if (!device)
+		return FALSE;
+
+	const UINT32 count = settings->DeviceCount;
+	for (size_t x = 0; x < count; x++)
+	{
+		const RDPDR_DEVICE* cur = settings->DeviceArray[x];
+		if (cur == device)
+		{
+			for (size_t y = x + 1; y < count; y++)
+			{
+				RDPDR_DEVICE* next = settings->DeviceArray[y];
+				settings->DeviceArray[y - 1] = next;
+			}
+			settings->DeviceArray[count - 1] = NULL;
+			settings->DeviceCount--;
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 RDPDR_DEVICE* freerdp_device_collection_find(rdpSettings* settings, const char* name)
 {
 	RDPDR_DEVICE* device = NULL;
@@ -245,7 +272,7 @@ RDPDR_DEVICE* freerdp_device_collection_find(rdpSettings* settings, const char*
 	WINPR_ASSERT(name);
 	for (UINT32 index = 0; index < settings->DeviceCount; index++)
 	{
-		device = (RDPDR_DEVICE*)settings->DeviceArray[index];
+		device = settings->DeviceArray[index];
 
 		if (!device->Name)
 			continue;
@@ -264,7 +291,7 @@ RDPDR_DEVICE* freerdp_device_collection_find_type(rdpSettings* settings, UINT32
 
 	for (UINT32 index = 0; index < settings->DeviceCount; index++)
 	{
-		device = (RDPDR_DEVICE*)settings->DeviceArray[index];
+		device = settings->DeviceArray[index];
 
 		if (device->Type == type)
 			return device;
@@ -392,6 +419,9 @@ fail:
 
 void freerdp_device_free(RDPDR_DEVICE* device)
 {
+	if (!device)
+		return;
+
 	union
 	{
 		RDPDR_DEVICE* dev;
@@ -403,8 +433,6 @@ void freerdp_device_free(RDPDR_DEVICE* device)
 	} cnv;
 
 	cnv.dev = device;
-	if (!cnv.dev)
-		return;
 
 	switch (device->Type)
 	{
@@ -536,14 +564,14 @@ void freerdp_device_collection_free(rdpSettings* settings)
 	if (settings->DeviceArray)
 	{
 		for (UINT32 index = 0; index < settings->DeviceArraySize; index++)
-			freerdp_settings_set_pointer_array(settings, FreeRDP_DeviceArray, index, NULL);
+			(void)freerdp_settings_set_pointer_array(settings, FreeRDP_DeviceArray, index, NULL);
 	}
 
 	free(settings->DeviceArray);
 
-	freerdp_settings_set_pointer(settings, FreeRDP_DeviceArray, NULL);
-	freerdp_settings_set_uint32(settings, FreeRDP_DeviceArraySize, 0);
-	freerdp_settings_set_uint32(settings, FreeRDP_DeviceCount, 0);
+	(void)freerdp_settings_set_pointer(settings, FreeRDP_DeviceArray, NULL);
+	(void)freerdp_settings_set_uint32(settings, FreeRDP_DeviceArraySize, 0);
+	(void)freerdp_settings_set_uint32(settings, FreeRDP_DeviceCount, 0);
 }
 
 BOOL freerdp_static_channel_collection_del(rdpSettings* settings, const char* name)
@@ -1166,8 +1194,10 @@ BOOL freerdp_settings_set_value_for_name(rdpSettings* settings, const char* name
 
 		case RDP_SETTINGS_TYPE_BOOL:
 		{
-			BOOL val = _strnicmp(value, "TRUE", 5) == 0;
-			if (!val && _strnicmp(value, "FALSE", 6) != 0)
+			const BOOL val = (_strnicmp(value, "TRUE", 5) == 0) || (_strnicmp(value, "ON", 5) == 0);
+			const BOOL nval =
+			    (_strnicmp(value, "FALSE", 6) == 0) || (_strnicmp(value, "OFF", 6) == 0);
+			if (!val && !nval)
 				return parsing_fail(name, "BOOL", value);
 			return freerdp_settings_set_bool(settings, (FreeRDP_Settings_Keys_Bool)index, val);
 		}
@@ -1947,7 +1977,7 @@ char* freerdp_rail_support_flags_to_string(UINT32 flags, char* buffer, size_t le
 	if ((flags & ~mask) != 0)
 	{
 		char tbuffer[64] = { 0 };
-		_snprintf(tbuffer, sizeof(tbuffer), "RAIL_FLAG_UNKNOWN 0x%08" PRIx32, flags & mask);
+		(void)_snprintf(tbuffer, sizeof(tbuffer), "RAIL_FLAG_UNKNOWN 0x%08" PRIx32, flags & mask);
 		winpr_str_append(tbuffer, buffer, length, "|");
 	}
 	return buffer;
@@ -2151,11 +2181,11 @@ const char* freerdp_supported_color_depths_string(UINT16 mask, char* buffer, siz
 	if (invalid != 0)
 	{
 		char str[32] = { 0 };
-		_snprintf(str, sizeof(str), "RNS_UD_INVALID[0x%04" PRIx32 "]", invalid);
+		(void)_snprintf(str, sizeof(str), "RNS_UD_INVALID[0x%04" PRIx32 "]", invalid);
 		winpr_str_append(str, buffer, size, "|");
 	}
 	char hex[32] = { 0 };
-	_snprintf(hex, sizeof(hex), "[0x%04" PRIx16 "]", mask);
+	(void)_snprintf(hex, sizeof(hex), "[0x%04" PRIx16 "]", mask);
 	return buffer;
 }
 
