@@ -34,6 +34,7 @@
 
 #include <freerdp/log.h>
 
+#include "utils.h"
 #include "credssp_auth.h"
 
 #define TAG FREERDP_TAG("core.auth")
@@ -197,7 +198,7 @@ static BOOL credssp_auth_client_init_cred_attributes(rdpCredsspAuth* auth)
 {
 	WINPR_ASSERT(auth);
 
-	if (auth->kerberosSettings.kdcUrl)
+	if (!utils_str_is_empty(auth->kerberosSettings.kdcUrl))
 	{
 		SECURITY_STATUS status = ERROR_INTERNAL_ERROR;
 		SecPkgCredentials_KdcProxySettingsW* secAttr = NULL;
@@ -808,6 +809,7 @@ static SecurityFunctionTable* auth_resolve_sspi_table(const rdpSettings* setting
 		if (!hSSPI)
 		{
 			WLog_ERR(TAG, "Failed to load SSPI module: %s", module_name);
+			free(sspi_module);
 			return FALSE;
 		}
 
@@ -945,7 +947,7 @@ BOOL credssp_auth_set_spn(rdpCredsspAuth* auth, const char* service, const char*
 		if (!spn)
 			return FALSE;
 
-		sprintf_s(spn, length, "%s/%s", service, hostname);
+		(void)sprintf_s(spn, length, "%s/%s", service, hostname);
 	}
 	if (!spn)
 		return FALSE;
