@@ -51,6 +51,7 @@
 #include <freerdp/error.h>
 #include <freerdp/event.h>
 #include <freerdp/locale/keyboard.h>
+#include <freerdp/locale/locale.h>
 #include <freerdp/channels/channels.h>
 #include <freerdp/version.h>
 #include <freerdp/log.h>
@@ -84,7 +85,6 @@ static void sig_abort_connect(int signum, const char* signame, void* ctx)
 static int freerdp_connect_begin(freerdp* instance)
 {
 	BOOL rc = 0;
-	UINT status2 = CHANNEL_RC_OK;
 	rdpRdp* rdp = NULL;
 	BOOL status = TRUE;
 	rdpSettings* settings = NULL;
@@ -121,18 +121,15 @@ static int freerdp_connect_begin(freerdp* instance)
 	freerdp_settings_print_warnings(settings);
 
 	if (status)
-	{
-		if (!rdp_set_backup_settings(rdp))
-			return 0;
+		status = rdp_set_backup_settings(rdp);
+	if (status)
+		status = utils_reload_channels(instance->context);
 
-		WINPR_ASSERT(instance->LoadChannels);
-		if (!instance->LoadChannels(instance))
-			return 0;
+	const UINT32 cp = freerdp_settings_get_uint32(settings, FreeRDP_KeyboardCodePage);
+	KeyboardLayout = freerdp_get_keyboard_default_layout_for_locale(cp);
+	if (KeyboardLayout == 0)
+		KeyboardLayout = freerdp_settings_get_uint32(settings, FreeRDP_KeyboardLayout);
 
-		status2 = freerdp_channels_pre_connect(instance->context->channels, instance);
-	}
-
-	KeyboardLayout = freerdp_settings_get_uint32(settings, FreeRDP_KeyboardLayout);
 	switch (KeyboardLayout)
 	{
 		case KBD_JAPANESE:
@@ -151,7 +148,7 @@ static int freerdp_connect_begin(freerdp* instance)
 			break;
 	}
 
-	if (!status || (status2 != CHANNEL_RC_OK))
+	if (!status)
 	{
 		rdpContext* context = instance->context;
 		WINPR_ASSERT(context);
@@ -413,8 +410,8 @@ static BOOL freerdp_prevent_session_lock(rdpContext* context)
 		if (now - in->lastInputTimestamp > FakeMouseMotionInterval)
 		{
 			WLog_Print(context->log, WLOG_DEBUG,
-			           "fake mouse move: x=%d y=%d lastInputTimestamp=%d "
-			           "FakeMouseMotionInterval=%d",
+			           "fake mouse move: x=%d y=%d lastInputTimestamp=%" PRIu64 " "
+			           "FakeMouseMotionInterval=%" PRIu32,
 			           in->lastX, in->lastY, in->lastInputTimestamp, FakeMouseMotionInterval);
 
 			BOOL status = freerdp_input_send_mouse_event(context->input, PTR_FLAGS_MOVE, in->lastX,
@@ -661,7 +658,7 @@ BOOL freerdp_shall_disconnect(freerdp* instance)
 	return freerdp_shall_disconnect_context(instance->context);
 }
 
-BOOL freerdp_shall_disconnect_context(rdpContext* context)
+BOOL freerdp_shall_disconnect_context(const rdpContext* context)
 {
 	if (!context)
 		return FALSE;
@@ -904,7 +901,7 @@ void freerdp_context_free(freerdp* instance)
 	freerdp_channels_free(ctx->channels);
 	ctx->channels = NULL;
 
-	codecs_free(ctx->codecs);
+	freerdp_client_codecs_free(ctx->codecs);
 	ctx->codecs = NULL;
 
 	stream_dump_free(ctx->dump);
@@ -1050,12 +1047,13 @@ void freerdp_set_last_error_ex(rdpContext* context, UINT32 lastError, const char
                                const char* file, int line)
 {
 	WINPR_ASSERT(context);
+	WINPR_ASSERT(line >= 0);
 
 	if (lastError)
 	{
 		if (WLog_IsLevelActive(context->log, WLOG_ERROR))
 		{
-			WLog_PrintMessage(context->log, WLOG_MESSAGE_TEXT, WLOG_ERROR, line, file, fkt,
+			WLog_PrintMessage(context->log, WLOG_MESSAGE_TEXT, WLOG_ERROR, (size_t)line, file, fkt,
 			                  "%s [0x%08" PRIX32 "]", freerdp_get_last_error_name(lastError),
 			                  lastError);
 		}
@@ -1083,7 +1081,7 @@ void freerdp_set_last_error_ex(rdpContext* context, UINT32 lastError, const char
 const char* freerdp_get_logon_error_info_type_ex(UINT32 type, char* buffer, size_t size)
 {
 	const char* str = freerdp_get_logon_error_info_type(type);
-	_snprintf(buffer, size, "%s(0x%04" PRIx32 ")", str, type);
+	(void)_snprintf(buffer, size, "%s(0x%04" PRIx32 ")", str, type);
 	return buffer;
 }
 
@@ -1138,7 +1136,7 @@ const char* freerdp_get_logon_error_info_data(UINT32 data)
 const char* freerdp_get_logon_error_info_data_ex(UINT32 data, char* buffer, size_t size)
 {
 	const char* str = freerdp_get_logon_error_info_data(data);
-	_snprintf(buffer, size, "%s(0x%04" PRIx32 ")", str, data);
+	(void)_snprintf(buffer, size, "%s(0x%04" PRIx32 ")", str, data);
 	return buffer;
 }
 
@@ -1277,7 +1275,7 @@ void setChannelError(rdpContext* context, UINT errorNum, WINPR_FORMAT_ARG const
 	WINPR_ASSERT(context);
 
 	context->channelErrorNum = errorNum;
-	vsnprintf(context->errorDescription, 499, format, ap);
+	(void)vsnprintf(context->errorDescription, 499, format, ap);
 	va_end(ap);
 	SetEvent(context->channelErrorEvent);
 }
