@@ -354,63 +354,60 @@ static UINT32 rpc_map_status_code_to_win32_error_code(UINT32 code)
 
 const char* rpc_error_to_string(UINT32 code)
 {
-	size_t index;
 	static char buffer[1024];
 
-	for (index = 0; index < ARRAYSIZE(RPC_FAULT_CODES); index++)
+	for (size_t index = 0; index < ARRAYSIZE(RPC_FAULT_CODES); index++)
 	{
 		const RPC_FAULT_CODE* const current = &RPC_FAULT_CODES[index];
 		if (current->code == code)
 		{
-			sprintf_s(buffer, ARRAYSIZE(buffer), "%s", current->name);
+			(void)sprintf_s(buffer, ARRAYSIZE(buffer), "%s", current->name);
 			goto out;
 		}
 	}
 
-	for (index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
+	for (size_t index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
 	{
 		const RPC_FAULT_CODE* const current = &RPC_TSG_FAULT_CODES[index];
 		if (current->code == code)
 		{
-			sprintf_s(buffer, ARRAYSIZE(buffer), "%s", current->name);
+			(void)sprintf_s(buffer, ARRAYSIZE(buffer), "%s", current->name);
 			goto out;
 		}
 	}
 
-	for (index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
+	for (size_t index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
 	{
 		const RPC_FAULT_CODE* const current = &RPC_TSG_FAULT_CODES[index];
 		if (current->code == HRESULT_CODE(code))
 		{
-			sprintf_s(buffer, ARRAYSIZE(buffer), "%s", current->name);
+			(void)sprintf_s(buffer, ARRAYSIZE(buffer), "%s", current->name);
 			goto out;
 		}
 	}
 
-	sprintf_s(buffer, ARRAYSIZE(buffer), "%s [0x%08" PRIX32 "]", "UNKNOWN", code);
+	(void)sprintf_s(buffer, ARRAYSIZE(buffer), "%s [0x%08" PRIX32 "]", "UNKNOWN", code);
 out:
 	return buffer;
 }
 
 const char* rpc_error_to_category(UINT32 code)
 {
-	size_t index;
-
-	for (index = 0; index < ARRAYSIZE(RPC_FAULT_CODES); index++)
+	for (size_t index = 0; index < ARRAYSIZE(RPC_FAULT_CODES); index++)
 	{
 		const RPC_FAULT_CODE* const current = &RPC_FAULT_CODES[index];
 		if (current->code == code)
 			return current->category;
 	}
 
-	for (index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
+	for (size_t index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
 	{
 		const RPC_FAULT_CODE* const current = &RPC_TSG_FAULT_CODES[index];
 		if (current->code == code)
 			return current->category;
 	}
 
-	for (index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
+	for (size_t index = 0; index < ARRAYSIZE(RPC_TSG_FAULT_CODES); index++)
 	{
 		const RPC_FAULT_CODE* const current = &RPC_TSG_FAULT_CODES[index];
 		if (current->code == HRESULT_CODE(code))
