@@ -157,10 +157,10 @@ static char* rdp_early_server_caps_string(UINT32 flags, char* buffer, size_t siz
 
 	if (unknown != 0)
 	{
-		_snprintf(msg, sizeof(msg), "RNS_UD_SC_UNKNOWN[0x%08" PRIx32 "]", unknown);
+		(void)_snprintf(msg, sizeof(msg), "RNS_UD_SC_UNKNOWN[0x%08" PRIx32 "]", unknown);
 		winpr_str_append(msg, buffer, size, "|");
 	}
-	_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", flags);
+	(void)_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", flags);
 	winpr_str_append(msg, buffer, size, "|");
 	return buffer;
 }
@@ -204,10 +204,10 @@ static const char* rdp_early_client_caps_string(UINT32 flags, char* buffer, size
 
 	if (unknown != 0)
 	{
-		_snprintf(msg, sizeof(msg), "RNS_UD_CS_UNKNOWN[0x%08" PRIx32 "]", unknown);
+		(void)_snprintf(msg, sizeof(msg), "RNS_UD_CS_UNKNOWN[0x%08" PRIx32 "]", unknown);
 		winpr_str_append(msg, buffer, size, "|");
 	}
-	_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", flags);
+	(void)_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", flags);
 	winpr_str_append(msg, buffer, size, "|");
 	return buffer;
 }
@@ -572,6 +572,9 @@ BOOL gcc_read_client_data_blocks(wStream* s, rdpMcs* mcs, UINT16 length)
 {
 	WINPR_ASSERT(s);
 	WINPR_ASSERT(mcs);
+
+	BOOL gotMultitransport = FALSE;
+
 	while (length > 0)
 	{
 		wStream sbuffer = { 0 };
@@ -641,6 +644,7 @@ BOOL gcc_read_client_data_blocks(wStream* s, rdpMcs* mcs, UINT16 length)
 
 			case 0xC009:
 			case CS_MULTITRANSPORT:
+				gotMultitransport = TRUE;
 				if (!gcc_read_client_multitransport_channel_data(sub, mcs))
 					return FALSE;
 
@@ -676,6 +680,14 @@ BOOL gcc_read_client_data_blocks(wStream* s, rdpMcs* mcs, UINT16 length)
 			length -= blockLength;
 	}
 
+	if (!gotMultitransport)
+	{
+		rdpSettings* settings = mcs_get_settings(mcs);
+		if (!freerdp_settings_set_bool(settings, FreeRDP_SupportMultitransport, FALSE))
+			return FALSE;
+		if (!freerdp_settings_set_uint32(settings, FreeRDP_MultitransportFlags, 0))
+			return FALSE;
+	}
 	return TRUE;
 }
 
@@ -732,49 +744,49 @@ char* gcc_block_type_string(UINT16 type, char* buffer, size_t size)
 	switch (type)
 	{
 		case CS_CORE:
-			_snprintf(buffer, size, "CS_CORE [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_CORE [0x%04" PRIx16 "]", type);
 			break;
 		case CS_SECURITY:
-			_snprintf(buffer, size, "CS_SECURITY [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_SECURITY [0x%04" PRIx16 "]", type);
 			break;
 		case CS_NET:
-			_snprintf(buffer, size, "CS_NET [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_NET [0x%04" PRIx16 "]", type);
 			break;
 		case CS_CLUSTER:
-			_snprintf(buffer, size, "CS_CLUSTER [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_CLUSTER [0x%04" PRIx16 "]", type);
 			break;
 		case CS_MONITOR:
-			_snprintf(buffer, size, "CS_MONITOR [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_MONITOR [0x%04" PRIx16 "]", type);
 			break;
 		case CS_MCS_MSGCHANNEL:
-			_snprintf(buffer, size, "CS_MONITOR [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_MONITOR [0x%04" PRIx16 "]", type);
 			break;
 		case CS_MONITOR_EX:
-			_snprintf(buffer, size, "CS_MONITOR_EX [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_MONITOR_EX [0x%04" PRIx16 "]", type);
 			break;
 		case CS_UNUSED1:
-			_snprintf(buffer, size, "CS_UNUSED1 [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_UNUSED1 [0x%04" PRIx16 "]", type);
 			break;
 		case CS_MULTITRANSPORT:
-			_snprintf(buffer, size, "CS_MONITOR_EX [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "CS_MONITOR_EX [0x%04" PRIx16 "]", type);
 			break;
 		case SC_CORE:
-			_snprintf(buffer, size, "SC_CORE [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "SC_CORE [0x%04" PRIx16 "]", type);
 			break;
 		case SC_SECURITY:
-			_snprintf(buffer, size, "SC_SECURITY [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "SC_SECURITY [0x%04" PRIx16 "]", type);
 			break;
 		case SC_NET:
-			_snprintf(buffer, size, "SC_NET [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "SC_NET [0x%04" PRIx16 "]", type);
 			break;
 		case SC_MCS_MSGCHANNEL:
-			_snprintf(buffer, size, "SC_MCS_MSGCHANNEL [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "SC_MCS_MSGCHANNEL [0x%04" PRIx16 "]", type);
 			break;
 		case SC_MULTITRANSPORT:
-			_snprintf(buffer, size, "SC_MULTITRANSPORT [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "SC_MULTITRANSPORT [0x%04" PRIx16 "]", type);
 			break;
 		default:
-			_snprintf(buffer, size, "UNKNOWN [0x%04" PRIx16 "]", type);
+			(void)_snprintf(buffer, size, "UNKNOWN [0x%04" PRIx16 "]", type);
 			break;
 	}
 	return buffer;
@@ -1375,14 +1387,10 @@ BOOL gcc_write_client_core_data(wStream* s, const rdpMcs* mcs)
 {
 	char buffer[2048] = { 0 };
 	char dbuffer[2048] = { 0 };
-	WCHAR* clientName = NULL;
-	size_t clientNameLength = 0;
 	BYTE connectionType = 0;
 	HIGH_COLOR_DEPTH highColorDepth = HIGH_COLOR_4BPP;
 
 	UINT16 earlyCapabilityFlags = 0;
-	WCHAR* clientDigProductId = NULL;
-	size_t clientDigProductIdLength = 0;
 	const rdpSettings* settings = mcs_get_const_settings(mcs);
 
 	WINPR_ASSERT(s);
@@ -1394,9 +1402,6 @@ BOOL gcc_write_client_core_data(wStream* s, const rdpMcs* mcs)
 
 	if (!gcc_write_user_data_header(s, CS_CORE, 234))
 		return FALSE;
-	clientName = ConvertUtf8ToWCharAlloc(settings->ClientHostname, &clientNameLength);
-	clientDigProductId =
-	    ConvertUtf8ToWCharAlloc(settings->ClientProductId, &clientDigProductIdLength);
 
 	Stream_Write_UINT32(s, settings->RdpVersion);    /* Version */
 	Stream_Write_UINT16(s, settings->DesktopWidth);  /* DesktopWidth */
@@ -1407,15 +1412,17 @@ BOOL gcc_write_client_core_data(wStream* s, const rdpMcs* mcs)
 	Stream_Write_UINT32(s, settings->KeyboardLayout); /* KeyboardLayout */
 	Stream_Write_UINT32(s, settings->ClientBuild);    /* ClientBuild */
 
-	/* clientName (32 bytes, null-terminated unicode, truncated to 15 characters) */
+	if (!Stream_EnsureRemainingCapacity(s, 32 + 12 + 64 + 8))
+		return FALSE;
 
+	/* clientName (32 bytes, null-terminated unicode, truncated to 15 characters) */
+	size_t clientNameLength = 0;
+	WCHAR* clientName = ConvertUtf8ToWCharAlloc(settings->ClientHostname, &clientNameLength);
 	if (clientNameLength >= 16)
 	{
 		clientNameLength = 16;
 		clientName[clientNameLength - 1] = 0;
 	}
-	if (!Stream_EnsureRemainingCapacity(s, 32 + 12 + 64 + 8))
-		return FALSE;
 
 	Stream_Write(s, clientName, (clientNameLength * 2));
 	Stream_Zero(s, 32 - (clientNameLength * 2));
@@ -1443,15 +1450,19 @@ BOOL gcc_write_client_core_data(wStream* s, const rdpMcs* mcs)
 	Stream_Write_UINT16(s, SupportedColorDepths); /* supportedColorDepths */
 	Stream_Write_UINT16(s, earlyCapabilityFlags); /* earlyCapabilityFlags */
 
+	if (!Stream_EnsureRemainingCapacity(s, 64 + 24))
+		return FALSE;
+
 	/* clientDigProductId (64 bytes, null-terminated unicode, truncated to 31 characters) */
+	size_t clientDigProductIdLength = 0;
+	WCHAR* clientDigProductId =
+	    ConvertUtf8ToWCharAlloc(settings->ClientProductId, &clientDigProductIdLength);
 	if (clientDigProductIdLength >= 32)
 	{
 		clientDigProductIdLength = 32;
 		clientDigProductId[clientDigProductIdLength - 1] = 0;
 	}
 
-	if (!Stream_EnsureRemainingCapacity(s, 64 + 24))
-		return FALSE;
 	Stream_Write(s, clientDigProductId, (clientDigProductIdLength * 2));
 	Stream_Zero(s, 64 - (clientDigProductIdLength * 2));
 	free(clientDigProductId);
@@ -1704,7 +1715,13 @@ BOOL gcc_read_server_security_data(wStream* s, rdpMcs* mcs)
 	Stream_Read_UINT32(s, settings->ServerCertificateLength); /* serverCertLen */
 
 	if ((settings->ServerRandomLength == 0) || (settings->ServerCertificateLength == 0))
+	{
+		WLog_ERR(TAG,
+		         "Invalid ServerRandom (length=%" PRIu32 ") or ServerCertificate (length=%" PRIu32
+		         ")",
+		         settings->ServerRandomLength, settings->ServerCertificateLength);
 		return FALSE;
+	}
 
 	if (!Stream_CheckAndLogRequiredLength(TAG, s, settings->ServerRandomLength))
 		return FALSE;
@@ -1759,6 +1776,9 @@ static BOOL gcc_update_server_random(rdpSettings* settings)
  */
 BOOL gcc_write_server_security_data(wStream* s, rdpMcs* mcs)
 {
+	if (!gcc_update_server_random(mcs_get_settings(mcs)))
+		return FALSE;
+
 	const rdpSettings* settings = mcs_get_const_settings(mcs);
 
 	WINPR_ASSERT(s);
@@ -1773,8 +1793,6 @@ BOOL gcc_write_server_security_data(wStream* s, rdpMcs* mcs)
 
 	if (settings->EncryptionMethods == ENCRYPTION_METHOD_NONE)
 		return TRUE;
-	if (!gcc_update_server_random(settings))
-		return FALSE;
 
 	if (!Stream_EnsureRemainingCapacity(s, sizeof(UINT32) + settings->ServerRandomLength))
 		return FALSE;
@@ -1913,6 +1931,13 @@ BOOL gcc_read_server_network_data(wStream* s, rdpMcs* mcs)
 	if (!Stream_CheckAndLogRequiredLengthOfSize(TAG, s, channelCount, 2ull))
 		return FALSE;
 
+	if (mcs->channelMaxCount < parsedChannelCount)
+	{
+		WLog_ERR(TAG, "requested %" PRIu32 " channels > channelMaxCount %" PRIu16,
+		         mcs->channelCount, mcs->channelMaxCount);
+		return FALSE;
+	}
+
 	for (UINT32 i = 0; i < parsedChannelCount; i++)
 	{
 		rdpMcsChannel* channel = &mcs->channels[i];
