@@ -284,14 +284,12 @@ static BOOL check_no_proxy(rdpSettings* settings, const char* no_proxy)
 
 void proxy_read_environment(rdpSettings* settings, char* envname)
 {
-	DWORD envlen = 0;
-	char* env = NULL;
-	envlen = GetEnvironmentVariableA(envname, NULL, 0);
+	const DWORD envlen = GetEnvironmentVariableA(envname, NULL, 0);
 
-	if (!envlen)
+	if (!envlen || (envlen <= 1))
 		return;
 
-	env = calloc(1, envlen);
+	char* env = calloc(1, envlen);
 
 	if (!env)
 	{
@@ -308,7 +306,8 @@ void proxy_read_environment(rdpSettings* settings, char* envname)
 				WLog_INFO(TAG, "deactivating proxy: %s [%s=%s]",
 				          freerdp_settings_get_string(settings, FreeRDP_ServerHostname), envname,
 				          env);
-				freerdp_settings_set_uint32(settings, FreeRDP_ProxyType, PROXY_TYPE_NONE);
+				if (!freerdp_settings_set_uint32(settings, FreeRDP_ProxyType, PROXY_TYPE_NONE))
+					WLog_WARN(TAG, "failed to set FreeRDP_ProxyType=PROXY_TYPE_NONE");
 			}
 		}
 		else
@@ -569,7 +568,7 @@ static BOOL http_proxy_connect(BIO* bufferedBio, const char* proxyUsername,
 				const char basic[] = CRLF "Proxy-Authorization: Basic ";
 				char* base64 = NULL;
 
-				sprintf_s(creds, size, "%s:%s", proxyUsername, proxyPassword);
+				(void)sprintf_s(creds, size, "%s:%s", proxyUsername, proxyPassword);
 				base64 = crypto_base64_encode((const BYTE*)creds, size - 1);
 
 				if (!base64 || !Stream_EnsureRemainingCapacity(s, strlen(basic) + strlen(base64)))
@@ -653,7 +652,7 @@ static BOOL http_proxy_connect(BIO* bufferedBio, const char* proxyUsername,
 
 	recv_buf[7] = 'X';
 
-	if (strncmp(recv_buf, "HTTP/1.X 200", 12))
+	if (strncmp(recv_buf, "HTTP/1.X 200", 12) != 0)
 		goto fail;
 
 	rc = TRUE;
