@@ -261,7 +261,7 @@ BOOL rdp_read_share_control_header(rdpRdp* rdp, wStream* s, UINT16* tpktLength,
 		WLog_Print(rdp->log, WLOG_DEBUG,
 		           "[Flow control PDU] type=%s, tpktLength=%" PRIuz ", remainingLength=%" PRIuz,
 		           pdu_type_to_str(*type, buffer, sizeof(buffer)), tpktLength ? *tpktLength : 0,
-		           *remainingLength);
+		           remainingLength ? *remainingLength : 0);
 		return TRUE;
 	}
 
@@ -692,6 +692,8 @@ static BOOL rdp_security_stream_out(rdpRdp* rdp, wStream* s, int length, UINT32
 {
 	BOOL status = 0;
 	WINPR_ASSERT(rdp);
+	WINPR_ASSERT(length >= 0);
+
 	sec_flags |= rdp->sec_flags;
 	*pad = 0;
 
@@ -709,7 +711,12 @@ static BOOL rdp_security_stream_out(rdpRdp* rdp, wStream* s, int length, UINT32
 			if (rdp->settings->EncryptionMethods == ENCRYPTION_METHOD_FIPS)
 			{
 				BYTE* data = Stream_PointerAs(s, BYTE) + 12;
-				length = length - (data - Stream_Buffer(s));
+				const size_t size = (data - Stream_Buffer(s));
+				if (size > length)
+					goto unlock;
+
+				length -= (int)size;
+
 				Stream_Write_UINT16(s, 0x10); /* length */
 				Stream_Write_UINT8(s, 0x1);   /* TSFIPS_VERSION 1*/
 				/* handle padding */
@@ -1084,12 +1091,19 @@ state_run_t rdp_recv_data_pdu(rdpRdp* rdp, wStream* s)
 
 	if (compressedType & PACKET_COMPRESSED)
 	{
+		if (compressedLength < 18)
+		{
+			WLog_Print(rdp->log, WLOG_ERROR,
+			           "bulk_decompress: not enough bytes for compressedLength %" PRIu16 "",
+			           compressedLength);
+			return STATE_RUN_FAILED;
+		}
+
 		UINT32 DstSize = 0;
 		const BYTE* pDstData = NULL;
 		UINT16 SrcSize = compressedLength - 18;
 
-		if ((compressedLength < 18) ||
-		    (!Stream_CheckAndLogRequiredLengthWLog(rdp->log, s, SrcSize)))
+		if (!Stream_CheckAndLogRequiredLengthWLog(rdp->log, s, SrcSize))
 		{
 			WLog_Print(rdp->log, WLOG_ERROR,
 			           "bulk_decompress: not enough bytes for compressedLength %" PRIu16 "",
@@ -1559,7 +1573,7 @@ const char* pdu_type_to_str(UINT16 pduType, char* buffer, size_t length)
 	winpr_str_append(str, buffer, length, "");
 	{
 		char msg[32] = { 0 };
-		_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", pduType);
+		(void)_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", pduType);
 		winpr_str_append(msg, buffer, length, "");
 	}
 	return buffer;
@@ -2237,7 +2251,7 @@ rdpRdp* rdp_new(rdpContext* context)
 	rdp->log = WLog_Get(RDP_TAG);
 	WINPR_ASSERT(rdp->log);
 
-	_snprintf(rdp->log_context, sizeof(rdp->log_context), "%p", (void*)context);
+	(void)_snprintf(rdp->log_context, sizeof(rdp->log_context), "%p", (void*)context);
 	WLog_SetContext(rdp->log, NULL, rdp->log_context);
 
 	InitializeCriticalSection(&rdp->critical);
@@ -2259,7 +2273,7 @@ rdpRdp* rdp_new(rdpContext* context)
 
 	/* Keep a backup copy of settings for later comparisons */
 	if (!rdp_set_backup_settings(rdp))
-		return FALSE;
+		goto fail;
 
 	rdp->settings->instance = context->instance;
 
@@ -2574,7 +2588,7 @@ const char* rdp_finalize_flags_to_str(UINT32 flags, char* buffer, size_t size)
 		winpr_str_append("UNKNOWN_FLAG", buffer, size, "|");
 	if (flags == 0)
 		winpr_str_append("NO_FLAG_SET", buffer, size, "|");
-	_snprintf(number, sizeof(number), " [0x%08" PRIx32 "]", flags);
+	(void)_snprintf(number, sizeof(number), " [0x%08" PRIx32 "]", flags);
 	winpr_str_append(number, buffer, size, "");
 	return buffer;
 }
@@ -2680,7 +2694,7 @@ const char* rdp_security_flag_string(UINT32 securityFlags, char* buffer, size_t
 	{
 		char msg[32] = { 0 };
 
-		_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", securityFlags);
+		(void)_snprintf(msg, sizeof(msg), "[0x%08" PRIx32 "]", securityFlags);
 		winpr_str_append(msg, buffer, size, "");
 	}
 	return buffer;
