@@ -68,7 +68,7 @@ static void delete_file(char* path)
 					break;
 			}
 
-			fclose(fp);
+			(void)fclose(fp);
 		}
 	}
 
@@ -138,11 +138,15 @@ static BOOL add_cert_to_list(SmartcardCertInfo*** certInfoList, size_t* count,
 		}
 	}
 
-	curInfoList = realloc(curInfoList, sizeof(SmartcardCertInfo*) * (curCount + 1));
-	if (!curInfoList)
 	{
-		WLog_ERR(TAG, "unable to reallocate certs");
-		return FALSE;
+		SmartcardCertInfo** tmpInfoList =
+		    realloc(curInfoList, sizeof(SmartcardCertInfo*) * (curCount + 1));
+		if (!tmpInfoList)
+		{
+			WLog_ERR(TAG, "unable to reallocate certs");
+			return FALSE;
+		}
+		curInfoList = tmpInfoList;
 	}
 
 	curInfoList[curCount++] = certInfo;
@@ -222,11 +226,14 @@ static BOOL set_info_certificate(SmartcardCertInfo* cert, BYTE* certBytes, DWORD
 		return FALSE;
 	}
 
-	if (userFilter && cert->userHint && strcmp(cert->userHint, userFilter) != 0)
+	if (userFilter && (!cert->upn || (strcmp(cert->upn, userFilter) != 0)))
 	{
-		WLog_DBG(TAG, "discarding non matching cert by user %s@%s", cert->userHint,
-		         cert->domainHint);
-		return FALSE;
+		if (cert->userHint && strcmp(cert->userHint, userFilter) != 0)
+		{
+			WLog_DBG(TAG, "discarding non matching cert by user %s@%s", cert->userHint,
+			         cert->domainHint);
+			return FALSE;
+		}
 	}
 
 	if (domainFilter && cert->domainHint && strcmp(cert->domainHint, domainFilter) != 0)
@@ -240,13 +247,12 @@ static BOOL set_info_certificate(SmartcardCertInfo* cert, BYTE* certBytes, DWORD
 }
 
 #ifndef _WIN32
-static BOOL build_pkinit_args(const rdpSettings* settings, SmartcardCertInfo* scCert)
+static BOOL build_pkinit_args(NCRYPT_PROV_HANDLE provider, SmartcardCertInfo* scCert)
 {
 	/* pkinit args only under windows
 	 * 		PKCS11:module_name=opensc-pkcs11.so
 	 */
-	const char* Pkcs11Module = freerdp_settings_get_string(settings, FreeRDP_Pkcs11Module);
-	const char* pkModule = Pkcs11Module ? Pkcs11Module : "opensc-pkcs11.so";
+	const char* pkModule = winpr_NCryptGetModulePath(provider);
 	size_t size = 0;
 
 	if (winpr_asprintf(&scCert->pkinitArgs, &size, "PKCS11:module_name=%s:slotid=%" PRIu16,
@@ -512,7 +518,7 @@ static BOOL list_provider_keys(const rdpSettings* settings, NCRYPT_PROV_HANDLE p
 			goto endofloop;
 
 #ifndef _WIN32
-		if (!build_pkinit_args(settings, cert))
+		if (!build_pkinit_args(provider, cert))
 		{
 			WLog_ERR(TAG, "error build pkinit args");
 			goto endofloop;
@@ -575,7 +581,7 @@ static BOOL smartcard_hw_enumerateCerts(const rdpSettings* settings, LPCWSTR csp
 		if (!scopeStr)
 			goto out;
 
-		_snprintf(scopeStr, readerSz + 5, "\\\\.\\%s\\", reader);
+		(void)_snprintf(scopeStr, readerSz + 5, "\\\\.\\%s\\", reader);
 		scope = ConvertUtf8NToWCharAlloc(scopeStr, readerSz + 5, NULL);
 		free(scopeStr);
 
@@ -662,7 +668,7 @@ static BOOL smartcard_hw_enumerateCerts(const rdpSettings* settings, LPCWSTR csp
 
 			if (ConvertWCharToUtf8(name->pszName, providerNameStr, ARRAYSIZE(providerNameStr)) < 0)
 			{
-				_snprintf(providerNameStr, sizeof(providerNameStr), "<unknown>");
+				(void)_snprintf(providerNameStr, sizeof(providerNameStr), "<unknown>");
 				WLog_ERR(TAG, "unable to convert provider name to char*, will show it as '%s'",
 				         providerNameStr);
 			}
