@@ -694,7 +694,7 @@ char* freerdp_tcp_address_to_string(const struct sockaddr_storage* addr, BOOL* p
 			break;
 
 		case AF_UNIX:
-			sprintf_s(ipAddress, ARRAYSIZE(ipAddress), "127.0.0.1");
+			(void)sprintf_s(ipAddress, ARRAYSIZE(ipAddress), "127.0.0.1");
 			break;
 
 		default:
@@ -779,7 +779,7 @@ struct addrinfo* freerdp_tcp_resolve_host(const char* hostname, int port, int ai
 
 	if (port >= 0)
 	{
-		sprintf_s(port_str, sizeof(port_str) - 1, "%d", port);
+		(void)sprintf_s(port_str, sizeof(port_str) - 1, "%d", port);
 		service = port_str;
 	}
 
@@ -895,7 +895,7 @@ static void peer_free(t_peer* peer)
 	peer->s = INVALID_SOCKET;
 }
 
-static int freerdp_tcp_connect_multi(rdpContext* context, char** hostnames, UINT32* ports,
+static int freerdp_tcp_connect_multi(rdpContext* context, char** hostnames, const UINT32* ports,
                                      UINT32 count, UINT16 port, UINT32 timeout)
 {
 	UINT32 sindex = count;
@@ -1071,6 +1071,54 @@ int freerdp_tcp_connect(rdpContext* context, const char* hostname, int port, DWO
 	return transport_tcp_connect(context->rdp->transport, hostname, port, timeout);
 }
 
+static int get_next_addrinfo(rdpContext* context, struct addrinfo* input, struct addrinfo** result,
+                             UINT32 errorCode)
+{
+	WINPR_ASSERT(context);
+	WINPR_ASSERT(result);
+
+	struct addrinfo* addr = input;
+	if (!addr)
+		goto fail;
+
+	if (freerdp_settings_get_bool(context->settings, FreeRDP_PreferIPv6OverIPv4))
+	{
+		while (addr && (addr->ai_family != AF_INET6))
+			addr = addr->ai_next;
+		if (!addr)
+			addr = input;
+	}
+
+	/* We want to force IPvX, abort if not detected */
+	const UINT32 IPvX = freerdp_settings_get_uint32(context->settings, FreeRDP_ForceIPvX);
+	switch (IPvX)
+	{
+		case 4:
+		case 6:
+		{
+			const int family = (IPvX == 4) ? AF_INET : AF_INET6;
+			while (addr && (addr->ai_family != family))
+				addr = addr->ai_next;
+			if (!addr)
+				goto fail;
+		}
+		break;
+		default:
+			break;
+	}
+
+	if (!addr)
+		goto fail;
+
+	*result = addr;
+	return 0;
+
+fail:
+	freerdp_set_last_error_if_not(context, errorCode);
+	freeaddrinfo(input);
+	return -1;
+}
+
 int freerdp_tcp_default_connect(rdpContext* context, rdpSettings* settings, const char* hostname,
                                 int port, DWORD timeout)
 {
@@ -1181,52 +1229,22 @@ int freerdp_tcp_default_connect(rdpContext* context, rdpSettings* settings, cons
 			 * If PreferIPv6OverIPv4 = TRUE we force to IPv6 if there
 			 * is such an address available, but fall back to first if not found
 			 */
-			addr = result;
-			if (freerdp_settings_get_bool(settings, FreeRDP_PreferIPv6OverIPv4))
-			{
-				while (addr && (addr->ai_family != AF_INET6))
-					addr = addr->ai_next;
-				if (!addr)
-					addr = result;
-			}
+			const int rc =
+			    get_next_addrinfo(context, result, &addr, FREERDP_ERROR_DNS_NAME_NOT_FOUND);
+			if (rc < 0)
+				return rc;
 
-			/* We want to force IPvX, abort if not detected */
-			const UINT32 IPvX = freerdp_settings_get_uint32(settings, FreeRDP_ForceIPvX);
-			switch (IPvX)
+			do
 			{
-				case 4:
-				case 6:
+				sockfd = socket(addr->ai_family, addr->ai_socktype, addr->ai_protocol);
+				if (sockfd < 0)
 				{
-					const int family = (IPvX == 4) ? AF_INET : AF_INET6;
-					while (addr && (addr->ai_family != family))
-						addr = addr->ai_next;
-					if (!addr)
-					{
-						freerdp_set_last_error_if_not(context, FREERDP_ERROR_DNS_NAME_NOT_FOUND);
-						freeaddrinfo(result);
-						return -1;
-					}
+					const int lrc = get_next_addrinfo(context, addr->ai_next, &addr,
+					                                  FREERDP_ERROR_CONNECT_FAILED);
+					if (lrc < 0)
+						return lrc;
 				}
-				break;
-				default:
-					break;
-			}
-
-			if (!addr)
-			{
-				freerdp_set_last_error_if_not(context, FREERDP_ERROR_DNS_NAME_NOT_FOUND);
-				freeaddrinfo(result);
-				return -1;
-			}
-			sockfd = socket(addr->ai_family, addr->ai_socktype, addr->ai_protocol);
-
-			if (sockfd < 0)
-			{
-				freerdp_set_last_error_if_not(context, FREERDP_ERROR_CONNECT_FAILED);
-
-				freeaddrinfo(result);
-				return -1;
-			}
+			} while (sockfd < 0);
 
 			if ((peerAddress = freerdp_tcp_address_to_string(
 			         (const struct sockaddr_storage*)addr->ai_addr, NULL)) != NULL)
