@@ -9,14 +9,15 @@
 
 static BOOL log_result(BOOL value, const char* fkt)
 {
-	fprintf(stderr, "TestSettings [%s] returned %s\n", fkt, value ? "TRUE" : "FALSE");
+	(void)fprintf(stderr, "TestSettings [%s] returned %s\n", fkt, value ? "TRUE" : "FALSE");
 	return value;
 }
 
 static BOOL compare(const ADDIN_ARGV* got, const ADDIN_ARGV* expect)
 {
-	int x;
 	BOOL rc = TRUE;
+	if (!got && !expect)
+		return FALSE;
 	if (!got && expect)
 		return FALSE;
 	if (got && !expect)
@@ -24,7 +25,7 @@ static BOOL compare(const ADDIN_ARGV* got, const ADDIN_ARGV* expect)
 	if (got->argc != expect->argc)
 		return FALSE;
 
-	for (x = 0; x < expect->argc; x++)
+	for (int x = 0; x < expect->argc; x++)
 	{
 		if (strcmp(got->argv[x], expect->argv[x]) != 0)
 			rc = FALSE;
@@ -35,16 +36,16 @@ static BOOL compare(const ADDIN_ARGV* got, const ADDIN_ARGV* expect)
 static BOOL test_dyn_channels(void)
 {
 	BOOL rc = FALSE;
-	BOOL test;
-	UINT32 u32;
+	BOOL test = 0;
+	UINT32 u32 = 0;
 	rdpSettings* settings = freerdp_settings_new(0);
 	const char* argv1[] = { "foobar" };
 	ADDIN_ARGV* args1 = NULL;
-	const ADDIN_ARGV* cmp1;
+	const ADDIN_ARGV* cmp1 = NULL;
 	const char* argv2[] = { "gaga", "abba", "foo" };
 	ADDIN_ARGV* args2 = NULL;
-	const ADDIN_ARGV* cmp2;
-	const ADDIN_ARGV* got;
+	const ADDIN_ARGV* cmp2 = NULL;
+	const ADDIN_ARGV* got = NULL;
 
 	if (!settings)
 		goto fail;
@@ -135,16 +136,16 @@ fail:
 static BOOL test_static_channels(void)
 {
 	BOOL rc = FALSE;
-	BOOL test;
-	UINT32 u32;
+	BOOL test = 0;
+	UINT32 u32 = 0;
 	rdpSettings* settings = freerdp_settings_new(0);
 	const char* argv1[] = { "foobar" };
 	ADDIN_ARGV* args1 = NULL;
-	const ADDIN_ARGV* cmp1;
+	const ADDIN_ARGV* cmp1 = NULL;
 	const char* argv2[] = { "gaga", "abba", "foo" };
 	ADDIN_ARGV* args2 = NULL;
-	const ADDIN_ARGV* cmp2;
-	const ADDIN_ARGV* got;
+	const ADDIN_ARGV* cmp2 = NULL;
+	const ADDIN_ARGV* got = NULL;
 
 	if (!settings)
 		goto fail;
@@ -261,7 +262,7 @@ fail:
 static BOOL test_helpers(void)
 {
 	BOOL rc = FALSE;
-	UINT32 flags;
+	UINT32 flags = 0;
 	rdpSettings* settings = freerdp_settings_new(0);
 	if (!settings)
 		goto fail;
@@ -304,19 +305,19 @@ static BOOL format_uint(char* buffer, size_t size, UINT64 value, UINT16 intType,
 	switch (intType)
 	{
 		case 0:
-			_snprintf(buffer, size, "%" PRIu64, lvalue);
+			(void)_snprintf(buffer, size, "%" PRIu64, lvalue);
 			return TRUE;
 		case 1:
-			_snprintf(buffer, size, "0x%" PRIx64, lvalue);
+			(void)_snprintf(buffer, size, "0x%" PRIx64, lvalue);
 			return TRUE;
 		case 2:
 			if (max < UINT64_MAX)
-				_snprintf(buffer, size, "%" PRIu64, max + 1);
+				(void)_snprintf(buffer, size, "%" PRIu64, max + 1);
 			else
-				_snprintf(buffer, size, "too large a number");
+				(void)_snprintf(buffer, size, "too large a number");
 			return FALSE;
 		default:
-			_snprintf(buffer, size, "not a number value");
+			(void)_snprintf(buffer, size, "not a number value");
 			return FALSE;
 	}
 }
@@ -326,16 +327,16 @@ static BOOL print_negative(char* buffer, size_t size, INT64 value, INT64 min)
 	switch (min)
 	{
 		case INT16_MIN:
-			_snprintf(buffer, size, "%" PRId16, (INT16)value);
+			(void)_snprintf(buffer, size, "%" PRId16, (INT16)value);
 			return FALSE;
 		case INT32_MIN:
-			_snprintf(buffer, size, "%" PRId32, (INT32)value);
+			(void)_snprintf(buffer, size, "%" PRId32, (INT32)value);
 			return FALSE;
 		case INT64_MIN:
-			_snprintf(buffer, size, "%" PRId64, (INT64)value);
+			(void)_snprintf(buffer, size, "%" PRId64, value);
 			return FALSE;
 		default:
-			_snprintf(buffer, size, "too small a number");
+			(void)_snprintf(buffer, size, "too small a number");
 			return FALSE;
 	}
 }
@@ -344,23 +345,23 @@ static BOOL print_xpositive(char* buffer, size_t size, INT64 value, INT64 max)
 {
 	if (value < 0)
 	{
-		_snprintf(buffer, size, "%" PRId64, value);
+		(void)_snprintf(buffer, size, "%" PRId64, value);
 		return TRUE;
 	}
 
 	switch (max)
 	{
 		case INT16_MAX:
-			_snprintf(buffer, size, "%" PRIx16, (INT16)value);
+			(void)_snprintf(buffer, size, "%" PRIx16, (INT16)value);
 			return FALSE;
 		case INT32_MAX:
-			_snprintf(buffer, size, "%" PRIx32, (INT32)value);
+			(void)_snprintf(buffer, size, "%" PRIx32, (INT32)value);
 			return FALSE;
 		case INT64_MAX:
-			_snprintf(buffer, size, "%" PRIx64, (INT64)value);
+			(void)_snprintf(buffer, size, "%" PRIx64, value);
 			return FALSE;
 		default:
-			_snprintf(buffer, size, "too small a number");
+			(void)_snprintf(buffer, size, "too small a number");
 			return FALSE;
 	}
 }
@@ -373,25 +374,25 @@ static BOOL format_int(char* buffer, size_t size, INT64 value, UINT16 intType, I
 	switch (intType)
 	{
 		case 0:
-			_snprintf(buffer, size, "%" PRId64, lvalue);
+			(void)_snprintf(buffer, size, "%" PRId64, lvalue);
 			return TRUE;
 		case 1:
 			print_xpositive(buffer, size, lvalue, max);
 			return TRUE;
 		case 2:
 			if (max < INT64_MAX)
-				_snprintf(buffer, size, "%" PRId64, max + 1);
+				(void)_snprintf(buffer, size, "%" PRId64, max + 1);
 			else
-				_snprintf(buffer, size, "too large a number");
+				(void)_snprintf(buffer, size, "too large a number");
 			return FALSE;
 		case 3:
 			if (min < INT64_MIN)
 				print_negative(buffer, size, min - 1, INT64_MIN);
 			else
-				_snprintf(buffer, size, "too small a number");
+				(void)_snprintf(buffer, size, "too small a number");
 			return FALSE;
 		default:
-			_snprintf(buffer, size, "not a number value");
+			(void)_snprintf(buffer, size, "not a number value");
 			return FALSE;
 	}
 }
@@ -402,37 +403,37 @@ static BOOL format_bool(char* buffer, size_t size, UINT16 intType)
 	switch (intType)
 	{
 		case 0:
-			_snprintf(buffer, size, "FALSE");
+			(void)_snprintf(buffer, size, "FALSE");
 			return TRUE;
 		case 1:
-			_snprintf(buffer, size, "FaLsE");
+			(void)_snprintf(buffer, size, "FaLsE");
 			return TRUE;
 		case 2:
-			_snprintf(buffer, size, "False");
+			(void)_snprintf(buffer, size, "False");
 			return TRUE;
 		case 3:
-			_snprintf(buffer, size, "false");
+			(void)_snprintf(buffer, size, "false");
 			return TRUE;
 		case 4:
-			_snprintf(buffer, size, "falseentry");
+			(void)_snprintf(buffer, size, "falseentry");
 			return FALSE;
 		case 5:
-			_snprintf(buffer, size, "TRUE");
+			(void)_snprintf(buffer, size, "TRUE");
 			return TRUE;
 		case 6:
-			_snprintf(buffer, size, "TrUe");
+			(void)_snprintf(buffer, size, "TrUe");
 			return TRUE;
 		case 7:
-			_snprintf(buffer, size, "True");
+			(void)_snprintf(buffer, size, "True");
 			return TRUE;
 		case 8:
-			_snprintf(buffer, size, "true");
+			(void)_snprintf(buffer, size, "true");
 			return TRUE;
 		case 9:
-			_snprintf(buffer, size, "someentry");
+			(void)_snprintf(buffer, size, "someentry");
 			return FALSE;
 		default:
-			_snprintf(buffer, size, "ok");
+			(void)_snprintf(buffer, size, "ok");
 			return FALSE;
 	}
 }
@@ -442,8 +443,9 @@ static BOOL check_key_helpers(size_t key, const char* stype)
 	int test_rounds = 100;
 	BOOL res = FALSE;
 	rdpSettings* settings = NULL;
-	SSIZE_T rc, tkey, type;
-	size_t x;
+	SSIZE_T rc = 0;
+	SSIZE_T tkey = 0;
+	SSIZE_T type = 0;
 	const size_t clear_keys[] = { FreeRDP_RdpServerCertificate,
 		                          FreeRDP_RdpServerRsaKey,
 		                          FreeRDP_RedirectionPassword,
@@ -514,7 +516,7 @@ static BOOL check_key_helpers(size_t key, const char* stype)
 		printf("[%s] freerdp_settings_new failed\n", stype);
 		goto fail;
 	}
-	for (x = 0; x < ARRAYSIZE(clear_keys); x++)
+	for (size_t x = 0; x < ARRAYSIZE(clear_keys); x++)
 	{
 		const size_t id = clear_keys[x];
 		const char* foo = freerdp_settings_get_name_for_key(id);
@@ -527,7 +529,8 @@ static BOOL check_key_helpers(size_t key, const char* stype)
 	do
 	{
 		UINT16 intEntryType = 0;
-		BOOL expect, have;
+		BOOL expect = 0;
+		BOOL have = 0;
 		char value[8192] = { 0 };
 		union
 		{
@@ -571,7 +574,7 @@ static BOOL check_key_helpers(size_t key, const char* stype)
 				break;
 			case RDP_SETTINGS_TYPE_STRING:
 				expect = TRUE;
-				_snprintf(value, sizeof(value), "somerandomstring");
+				(void)_snprintf(value, sizeof(value), "somerandomstring");
 				break;
 			case RDP_SETTINGS_TYPE_POINTER:
 				expect = FALSE;
@@ -717,7 +720,6 @@ fail:
 
 static BOOL check_device_type(void)
 {
-	size_t x;
 	struct test_entry
 	{
 		int expect;
@@ -765,7 +767,7 @@ static BOOL check_device_type(void)
 		{ -3, 0x123, 4, args },
 	};
 	BOOL rc = TRUE;
-	for (x = 0; x < ARRAYSIZE(tests); x++)
+	for (size_t x = 0; x < ARRAYSIZE(tests); x++)
 	{
 		const struct test_entry* cur = &tests[x];
 		int got = check_device_type_arg(cur->type, cur->count, cur->args);
@@ -777,7 +779,6 @@ static BOOL check_device_type(void)
 
 static BOOL check_offsets(rdpSettings* settings, size_t id, size_t min, size_t max, BOOL checkPtr)
 {
-	size_t x;
 	BOOL rc = TRUE;
 
 	WINPR_ASSERT(settings);
@@ -785,7 +786,7 @@ static BOOL check_offsets(rdpSettings* settings, size_t id, size_t min, size_t m
 	if (!freerdp_settings_get_pointer(settings, id))
 		return FALSE;
 
-	for (x = min; x < max; x++)
+	for (size_t x = min; x < max; x++)
 	{
 		const void* ptr = freerdp_settings_get_pointer_array(settings, id, x);
 		if (!ptr && checkPtr)
@@ -797,13 +798,11 @@ static BOOL check_offsets(rdpSettings* settings, size_t id, size_t min, size_t m
 static BOOL test_write_offsets(rdpSettings* settings, size_t id, size_t elementSize, size_t min,
                                size_t max)
 {
-	size_t x;
-
 	WINPR_ASSERT(settings);
 
-	for (x = min; x < max; x++)
+	for (size_t x = min; x < max; x++)
 	{
-		const void* ptr;
+		const void* ptr = NULL;
 		char buffer[8192] = { 0 };
 
 		winpr_RAND(buffer, sizeof(buffer));
@@ -829,7 +828,6 @@ static BOOL test_pointer_array(void)
 		size_t size;
 		size_t elementSize;
 	};
-	size_t x;
 	const struct pointer_test_case tests[] = {
 		{ FALSE, FALSE, FreeRDP_DeviceArray, FreeRDP_DeviceArraySize, 32, sizeof(RDPDR_DEVICE*) },
 		{ FALSE, FALSE, FreeRDP_StaticChannelArray, FreeRDP_StaticChannelArraySize, 32,
@@ -867,7 +865,7 @@ static BOOL test_pointer_array(void)
 	if (!settings)
 		goto fail;
 
-	for (x = 0; x < ARRAYSIZE(tests); x++)
+	for (size_t x = 0; x < ARRAYSIZE(tests); x++)
 	{
 		const struct pointer_test_case* cur = &tests[x];
 		if (!freerdp_settings_set_pointer_len(settings, cur->id, NULL, cur->size))
@@ -934,7 +932,6 @@ fail:
 int TestSettings(int argc, char* argv[])
 {
 	int rc = -1;
-	size_t x;
 	rdpSettings* settings = NULL;
 	rdpSettings* cloned = NULL;
 	rdpSettings* cloned2 = NULL;
@@ -974,7 +971,7 @@ int TestSettings(int argc, char* argv[])
 
 #if defined(have_bool_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(bool_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(bool_list_indices); x++)
 	{
 		const size_t key = bool_list_indices[x];
 		const char* name = freerdp_settings_get_name_for_key(key);
@@ -994,7 +991,7 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_int16_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(int16_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(int16_list_indices); x++)
 	{
 		const size_t key = int16_list_indices[x];
 		const char* name = freerdp_settings_get_name_for_key(key);
@@ -1014,7 +1011,7 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_uint16_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(uint16_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(uint16_list_indices); x++)
 	{
 		const size_t key = uint16_list_indices[x];
 		const char* name = freerdp_settings_get_name_for_key(key);
@@ -1034,7 +1031,7 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_uint32_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(uint32_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(uint32_list_indices); x++)
 	{
 		const size_t key = uint32_list_indices[x];
 		const char* name = freerdp_settings_get_name_for_key(key);
@@ -1054,7 +1051,7 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_int32_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(int32_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(int32_list_indices); x++)
 	{
 		const size_t key = int32_list_indices[x];
 		const char* name = freerdp_settings_get_name_for_key(key);
@@ -1074,7 +1071,7 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_uint64_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(uint64_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(uint64_list_indices); x++)
 	{
 		const size_t key = uint64_list_indices[x];
 		const char* name = freerdp_settings_get_name_for_key(key);
@@ -1094,7 +1091,7 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_int64_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(int64_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(int64_list_indices); x++)
 	{
 		const size_t key = int64_list_indices[x];
 		const char* name = freerdp_settings_get_name_for_key(key);
@@ -1114,11 +1111,11 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_string_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(string_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(string_list_indices); x++)
 	{
 		const size_t key = string_list_indices[x];
 		const char val[] = "test-string";
-		const char* res;
+		const char* res = NULL;
 		const char* name = freerdp_settings_get_name_for_key(key);
 		const char* oval = freerdp_settings_get_string(settings, key);
 		const char* cval = freerdp_settings_get_string(cloned, key);
@@ -1139,7 +1136,7 @@ int TestSettings(int argc, char* argv[])
 #endif
 #if defined(have_pointer_list_indices)
 
-	for (x = 0; x < ARRAYSIZE(pointer_list_indices); x++)
+	for (size_t x = 0; x < ARRAYSIZE(pointer_list_indices); x++)
 	{
 		const size_t key = pointer_list_indices[x];
 		const void* val = freerdp_settings_get_pointer(settings, key);
