@@ -377,8 +377,8 @@ fail:
 	return NULL;
 }
 
-static BOOL _update_read_pointer_color(wStream* s, POINTER_COLOR_UPDATE* pointer_color, BYTE xorBpp,
-                                       UINT32 flags)
+static BOOL s_update_read_pointer_color(wStream* s, POINTER_COLOR_UPDATE* pointer_color,
+                                        BYTE xorBpp, UINT32 flags)
 {
 	BYTE* newMask = NULL;
 	UINT32 scanlineSize = 0;
@@ -514,8 +514,8 @@ POINTER_COLOR_UPDATE* update_read_pointer_color(rdpUpdate* update, wStream* s, B
 	if (!pointer_color)
 		goto fail;
 
-	if (!_update_read_pointer_color(s, pointer_color, xorBpp,
-	                                update->context->settings->LargePointerFlag))
+	if (!s_update_read_pointer_color(s, pointer_color, xorBpp,
+	                                 update->context->settings->LargePointerFlag))
 		goto fail;
 
 	return pointer_color;
@@ -527,7 +527,7 @@ fail:
 	return NULL;
 }
 
-static BOOL _update_read_pointer_large(wStream* s, POINTER_LARGE_UPDATE* pointer)
+static BOOL s_update_read_pointer_large(wStream* s, POINTER_LARGE_UPDATE* pointer)
 {
 	BYTE* newMask = NULL;
 	UINT32 scanlineSize = 0;
@@ -644,7 +644,7 @@ POINTER_LARGE_UPDATE* update_read_pointer_large(rdpUpdate* update, wStream* s)
 	if (!pointer)
 		goto fail;
 
-	if (!_update_read_pointer_large(s, pointer))
+	if (!s_update_read_pointer_large(s, pointer))
 		goto fail;
 
 	return pointer;
@@ -676,8 +676,9 @@ POINTER_NEW_UPDATE* update_read_pointer_new(rdpUpdate* update, wStream* s)
 		goto fail;
 	}
 
-	if (!_update_read_pointer_color(s, &pointer_new->colorPtrAttr, pointer_new->xorBpp,
-	                                update->context->settings->LargePointerFlag)) /* colorPtrAttr */
+	if (!s_update_read_pointer_color(
+	        s, &pointer_new->colorPtrAttr, pointer_new->xorBpp,
+	        update->context->settings->LargePointerFlag)) /* colorPtrAttr */
 		goto fail;
 
 	return pointer_new;
@@ -984,7 +985,7 @@ void update_post_disconnect(rdpUpdate* update)
 	up->initialState = TRUE;
 }
 
-static BOOL _update_begin_paint(rdpContext* context)
+static BOOL s_update_begin_paint(rdpContext* context)
 {
 	wStream* s = NULL;
 	WINPR_ASSERT(context);
@@ -1011,7 +1012,7 @@ static BOOL _update_begin_paint(rdpContext* context)
 	return TRUE;
 }
 
-static BOOL _update_end_paint(rdpContext* context)
+static BOOL s_update_end_paint(rdpContext* context)
 {
 	wStream* s = NULL;
 	WINPR_ASSERT(context);
@@ -3128,8 +3129,8 @@ void update_register_server_callbacks(rdpUpdate* update)
 {
 	WINPR_ASSERT(update);
 
-	update->BeginPaint = _update_begin_paint;
-	update->EndPaint = _update_end_paint;
+	update->BeginPaint = s_update_begin_paint;
+	update->EndPaint = s_update_end_paint;
 	update->SetBounds = update_set_bounds;
 	update->Synchronize = update_send_synchronize;
 	update->DesktopResize = update_send_desktop_resize;
@@ -3335,9 +3336,12 @@ void rdp_update_unlock(rdpUpdate* update)
 
 BOOL update_begin_paint(rdpUpdate* update)
 {
+	rdp_update_internal* up = update_cast(update);
 	WINPR_ASSERT(update);
 	rdp_update_lock(update);
 
+	up->withinBeginEndPaint = TRUE;
+
 	WINPR_ASSERT(update->context);
 
 	BOOL rc = IFCALLRESULT(TRUE, update->BeginPaint, update->context);
@@ -3370,6 +3374,13 @@ BOOL update_end_paint(rdpUpdate* update)
 	IFCALLRET(update->EndPaint, rc, update->context);
 	if (!rc)
 		WLog_WARN(TAG, "EndPaint call failed");
+
+	rdp_update_internal* up = update_cast(update);
+
+	if (!up->withinBeginEndPaint)
+		return rc;
+	up->withinBeginEndPaint = FALSE;
+
 	rdp_update_unlock(update);
 	return rc;
 }
