@@ -624,7 +624,7 @@ static UINT gdi_SurfaceCommand_AVC420(rdpGdi* gdi, RdpgfxClientContext* context,
 	for (UINT32 i = 0; i < meta->numRegionRects; i++)
 	{
 		region16_union_rect(&(surface->invalidRegion), &(surface->invalidRegion),
-		                    (RECTANGLE_16*)&(meta->regionRects[i]));
+		                    &(meta->regionRects[i]));
 	}
 
 	status = IFCALLRESULT(CHANNEL_RC_OK, context->UpdateSurfaceArea, context, surface->surfaceId,
@@ -751,11 +751,11 @@ static BOOL gdi_apply_alpha(BYTE* data, UINT32 format, UINT32 stride, RECTANGLE_
 	const UINT32 bpp = FreeRDPGetBytesPerPixel(format);
 	WINPR_ASSERT(rect);
 
-	for (UINT32 y = rect->top; y < rect->bottom; y++)
+	for (size_t y = rect->top; y < rect->bottom; y++)
 	{
-		BYTE* line = &data[stride * y];
+		BYTE* line = &data[y * stride];
 
-		for (UINT32 x = first ? rect->left + startOffsetX : rect->left; x < rect->right; x++)
+		for (size_t x = first ? rect->left + startOffsetX : rect->left; x < rect->right; x++)
 		{
 			BYTE r = 0;
 			BYTE g = 0;
@@ -825,11 +825,11 @@ static UINT gdi_SurfaceCommand_Alpha(rdpGdi* gdi, RdpgfxClientContext* context,
 		if (!Stream_CheckAndLogRequiredLengthOfSize(TAG, s, cmd->height, cmd->width))
 			return ERROR_INVALID_DATA;
 
-		for (UINT32 y = cmd->top; y < cmd->top + cmd->height; y++)
+		for (size_t y = cmd->top; y < cmd->top + cmd->height; y++)
 		{
-			BYTE* line = &surface->data[surface->scanline * y];
+			BYTE* line = &surface->data[y * surface->scanline];
 
-			for (UINT32 x = cmd->left; x < cmd->left + cmd->width; x++)
+			for (size_t x = cmd->left; x < cmd->left + cmd->width; x++)
 			{
 				UINT32 color = 0;
 				BYTE r = 0;
@@ -1266,7 +1266,7 @@ static BOOL intersect_rect(const RECTANGLE_16* rect, const gdiGfxSurface* surfac
 static UINT gdi_SolidFill(RdpgfxClientContext* context, const RDPGFX_SOLID_FILL_PDU* solidFill)
 {
 	UINT status = ERROR_INTERNAL_ERROR;
-	BYTE a = 0;
+	BYTE a = 0xff;
 	RECTANGLE_16 invalidRect = { 0 };
 	rdpGdi* gdi = (rdpGdi*)context->custom;
 
@@ -1281,10 +1281,17 @@ static UINT gdi_SolidFill(RdpgfxClientContext* context, const RDPGFX_SOLID_FILL_
 	const BYTE b = solidFill->fillPixel.B;
 	const BYTE g = solidFill->fillPixel.G;
 	const BYTE r = solidFill->fillPixel.R;
+
+#if 0
+	/* [MS-RDPEGFX] 3.3.5.4 Processing an RDPGFX_SOLIDFILL_PDU message
+	 * https://learn.microsoft.com/en-us/windows/win32/gdi/binary-raster-operations
+	 *
+	 * this sounds like the alpha value is always ignored.
+	 */
 	if (FreeRDPColorHasAlpha(surface->format))
 		a = solidFill->fillPixel.XA;
-	else
-		a = 0xFF;
+#endif
+
 	const UINT32 color = FreeRDPGetColor(surface->format, r, g, b, a);
 
 	for (UINT16 index = 0; index < solidFill->fillRectCount; index++)
