@@ -36,31 +36,15 @@ int test_sizes[] = { 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096 };
 
 /* ------------------------------------------------------------------------- */
 
-#ifdef _WIN32
-float _delta_time(const struct timespec* t0, const struct timespec* t1)
+float measure_delta_time(UINT64 t0, UINT64 t1)
 {
-	return 0.0f;
+	INT64 diff = (INT64)(t1 - t0);
+	double retval = diff / 1000000000.0;
+	return (retval < 0.0) ? 0.0f : (float)retval;
 }
-#else
-float _delta_time(const struct timespec* t0, const struct timespec* t1)
-{
-	INT64 secs = (INT64)(t1->tv_sec) - (INT64)(t0->tv_sec);
-	long nsecs = t1->tv_nsec - t0->tv_nsec;
-	double retval = NAN;
-
-	if (nsecs < 0)
-	{
-		--secs;
-		nsecs += 1000000000;
-	}
-
-	retval = (double)secs + (double)nsecs / (double)1000000000.0;
-	return (retval < 0.0) ? 0.0 : (float)retval;
-}
-#endif
 
 /* ------------------------------------------------------------------------- */
-void _floatprint(float t, char* output)
+void measure_floatprint(float t, char* output)
 {
 	/* I don't want to link against -lm, so avoid log,exp,... */
 	float f = 10.0;
@@ -73,19 +57,19 @@ void _floatprint(float t, char* output)
 	i = ((int)(t / f + 0.5f)) * (int)f;
 
 	if (t < 0.0f)
-		sprintf(output, "%f", t);
+		(void)sprintf(output, "%f", t);
 	else if (i == 0)
-		sprintf(output, "%d", (int)(t + 0.5f));
+		(void)sprintf(output, "%d", (int)(t + 0.5f));
 	else if (t < 1e+3f)
-		sprintf(output, "%3d", i);
+		(void)sprintf(output, "%3d", i);
 	else if (t < 1e+6f)
-		sprintf(output, "%3d,%03d", i / 1000, i % 1000);
+		(void)sprintf(output, "%3d,%03d", i / 1000, i % 1000);
 	else if (t < 1e+9f)
-		sprintf(output, "%3d,%03d,000", i / 1000000, (i % 1000000) / 1000);
+		(void)sprintf(output, "%3d,%03d,000", i / 1000000, (i % 1000000) / 1000);
 	else if (t < 1e+12f)
-		sprintf(output, "%3d,%03d,000,000", i / 1000000000, (i % 1000000000) / 1000000);
+		(void)sprintf(output, "%3d,%03d,000,000", i / 1000000000, (i % 1000000000) / 1000000);
 	else
-		sprintf(output, "%f", t);
+		(void)sprintf(output, "%f", t);
 }
 
 void prim_test_setup(BOOL performance)
