@@ -126,12 +126,18 @@ BOOL freerdp_http_request(const char* url, const char* body, long* status_code,
 	{
 		blen = strlen(body);
 		if (winpr_asprintf(&headers, &size, post_header_fmt, path, hostname, blen) < 0)
+		{
+			free(hostname);
 			return FALSE;
+		}
 	}
 	else
 	{
 		if (winpr_asprintf(&headers, &size, get_header_fmt, path, hostname) < 0)
+		{
+			free(hostname);
 			return FALSE;
+		}
 	}
 
 	ssl_ctx = SSL_CTX_new(TLS_client_method());
@@ -381,6 +387,6 @@ const char* freerdp_http_status_string(long status)
 char* freerdp_http_status_string_format(long status, char* buffer, size_t size)
 {
 	const char* code = freerdp_http_status_string(status);
-	_snprintf(buffer, size, "%s [%ld]", code, status);
+	(void)_snprintf(buffer, size, "%s [%ld]", code, status);
 	return buffer;
 }
