@@ -84,10 +84,12 @@ struct s_scard_context_element
 	void (*fn_free)(void*);
 };
 
+static void context_free(void* arg);
+
 static LONG smartcard_EstablishContext_Call(scard_call_context* smartcard, wStream* out,
                                             SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	SCARDCONTEXT hContext = { 0 };
 	EstablishContext_Return ret = { 0 };
 	EstablishContext_Call* call = &operation->call.establishContext;
@@ -114,15 +116,10 @@ static LONG smartcard_EstablishContext_Call(scard_call_context* smartcard, wStre
 			}
 		}
 
-		if (!pContext)
-		{
-			WLog_ERR(TAG, "smartcard_context_new failed!");
-			return STATUS_NO_MEMORY;
-		}
-
 		if (!HashTable_Insert(smartcard->rgSCardContextList, key, (void*)pContext))
 		{
 			WLog_ERR(TAG, "ListDictionary_Add failed!");
+			context_free(pContext);
 			return STATUS_INTERNAL_ERROR;
 		}
 	}
@@ -131,6 +128,7 @@ static LONG smartcard_EstablishContext_Call(scard_call_context* smartcard, wStre
 		return scard_log_status_error(TAG, "SCardEstablishContext", status);
 	}
 
+	// NOLINTNEXTLINE(clang-analyzer-unix.Malloc): HashTable_Insert takes ownership of pContext
 	smartcard_scard_context_native_to_redir(&(ret.hContext), hContext);
 
 	status = smartcard_pack_establish_context_return(out, &ret);
@@ -181,7 +179,7 @@ static LONG smartcard_IsValidContext_Call(scard_call_context* smartcard, wStream
 static LONG smartcard_ListReaderGroupsA_Call(scard_call_context* smartcard, wStream* out,
                                              SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	ListReaderGroups_Return ret = { 0 };
 	LPSTR mszGroups = NULL;
 	DWORD cchGroups = 0;
@@ -193,6 +191,9 @@ static LONG smartcard_ListReaderGroupsA_Call(scard_call_context* smartcard, wStr
 	cchGroups = SCARD_AUTOALLOCATE;
 	ret.ReturnCode =
 	    wrap(smartcard, SCardListReaderGroupsA, operation->hContext, (LPSTR)&mszGroups, &cchGroups);
+	if (cchGroups == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
+
 	ret.msz = (BYTE*)mszGroups;
 	ret.cBytes = cchGroups;
 
@@ -210,7 +211,7 @@ static LONG smartcard_ListReaderGroupsA_Call(scard_call_context* smartcard, wStr
 static LONG smartcard_ListReaderGroupsW_Call(scard_call_context* smartcard, wStream* out,
                                              SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	ListReaderGroups_Return ret = { 0 };
 	LPWSTR mszGroups = NULL;
 	DWORD cchGroups = 0;
@@ -222,6 +223,9 @@ static LONG smartcard_ListReaderGroupsW_Call(scard_call_context* smartcard, wStr
 	cchGroups = SCARD_AUTOALLOCATE;
 	status = ret.ReturnCode = wrap(smartcard, SCardListReaderGroupsW, operation->hContext,
 	                               (LPWSTR)&mszGroups, &cchGroups);
+	if (cchGroups == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
+
 	ret.msz = (BYTE*)mszGroups;
 	ret.cBytes = cchGroups * sizeof(WCHAR);
 
@@ -262,7 +266,8 @@ static BOOL filter_match(wLinkedList* list, LPCSTR reader, size_t readerLen)
 
 static DWORD filter_device_by_name_a(wLinkedList* list, LPSTR* mszReaders, DWORD cchReaders)
 {
-	size_t rpos = 0, wpos = 0;
+	size_t rpos = 0;
+	size_t wpos = 0;
 
 	if (*mszReaders == NULL || LinkedList_Count(list) < 1)
 		return cchReaders;
@@ -298,7 +303,7 @@ static DWORD filter_device_by_name_a(wLinkedList* list, LPSTR* mszReaders, DWORD
 
 static DWORD filter_device_by_name_w(wLinkedList* list, LPWSTR* mszReaders, DWORD cchReaders)
 {
-	DWORD rc;
+	DWORD rc = 0;
 	LPSTR readers = NULL;
 
 	if (LinkedList_Count(list) < 1)
@@ -327,11 +332,11 @@ static DWORD filter_device_by_name_w(wLinkedList* list, LPWSTR* mszReaders, DWOR
 static LONG smartcard_ListReadersA_Call(scard_call_context* smartcard, wStream* out,
                                         SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	ListReaders_Return ret = { 0 };
 	LPSTR mszReaders = NULL;
 	DWORD cchReaders = 0;
-	ListReaders_Call* call;
+	ListReaders_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -341,6 +346,8 @@ static LONG smartcard_ListReadersA_Call(scard_call_context* smartcard, wStream*
 	cchReaders = SCARD_AUTOALLOCATE;
 	status = ret.ReturnCode = wrap(smartcard, SCardListReadersA, operation->hContext,
 	                               (LPCSTR)call->mszGroups, (LPSTR)&mszReaders, &cchReaders);
+	if (cchReaders == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
 
 	if (status != SCARD_S_SUCCESS)
 	{
@@ -369,10 +376,10 @@ static LONG smartcard_ListReadersA_Call(scard_call_context* smartcard, wStream*
 static LONG smartcard_ListReadersW_Call(scard_call_context* smartcard, wStream* out,
                                         SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	ListReaders_Return ret = { 0 };
 	DWORD cchReaders = 0;
-	ListReaders_Call* call;
+	ListReaders_Call* call = NULL;
 	union
 	{
 		const BYTE* bp;
@@ -396,6 +403,8 @@ static LONG smartcard_ListReadersW_Call(scard_call_context* smartcard, wStream*
 	cchReaders = SCARD_AUTOALLOCATE;
 	status = ret.ReturnCode = wrap(smartcard, SCardListReadersW, operation->hContext, string.wz,
 	                               (LPWSTR)&mszReaders.pw, &cchReaders);
+	if (cchReaders == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
 
 	if (status != SCARD_S_SUCCESS)
 		return scard_log_status_error(TAG, "SCardListReadersW", status);
@@ -418,7 +427,7 @@ static LONG smartcard_IntroduceReaderGroupA_Call(scard_call_context* smartcard,
                                                  SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndStringA_Call* call;
+	ContextAndStringA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -435,7 +444,7 @@ static LONG smartcard_IntroduceReaderGroupW_Call(scard_call_context* smartcard,
                                                  SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndStringW_Call* call;
+	ContextAndStringW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -452,7 +461,7 @@ static LONG smartcard_IntroduceReaderA_Call(scard_call_context* smartcard, wStre
                                             SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndTwoStringA_Call* call;
+	ContextAndTwoStringA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -470,7 +479,7 @@ static LONG smartcard_IntroduceReaderW_Call(scard_call_context* smartcard, wStre
                                             SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndTwoStringW_Call* call;
+	ContextAndTwoStringW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -488,7 +497,7 @@ static LONG smartcard_ForgetReaderA_Call(scard_call_context* smartcard, wStream*
                                          SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndStringA_Call* call;
+	ContextAndStringA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -505,7 +514,7 @@ static LONG smartcard_ForgetReaderW_Call(scard_call_context* smartcard, wStream*
                                          SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndStringW_Call* call;
+	ContextAndStringW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -522,7 +531,7 @@ static LONG smartcard_AddReaderToGroupA_Call(scard_call_context* smartcard, wStr
                                              SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndTwoStringA_Call* call;
+	ContextAndTwoStringA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -540,7 +549,7 @@ static LONG smartcard_AddReaderToGroupW_Call(scard_call_context* smartcard, wStr
                                              SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndTwoStringW_Call* call;
+	ContextAndTwoStringW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -558,7 +567,7 @@ static LONG smartcard_RemoveReaderFromGroupA_Call(scard_call_context* smartcard,
                                                   SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndTwoStringA_Call* call;
+	ContextAndTwoStringA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -576,7 +585,7 @@ static LONG smartcard_RemoveReaderFromGroupW_Call(scard_call_context* smartcard,
                                                   SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	ContextAndTwoStringW_Call* call;
+	ContextAndTwoStringW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -593,10 +602,9 @@ static LONG smartcard_RemoveReaderFromGroupW_Call(scard_call_context* smartcard,
 static LONG smartcard_LocateCardsA_Call(scard_call_context* smartcard, wStream* out,
                                         SMARTCARD_OPERATION* operation)
 {
-	UINT32 x;
-	LONG status;
+	LONG status = 0;
 	LocateCards_Return ret = { 0 };
-	LocateCardsA_Call* call;
+	LocateCardsA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(operation);
@@ -617,7 +625,7 @@ static LONG smartcard_LocateCardsA_Call(scard_call_context* smartcard, wStream*
 			return STATUS_NO_MEMORY;
 	}
 
-	for (x = 0; x < ret.cReaders; x++)
+	for (UINT32 x = 0; x < ret.cReaders; x++)
 	{
 		ret.rgReaderStates[x].dwCurrentState = call->rgReaderStates[x].dwCurrentState;
 		ret.rgReaderStates[x].dwEventState = call->rgReaderStates[x].dwEventState;
@@ -637,10 +645,9 @@ static LONG smartcard_LocateCardsA_Call(scard_call_context* smartcard, wStream*
 static LONG smartcard_LocateCardsW_Call(scard_call_context* smartcard, wStream* out,
                                         SMARTCARD_OPERATION* operation)
 {
-	UINT32 x;
-	LONG status;
+	LONG status = 0;
 	LocateCards_Return ret = { 0 };
-	LocateCardsW_Call* call;
+	LocateCardsW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(operation);
@@ -661,7 +668,7 @@ static LONG smartcard_LocateCardsW_Call(scard_call_context* smartcard, wStream*
 			return STATUS_NO_MEMORY;
 	}
 
-	for (x = 0; x < ret.cReaders; x++)
+	for (UINT32 x = 0; x < ret.cReaders; x++)
 	{
 		ret.rgReaderStates[x].dwCurrentState = call->rgReaderStates[x].dwCurrentState;
 		ret.rgReaderStates[x].dwEventState = call->rgReaderStates[x].dwEventState;
@@ -681,10 +688,10 @@ static LONG smartcard_LocateCardsW_Call(scard_call_context* smartcard, wStream*
 static LONG smartcard_ReadCacheA_Call(scard_call_context* smartcard, wStream* out,
                                       SMARTCARD_OPERATION* operation)
 {
-	LONG status;
-	BOOL autoalloc;
+	LONG status = 0;
+	BOOL autoalloc = 0;
 	ReadCache_Return ret = { 0 };
-	ReadCacheA_Call* call;
+	ReadCacheA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -732,9 +739,9 @@ static LONG smartcard_ReadCacheA_Call(scard_call_context* smartcard, wStream* ou
 static LONG smartcard_ReadCacheW_Call(scard_call_context* smartcard, wStream* out,
                                       SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	ReadCache_Return ret = { 0 };
-	ReadCacheW_Call* call;
+	ReadCacheW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -752,7 +759,7 @@ static LONG smartcard_ReadCacheW_Call(scard_call_context* smartcard, wStream* ou
 	if ((ret.ReturnCode != SCARD_W_CACHE_ITEM_NOT_FOUND) &&
 	    (ret.ReturnCode != SCARD_W_CACHE_ITEM_STALE))
 	{
-		scard_log_status_error(TAG, "SCardReadCacheA", ret.ReturnCode);
+		scard_log_status_error(TAG, "SCardReadCacheW", ret.ReturnCode);
 	}
 
 	status = smartcard_pack_read_cache_return(out, &ret);
@@ -769,7 +776,7 @@ static LONG smartcard_WriteCacheA_Call(scard_call_context* smartcard, wStream* o
                                        SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	WriteCacheA_Call* call;
+	WriteCacheA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -789,7 +796,7 @@ static LONG smartcard_WriteCacheW_Call(scard_call_context* smartcard, wStream* o
                                        SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	WriteCacheW_Call* call;
+	WriteCacheW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -808,7 +815,7 @@ static LONG smartcard_WriteCacheW_Call(scard_call_context* smartcard, wStream* o
 static LONG smartcard_GetTransmitCount_Call(scard_call_context* smartcard, wStream* out,
                                             SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	GetTransmitCount_Return ret = { 0 };
 
 	WINPR_ASSERT(smartcard);
@@ -839,9 +846,9 @@ static LONG smartcard_ReleaseStartedEvent_Call(scard_call_context* smartcard, wS
 static LONG smartcard_GetReaderIcon_Call(scard_call_context* smartcard, wStream* out,
                                          SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	GetReaderIcon_Return ret = { 0 };
-	GetReaderIcon_Call* call;
+	GetReaderIcon_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -853,6 +860,8 @@ static LONG smartcard_GetReaderIcon_Call(scard_call_context* smartcard, wStream*
 	ret.ReturnCode = wrap(smartcard, SCardGetReaderIconW, operation->hContext, call->szReaderName,
 	                      (LPBYTE)&ret.pbData, &ret.cbDataLen);
 	scard_log_status_error(TAG, "SCardGetReaderIconW", ret.ReturnCode);
+	if (ret.cbDataLen == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
 
 	status = smartcard_pack_get_reader_icon_return(out, &ret);
 	wrap(smartcard, SCardFreeMemory, operation->hContext, ret.pbData);
@@ -865,9 +874,9 @@ static LONG smartcard_GetReaderIcon_Call(scard_call_context* smartcard, wStream*
 static LONG smartcard_GetDeviceTypeId_Call(scard_call_context* smartcard, wStream* out,
                                            SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	GetDeviceTypeId_Return ret = { 0 };
-	GetDeviceTypeId_Call* call;
+	GetDeviceTypeId_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -890,11 +899,10 @@ static LONG smartcard_GetStatusChangeA_Call(scard_call_context* smartcard, wStre
                                             SMARTCARD_OPERATION* operation)
 {
 	LONG status = STATUS_NO_MEMORY;
-	UINT32 index;
-	DWORD dwTimeOut, x;
+	DWORD dwTimeOut = 0;
 	const DWORD dwTimeStep = 100;
 	GetStatusChange_Return ret = { 0 };
-	GetStatusChangeA_Call* call;
+	GetStatusChangeA_Call* call = NULL;
 	LPSCARD_READERSTATEA rgReaderStates = NULL;
 
 	WINPR_ASSERT(smartcard);
@@ -913,7 +921,7 @@ static LONG smartcard_GetStatusChangeA_Call(scard_call_context* smartcard, wStre
 			goto fail;
 	}
 
-	for (x = 0; x < MAX(1, dwTimeOut);)
+	for (UINT32 x = 0; x < MAX(1, dwTimeOut);)
 	{
 		if (call->cReaders > 0)
 			memcpy(rgReaderStates, call->rgReaderStates,
@@ -929,7 +937,7 @@ static LONG smartcard_GetStatusChangeA_Call(scard_call_context* smartcard, wStre
 	}
 	scard_log_status_error(TAG, "SCardGetStatusChangeA", ret.ReturnCode);
 
-	for (index = 0; index < ret.cReaders; index++)
+	for (UINT32 index = 0; index < ret.cReaders; index++)
 	{
 		const SCARD_READERSTATEA* cur = &rgReaderStates[index];
 		ReaderState_Return* rout = &ret.rgReaderStates[index];
@@ -953,11 +961,10 @@ static LONG smartcard_GetStatusChangeW_Call(scard_call_context* smartcard, wStre
                                             SMARTCARD_OPERATION* operation)
 {
 	LONG status = STATUS_NO_MEMORY;
-	UINT32 index;
-	DWORD dwTimeOut, x;
+	DWORD dwTimeOut = 0;
 	const DWORD dwTimeStep = 100;
 	GetStatusChange_Return ret = { 0 };
-	GetStatusChangeW_Call* call;
+	GetStatusChangeW_Call* call = NULL;
 	LPSCARD_READERSTATEW rgReaderStates = NULL;
 
 	WINPR_ASSERT(smartcard);
@@ -976,7 +983,7 @@ static LONG smartcard_GetStatusChangeW_Call(scard_call_context* smartcard, wStre
 			goto fail;
 	}
 
-	for (x = 0; x < MAX(1, dwTimeOut);)
+	for (UINT32 x = 0; x < MAX(1, dwTimeOut);)
 	{
 		if (call->cReaders > 0)
 			memcpy(rgReaderStates, call->rgReaderStates,
@@ -994,7 +1001,7 @@ static LONG smartcard_GetStatusChangeW_Call(scard_call_context* smartcard, wStre
 	}
 	scard_log_status_error(TAG, "SCardGetStatusChangeW", ret.ReturnCode);
 
-	for (index = 0; index < ret.cReaders; index++)
+	for (UINT32 index = 0; index < ret.cReaders; index++)
 	{
 		const SCARD_READERSTATEW* cur = &rgReaderStates[index];
 		ReaderState_Return* rout = &ret.rgReaderStates[index];
@@ -1032,10 +1039,10 @@ static LONG smartcard_Cancel_Call(scard_call_context* smartcard, wStream* out,
 static LONG smartcard_ConnectA_Call(scard_call_context* smartcard, wStream* out,
                                     SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	SCARDHANDLE hCard = 0;
 	Connect_Return ret = { 0 };
-	ConnectA_Call* call;
+	ConnectA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1068,10 +1075,10 @@ out_fail:
 static LONG smartcard_ConnectW_Call(scard_call_context* smartcard, wStream* out,
                                     SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	SCARDHANDLE hCard = 0;
 	Connect_Return ret = { 0 };
-	ConnectW_Call* call;
+	ConnectW_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1104,9 +1111,9 @@ out_fail:
 static LONG smartcard_Reconnect_Call(scard_call_context* smartcard, wStream* out,
                                      SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	Reconnect_Return ret = { 0 };
-	Reconnect_Call* call;
+	Reconnect_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1128,7 +1135,7 @@ static LONG smartcard_Disconnect_Call(scard_call_context* smartcard, wStream* ou
                                       SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	HCardAndDisposition_Call* call;
+	HCardAndDisposition_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1162,7 +1169,7 @@ static LONG smartcard_EndTransaction_Call(scard_call_context* smartcard, wStream
                                           SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	HCardAndDisposition_Call* call;
+	HCardAndDisposition_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1179,7 +1186,7 @@ static LONG smartcard_EndTransaction_Call(scard_call_context* smartcard, wStream
 static LONG smartcard_State_Call(scard_call_context* smartcard, wStream* out,
                                  SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	State_Return ret = { 0 };
 
 	WINPR_ASSERT(smartcard);
@@ -1201,12 +1208,12 @@ static LONG smartcard_State_Call(scard_call_context* smartcard, wStream* out,
 static LONG smartcard_StatusA_Call(scard_call_context* smartcard, wStream* out,
                                    SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	Status_Return ret = { 0 };
 	DWORD cchReaderLen = 0;
 	DWORD cbAtrLen = 0;
 	LPSTR mszReaderNames = NULL;
-	Status_Call* call;
+	Status_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1228,6 +1235,9 @@ static LONG smartcard_StatusA_Call(scard_call_context* smartcard, wStream* out,
 	         &ret.dwState, &ret.dwProtocol, cbAtrLen ? (BYTE*)&ret.pbAtr : NULL, &cbAtrLen);
 
 	scard_log_status_error(TAG, "SCardStatusA", status);
+	if (cchReaderLen == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
+
 	if (status == SCARD_S_SUCCESS)
 	{
 		if (!call->fmszReaderNamesIsNULL)
@@ -1252,11 +1262,11 @@ static LONG smartcard_StatusA_Call(scard_call_context* smartcard, wStream* out,
 static LONG smartcard_StatusW_Call(scard_call_context* smartcard, wStream* out,
                                    SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	Status_Return ret = { 0 };
 	LPWSTR mszReaderNames = NULL;
-	Status_Call* call;
-	DWORD cbAtrLen;
+	Status_Call* call = NULL;
+	DWORD cbAtrLen = 0;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1280,6 +1290,9 @@ static LONG smartcard_StatusW_Call(scard_call_context* smartcard, wStream* out,
 	         call->fmszReaderNamesIsNULL ? NULL : (LPWSTR)&mszReaderNames, &ret.cBytes,
 	         &ret.dwState, &ret.dwProtocol, (BYTE*)&ret.pbAtr, &cbAtrLen);
 	scard_log_status_error(TAG, "SCardStatusW", status);
+	if (ret.cBytes == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
+
 	if (status == SCARD_S_SUCCESS)
 	{
 		if (!call->fmszReaderNamesIsNULL)
@@ -1289,6 +1302,7 @@ static LONG smartcard_StatusW_Call(scard_call_context* smartcard, wStream* out,
 	}
 
 	/* SCardStatusW returns number of characters, we need number of bytes */
+	WINPR_ASSERT(ret.cBytes != SCARD_AUTOALLOCATE);
 	ret.cBytes *= sizeof(WCHAR);
 
 	status = smartcard_pack_status_return(out, &ret, TRUE);
@@ -1304,9 +1318,9 @@ static LONG smartcard_StatusW_Call(scard_call_context* smartcard, wStream* out,
 static LONG smartcard_Transmit_Call(scard_call_context* smartcard, wStream* out,
                                     SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	Transmit_Return ret = { 0 };
-	Transmit_Call* call;
+	Transmit_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1346,9 +1360,9 @@ static LONG smartcard_Transmit_Call(scard_call_context* smartcard, wStream* out,
 static LONG smartcard_Control_Call(scard_call_context* smartcard, wStream* out,
                                    SMARTCARD_OPERATION* operation)
 {
-	LONG status;
+	LONG status = 0;
 	Control_Return ret = { 0 };
-	Control_Call* call;
+	Control_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1377,11 +1391,11 @@ static LONG smartcard_GetAttrib_Call(scard_call_context* smartcard, wStream* out
                                      SMARTCARD_OPERATION* operation)
 {
 	BOOL autoAllocate = FALSE;
-	LONG status;
+	LONG status = 0;
 	DWORD cbAttrLen = 0;
 	LPBYTE pbAttr = NULL;
 	GetAttrib_Return ret = { 0 };
-	const GetAttrib_Call* call;
+	const GetAttrib_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(operation);
@@ -1406,6 +1420,9 @@ static LONG smartcard_GetAttrib_Call(scard_call_context* smartcard, wStream* out
 	ret.ReturnCode =
 	    wrap(smartcard, SCardGetAttrib, operation->hCard, call->dwAttrId, pbAttr, &cbAttrLen);
 	scard_log_status_error(TAG, "SCardGetAttrib", ret.ReturnCode);
+	if (cbAttrLen == SCARD_AUTOALLOCATE)
+		return SCARD_F_UNKNOWN_ERROR;
+
 	ret.cbAttrLen = cbAttrLen;
 
 	status = smartcard_pack_get_attrib_return(out, &ret, call->dwAttrId, call->cbAttrLen);
@@ -1421,7 +1438,7 @@ static LONG smartcard_SetAttrib_Call(scard_call_context* smartcard, wStream* out
                                      SMARTCARD_OPERATION* operation)
 {
 	Long_Return ret = { 0 };
-	SetAttrib_Call* call;
+	SetAttrib_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1458,12 +1475,11 @@ static LONG smartcard_AccessStartedEvent_Call(scard_call_context* smartcard, wSt
 static LONG smartcard_LocateCardsByATRA_Call(scard_call_context* smartcard, wStream* out,
                                              SMARTCARD_OPERATION* operation)
 {
-	LONG status;
-	DWORD i, j, k;
+	LONG status = 0;
 	GetStatusChange_Return ret = { 0 };
 	LPSCARD_READERSTATEA state = NULL;
 	LPSCARD_READERSTATEA states = NULL;
-	LocateCardsByATRA_Call* call;
+	LocateCardsByATRA_Call* call = NULL;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(operation);
@@ -1474,9 +1490,9 @@ static LONG smartcard_LocateCardsByATRA_Call(scard_call_context* smartcard, wStr
 	if (!states)
 		return STATUS_NO_MEMORY;
 
-	for (i = 0; i < call->cReaders; i++)
+	for (UINT32 i = 0; i < call->cReaders; i++)
 	{
-		states[i].szReader = (LPSTR)call->rgReaderStates[i].szReader;
+		states[i].szReader = call->rgReaderStates[i].szReader;
 		states[i].dwCurrentState = call->rgReaderStates[i].dwCurrentState;
 		states[i].dwEventState = call->rgReaderStates[i].dwEventState;
 		states[i].cbAtr = call->rgReaderStates[i].cbAtr;
@@ -1487,11 +1503,11 @@ static LONG smartcard_LocateCardsByATRA_Call(scard_call_context* smartcard, wStr
 	                               0x000001F4, states, call->cReaders);
 
 	scard_log_status_error(TAG, "SCardGetStatusChangeA", status);
-	for (i = 0; i < call->cAtrs; i++)
+	for (UINT32 i = 0; i < call->cAtrs; i++)
 	{
-		for (j = 0; j < call->cReaders; j++)
+		for (UINT32 j = 0; j < call->cReaders; j++)
 		{
-			for (k = 0; k < call->rgAtrMasks[i].cbAtr; k++)
+			for (UINT32 k = 0; k < call->rgAtrMasks[i].cbAtr; k++)
 			{
 				if ((call->rgAtrMasks[i].rgbAtr[k] & call->rgAtrMasks[i].rgbMask[k]) !=
 				    (states[j].rgbAtr[k] & call->rgAtrMasks[i].rgbMask[k]))
@@ -1516,7 +1532,7 @@ static LONG smartcard_LocateCardsByATRA_Call(scard_call_context* smartcard, wStr
 		return STATUS_NO_MEMORY;
 	}
 
-	for (i = 0; i < ret.cReaders; i++)
+	for (UINT32 i = 0; i < ret.cReaders; i++)
 	{
 		state = &states[i];
 		ret.rgReaderStates[i].dwCurrentState = state->dwCurrentState;
@@ -1539,11 +1555,11 @@ static LONG smartcard_LocateCardsByATRA_Call(scard_call_context* smartcard, wStr
 LONG smartcard_irp_device_control_call(scard_call_context* smartcard, wStream* out,
                                        UINT32* pIoStatus, SMARTCARD_OPERATION* operation)
 {
-	LONG result;
-	UINT32 offset;
-	UINT32 ioControlCode;
-	size_t outputBufferLength;
-	size_t objectBufferLength;
+	LONG result = 0;
+	UINT32 offset = 0;
+	UINT32 ioControlCode = 0;
+	size_t outputBufferLength = 0;
+	size_t objectBufferLength = 0;
 
 	WINPR_ASSERT(smartcard);
 	WINPR_ASSERT(out);
@@ -1818,7 +1834,7 @@ LONG smartcard_irp_device_control_call(scard_call_context* smartcard, wStream* o
 	return SCARD_S_SUCCESS;
 }
 
-static void context_free(void* arg)
+void context_free(void* arg)
 {
 	struct s_scard_context_element* element = arg;
 	if (!arg)
@@ -1831,8 +1847,8 @@ static void context_free(void* arg)
 
 scard_call_context* smartcard_call_context_new(const rdpSettings* settings)
 {
-	wObject* obj;
-	scard_call_context* ctx;
+	wObject* obj = NULL;
+	scard_call_context* ctx = NULL;
 
 	WINPR_ASSERT(settings);
 	ctx = calloc(1, sizeof(scard_call_context));
@@ -1901,7 +1917,10 @@ scard_call_context* smartcard_call_context_new(const rdpSettings* settings)
 
 	return ctx;
 fail:
+	WINPR_PRAGMA_DIAG_PUSH
+	WINPR_PRAGMA_DIAG_IGNORED_MISMATCHED_DEALLOC
 	smartcard_call_context_free(ctx);
+	WINPR_PRAGMA_DIAG_POP
 	return NULL;
 }
 
@@ -1915,6 +1934,7 @@ void smartcard_call_context_free(scard_call_context* ctx)
 	LinkedList_Free(ctx->names);
 	if (ctx->StartedEvent)
 	{
+		WINPR_ASSERT(ctx->useEmulatedCard || ctx->pWinSCardApi);
 		wrap(ctx, SCardReleaseStartedEvent);
 	}
 
@@ -1987,7 +2007,7 @@ BOOL smarcard_call_set_callbacks(scard_call_context* ctx, void* userdata,
 
 void* smartcard_call_get_context(scard_call_context* ctx, SCARDCONTEXT hContext)
 {
-	struct s_scard_context_element* element;
+	struct s_scard_context_element* element = NULL;
 
 	WINPR_ASSERT(ctx);
 	element = HashTable_GetItemValue(ctx->rgSCardContextList, (void*)hContext);
