@@ -167,7 +167,7 @@ static char* rdtk_font_load_descriptor_file(const char* filename, size_t* pSize)
 
 	if (fileSize.i64 < 1)
 	{
-		fclose(fp);
+		(void)fclose(fp);
 		return NULL;
 	}
 
@@ -175,7 +175,7 @@ static char* rdtk_font_load_descriptor_file(const char* filename, size_t* pSize)
 
 	if (!buffer)
 	{
-		fclose(fp);
+		(void)fclose(fp);
 		return NULL;
 	}
 
@@ -186,7 +186,7 @@ static char* rdtk_font_load_descriptor_file(const char* filename, size_t* pSize)
 			readSize = fileSize.s;
 	}
 
-	fclose(fp);
+	(void)fclose(fp);
 
 	if (readSize < 1)
 	{
@@ -410,7 +410,7 @@ static int rdtk_font_parse_descriptor_buffer(rdtkFont* font, uint8_t* buffer, si
 
 		*r = '\0';
 		/* start parsing glyph */
-		if (index > font->glyphCount)
+		if (index >= font->glyphCount)
 			return -1;
 
 		rdtkGlyph* glyph = &font->glyphs[index];
