@@ -30,7 +30,6 @@
 #include "pf_server.h"
 #include <freerdp/server/proxy/proxy_config.h>
 
-#include <freerdp/server/proxy/proxy_config.h>
 #include <freerdp/server/proxy/proxy_log.h>
 
 #include <freerdp/crypto/crypto.h>
@@ -51,12 +50,12 @@
 
 #define CONFIG_PRINT_SECTION(section) WLog_INFO(TAG, "\t%s:", section)
 #define CONFIG_PRINT_SECTION_KEY(section, key) WLog_INFO(TAG, "\t%s/%s:", section, key)
-#define CONFIG_PRINT_STR(config, key) WLog_INFO(TAG, "\t\t%s: %s", #key, config->key)
+#define CONFIG_PRINT_STR(config, key) WLog_INFO(TAG, "\t\t%s: %s", #key, (config)->key)
 #define CONFIG_PRINT_STR_CONTENT(config, key) \
-	WLog_INFO(TAG, "\t\t%s: %s", #key, config->key ? "set" : NULL)
-#define CONFIG_PRINT_BOOL(config, key) WLog_INFO(TAG, "\t\t%s: %s", #key, boolstr(config->key))
-#define CONFIG_PRINT_UINT16(config, key) WLog_INFO(TAG, "\t\t%s: %" PRIu16 "", #key, config->key)
-#define CONFIG_PRINT_UINT32(config, key) WLog_INFO(TAG, "\t\t%s: %" PRIu32 "", #key, config->key)
+	WLog_INFO(TAG, "\t\t%s: %s", #key, (config)->key ? "set" : NULL)
+#define CONFIG_PRINT_BOOL(config, key) WLog_INFO(TAG, "\t\t%s: %s", #key, boolstr((config)->key))
+#define CONFIG_PRINT_UINT16(config, key) WLog_INFO(TAG, "\t\t%s: %" PRIu16 "", #key, (config)->key)
+#define CONFIG_PRINT_UINT32(config, key) WLog_INFO(TAG, "\t\t%s: %" PRIu32 "", #key, (config)->key)
 
 static const char* bool_str_true = "true";
 static const char* bool_str_false = "false";
@@ -76,13 +75,6 @@ static const char* key_target_pwd = "Password";
 static const char* key_target_domain = "Domain";
 static const char* key_target_tls_seclevel = "TlsSecLevel";
 
-static const char* section_clipboard = "Clipboard";
-static const char* key_clip_text_only = "TextOnly";
-static const char* key_clip_text_max_len = "MaxTextLength";
-
-static const char* section_gfx_settings = "GFXSettings";
-static const char* key_gfx_decode = "DecodeGFX";
-
 static const char* section_plugins = "Plugins";
 static const char* key_plugins_modules = "Modules";
 static const char* key_plugins_required = "Required";
@@ -138,8 +130,8 @@ static char** pf_config_parse_comma_separated_list(const char* list, size_t* cou
 static BOOL pf_config_get_uint16(wIniFile* ini, const char* section, const char* key,
                                  UINT16* result, BOOL required)
 {
-	int val;
-	const char* strval;
+	int val = 0;
+	const char* strval = NULL;
 
 	WINPR_ASSERT(result);
 
@@ -163,8 +155,8 @@ static BOOL pf_config_get_uint16(wIniFile* ini, const char* section, const char*
 static BOOL pf_config_get_uint32(wIniFile* ini, const char* section, const char* key,
                                  UINT32* result, BOOL required)
 {
-	int val;
-	const char* strval;
+	int val = 0;
+	const char* strval = NULL;
 
 	WINPR_ASSERT(result);
 
@@ -189,8 +181,8 @@ static BOOL pf_config_get_uint32(wIniFile* ini, const char* section, const char*
 
 static BOOL pf_config_get_bool(wIniFile* ini, const char* section, const char* key, BOOL fallback)
 {
-	int num_value;
-	const char* str_value;
+	int num_value = 0;
+	const char* str_value = NULL;
 
 	str_value = IniFile_GetKeyValueString(ini, section, key);
 	if (!str_value)
@@ -216,7 +208,7 @@ static BOOL pf_config_get_bool(wIniFile* ini, const char* section, const char* k
 static const char* pf_config_get_str(wIniFile* ini, const char* section, const char* key,
                                      BOOL required)
 {
-	const char* value;
+	const char* value = NULL;
 
 	value = IniFile_GetKeyValueString(ini, section, key);
 
@@ -232,7 +224,7 @@ static const char* pf_config_get_str(wIniFile* ini, const char* section, const c
 
 static BOOL pf_config_load_server(wIniFile* ini, proxyConfig* config)
 {
-	const char* host;
+	const char* host = NULL;
 
 	WINPR_ASSERT(config);
 	host = pf_config_get_str(ini, section_server, key_host, FALSE);
@@ -253,7 +245,7 @@ static BOOL pf_config_load_server(wIniFile* ini, proxyConfig* config)
 
 static BOOL pf_config_load_target(wIniFile* ini, proxyConfig* config)
 {
-	const char* target_value;
+	const char* target_value = NULL;
 
 	WINPR_ASSERT(config);
 	config->FixedTarget = pf_config_get_bool(ini, section_target, key_target_fixed, FALSE);
@@ -359,22 +351,10 @@ static BOOL pf_config_load_security(wIniFile* ini, proxyConfig* config)
 	return TRUE;
 }
 
-static BOOL pf_config_load_clipboard(wIniFile* ini, proxyConfig* config)
-{
-	WINPR_ASSERT(config);
-	config->TextOnly = pf_config_get_bool(ini, section_clipboard, key_clip_text_only, FALSE);
-
-	if (!pf_config_get_uint32(ini, section_clipboard, key_clip_text_max_len, &config->MaxTextLength,
-	                          FALSE))
-		return FALSE;
-
-	return TRUE;
-}
-
 static BOOL pf_config_load_modules(wIniFile* ini, proxyConfig* config)
 {
-	const char* modules_to_load;
-	const char* required_modules;
+	const char* modules_to_load = NULL;
+	const char* required_modules = NULL;
 
 	modules_to_load = pf_config_get_str(ini, section_plugins, key_plugins_modules, FALSE);
 	required_modules = pf_config_get_str(ini, section_plugins, key_plugins_required, FALSE);
@@ -387,13 +367,6 @@ static BOOL pf_config_load_modules(wIniFile* ini, proxyConfig* config)
 	return TRUE;
 }
 
-static BOOL pf_config_load_gfx_settings(wIniFile* ini, proxyConfig* config)
-{
-	WINPR_ASSERT(config);
-	config->DecodeGFX = pf_config_get_bool(ini, section_gfx_settings, key_gfx_decode, FALSE);
-	return TRUE;
-}
-
 static char* pf_config_decode_base64(const char* data, const char* name, size_t* pLength)
 {
 	const char* headers[] = { "-----BEGIN PUBLIC KEY-----", "-----BEGIN RSA PUBLIC KEY-----",
@@ -466,8 +439,8 @@ static char* pf_config_decode_base64(const char* data, const char* name, size_t*
 
 static BOOL pf_config_load_certificates(wIniFile* ini, proxyConfig* config)
 {
-	const char* tmp1;
-	const char* tmp2;
+	const char* tmp1 = NULL;
+	const char* tmp2 = NULL;
 
 	WINPR_ASSERT(ini);
 	WINPR_ASSERT(config);
@@ -604,12 +577,6 @@ proxyConfig* server_config_load_ini(wIniFile* ini)
 		if (!pf_config_load_modules(ini, config))
 			goto out;
 
-		if (!pf_config_load_clipboard(ini, config))
-			goto out;
-
-		if (!pf_config_load_gfx_settings(ini, config))
-			goto out;
-
 		if (!pf_config_load_certificates(ini, config))
 			goto out;
 		config->ini = IniFile_Clone(ini);
@@ -712,16 +679,6 @@ BOOL pf_server_config_dump(const char* file)
 	                              "module1,module2,...") < 0)
 		goto fail;
 
-	/* Clipboard configuration */
-	if (IniFile_SetKeyValueString(ini, section_clipboard, key_clip_text_only, bool_str_false) < 0)
-		goto fail;
-	if (IniFile_SetKeyValueInt(ini, section_clipboard, key_clip_text_max_len, 0) < 0)
-		goto fail;
-
-	/* GFX configuration */
-	if (IniFile_SetKeyValueString(ini, section_gfx_settings, key_gfx_decode, bool_str_false) < 0)
-		goto fail;
-
 	/* Certificate configuration */
 	if (IniFile_SetKeyValueString(ini, section_certificates, key_cert_file,
 	                              "<absolute path to some certificate file> OR") < 0)
@@ -751,7 +708,7 @@ fail:
 proxyConfig* pf_server_config_load_buffer(const char* buffer)
 {
 	proxyConfig* config = NULL;
-	wIniFile* ini;
+	wIniFile* ini = NULL;
 
 	ini = IniFile_New();
 
@@ -798,17 +755,13 @@ out:
 
 static void pf_server_config_print_list(char** list, size_t count)
 {
-	size_t i;
-
 	WINPR_ASSERT(list);
-	for (i = 0; i < count; i++)
+	for (size_t i = 0; i < count; i++)
 		WLog_INFO(TAG, "\t\t- %s", list[i]);
 }
 
 void pf_server_config_print(const proxyConfig* config)
 {
-	size_t x;
-
 	WINPR_ASSERT(config);
 	WLog_INFO(TAG, "Proxy configuration:");
 
@@ -867,22 +820,14 @@ void pf_server_config_print(const proxyConfig* config)
 		pf_server_config_print_list(config->Intercept, config->InterceptCount);
 	}
 
-	CONFIG_PRINT_SECTION(section_clipboard);
-	CONFIG_PRINT_BOOL(config, TextOnly);
-	if (config->MaxTextLength > 0)
-		CONFIG_PRINT_UINT32(config, MaxTextLength);
-
-	CONFIG_PRINT_SECTION(section_gfx_settings);
-	CONFIG_PRINT_BOOL(config, DecodeGFX);
-
 	/* modules */
 	CONFIG_PRINT_SECTION_KEY(section_plugins, key_plugins_modules);
-	for (x = 0; x < config->ModulesCount; x++)
+	for (size_t x = 0; x < config->ModulesCount; x++)
 		CONFIG_PRINT_STR(config, Modules[x]);
 
 	/* Required plugins */
 	CONFIG_PRINT_SECTION_KEY(section_plugins, key_plugins_required);
-	for (x = 0; x < config->RequiredPluginsCount; x++)
+	for (size_t x = 0; x < config->RequiredPluginsCount; x++)
 		CONFIG_PRINT_STR(config, RequiredPlugins[x]);
 
 	CONFIG_PRINT_SECTION(section_certificates);
@@ -1077,9 +1022,9 @@ static BOOL config_plugin_unload(proxyPlugin* plugin)
 
 static BOOL config_plugin_keyboard_event(proxyPlugin* plugin, proxyData* pdata, void* param)
 {
-	BOOL rc;
-	const struct config_plugin_data* custom;
-	const proxyConfig* cfg;
+	BOOL rc = 0;
+	const struct config_plugin_data* custom = NULL;
+	const proxyConfig* cfg = NULL;
 	const proxyKeyboardEventInfo* event_data = (const proxyKeyboardEventInfo*)(param);
 
 	WINPR_ASSERT(plugin);
@@ -1101,9 +1046,9 @@ static BOOL config_plugin_keyboard_event(proxyPlugin* plugin, proxyData* pdata,
 
 static BOOL config_plugin_unicode_event(proxyPlugin* plugin, proxyData* pdata, void* param)
 {
-	BOOL rc;
-	const struct config_plugin_data* custom;
-	const proxyConfig* cfg;
+	BOOL rc = 0;
+	const struct config_plugin_data* custom = NULL;
+	const proxyConfig* cfg = NULL;
 	const proxyUnicodeEventInfo* event_data = (const proxyUnicodeEventInfo*)(param);
 
 	WINPR_ASSERT(plugin);
@@ -1125,9 +1070,9 @@ static BOOL config_plugin_unicode_event(proxyPlugin* plugin, proxyData* pdata, v
 
 static BOOL config_plugin_mouse_event(proxyPlugin* plugin, proxyData* pdata, void* param)
 {
-	BOOL rc;
-	const struct config_plugin_data* custom;
-	const proxyConfig* cfg;
+	BOOL rc = 0;
+	const struct config_plugin_data* custom = NULL;
+	const proxyConfig* cfg = NULL;
 	const proxyMouseEventInfo* event_data = (const proxyMouseEventInfo*)(param);
 
 	WINPR_ASSERT(plugin);
@@ -1148,9 +1093,9 @@ static BOOL config_plugin_mouse_event(proxyPlugin* plugin, proxyData* pdata, voi
 
 static BOOL config_plugin_mouse_ex_event(proxyPlugin* plugin, proxyData* pdata, void* param)
 {
-	BOOL rc;
-	const struct config_plugin_data* custom;
-	const proxyConfig* cfg;
+	BOOL rc = 0;
+	const struct config_plugin_data* custom = NULL;
+	const proxyConfig* cfg = NULL;
 	const proxyMouseExEventInfo* event_data = (const proxyMouseExEventInfo*)(param);
 
 	WINPR_ASSERT(plugin);
@@ -1197,23 +1142,20 @@ static BOOL config_plugin_server_channel_data(proxyPlugin* plugin, proxyData* pd
 
 static BOOL config_plugin_dynamic_channel_create(proxyPlugin* plugin, proxyData* pdata, void* param)
 {
-	pf_utils_channel_mode rc;
-	BOOL accept;
-	const struct config_plugin_data* custom;
-	const proxyConfig* cfg;
+	BOOL accept = 0;
 	const proxyChannelDataEventInfo* channel = (const proxyChannelDataEventInfo*)(param);
 
 	WINPR_ASSERT(plugin);
 	WINPR_ASSERT(pdata);
 	WINPR_ASSERT(channel);
 
-	custom = plugin->custom;
+	const struct config_plugin_data* custom = plugin->custom;
 	WINPR_ASSERT(custom);
 
-	cfg = custom->config;
+	const proxyConfig* cfg = custom->config;
 	WINPR_ASSERT(cfg);
 
-	rc = pf_utils_get_channel_mode(cfg, channel->channel_name);
+	pf_utils_channel_mode rc = pf_utils_get_channel_mode(cfg, channel->channel_name);
 	switch (rc)
 	{
 
@@ -1265,23 +1207,20 @@ static BOOL config_plugin_dynamic_channel_create(proxyPlugin* plugin, proxyData*
 
 static BOOL config_plugin_channel_create(proxyPlugin* plugin, proxyData* pdata, void* param)
 {
-	pf_utils_channel_mode rc;
-	BOOL accept;
-	const struct config_plugin_data* custom;
-	const proxyConfig* cfg;
+	BOOL accept = 0;
 	const proxyChannelDataEventInfo* channel = (const proxyChannelDataEventInfo*)(param);
 
 	WINPR_ASSERT(plugin);
 	WINPR_ASSERT(pdata);
 	WINPR_ASSERT(channel);
 
-	custom = plugin->custom;
+	const struct config_plugin_data* custom = plugin->custom;
 	WINPR_ASSERT(custom);
 
-	cfg = custom->config;
+	const proxyConfig* cfg = custom->config;
 	WINPR_ASSERT(cfg);
 
-	rc = pf_utils_get_channel_mode(cfg, channel->channel_name);
+	pf_utils_channel_mode rc = pf_utils_get_channel_mode(cfg, channel->channel_name);
 	switch (rc)
 	{
 		case PF_UTILS_CHANNEL_INTERCEPT:
@@ -1318,7 +1257,7 @@ static BOOL config_plugin_channel_create(proxyPlugin* plugin, proxyData* pdata,
 
 BOOL pf_config_plugin(proxyPluginsManager* plugins_manager, void* userdata)
 {
-	struct config_plugin_data* custom;
+	struct config_plugin_data* custom = NULL;
 	proxyPlugin plugin = { 0 };
 
 	plugin.name = config_plugin_name;
