@@ -75,8 +75,8 @@ static struct wl_buffer* create_pointer_buffer(UwacSeat* seat, const void* src,
 	wl_shm_pool_destroy(pool);
 
 	if (munmap(data, size) < 0)
-		fprintf(stderr, "%s: munmap(%p, %zu) failed with [%d] %s\n", __func__, data, size, errno,
-		        strerror(errno));
+		(void)fprintf(stderr, "%s: munmap(%p, %zu) failed with [%d] %s\n", __func__, data, size,
+		              errno, strerror(errno));
 
 error_mmap:
 	close(fd);
@@ -818,6 +818,8 @@ static void pointer_handle_motion(void* data, struct wl_pointer* pointer, uint32
 	assert(input);
 
 	UwacWindow* window = input->pointer_focus;
+	if (!window || !window->display)
+		return;
 
 	int scale = window->display->actual_scale;
 	int sx_i = wl_fixed_to_int(sx_w) * scale;
@@ -825,7 +827,7 @@ static void pointer_handle_motion(void* data, struct wl_pointer* pointer, uint32
 	double sx_d = wl_fixed_to_double(sx_w) * scale;
 	double sy_d = wl_fixed_to_double(sy_w) * scale;
 
-	if (!window || (sx_i < 0) || (sy_i < 0))
+	if ((sx_i < 0) || (sy_i < 0))
 		return;
 
 	input->sx = sx_d;
@@ -1101,7 +1103,7 @@ UwacSeat* UwacSeatNew(UwacDisplay* d, uint32_t id, uint32_t version)
 	ret->xkb_context = xkb_context_new(0);
 	if (!ret->xkb_context)
 	{
-		fprintf(stderr, "%s: unable to allocate a xkb_context\n", __func__);
+		(void)fprintf(stderr, "%s: unable to allocate a xkb_context\n", __func__);
 		goto fail;
 	}
 
@@ -1112,13 +1114,13 @@ UwacSeat* UwacSeatNew(UwacDisplay* d, uint32_t id, uint32_t version)
 	ret->repeat_timer_fd = timerfd_create(CLOCK_MONOTONIC, TFD_CLOEXEC | TFD_NONBLOCK);
 	if (ret->repeat_timer_fd < 0)
 	{
-		fprintf(stderr, "%s: error creating repeat timer\n", __func__);
+		(void)fprintf(stderr, "%s: error creating repeat timer\n", __func__);
 		goto fail;
 	}
 	ret->repeat_task.run = keyboard_repeat_func;
 	if (UwacDisplayWatchFd(d, ret->repeat_timer_fd, EPOLLIN, &ret->repeat_task) < 0)
 	{
-		fprintf(stderr, "%s: error polling repeat timer\n", __func__);
+		(void)fprintf(stderr, "%s: error polling repeat timer\n", __func__);
 		goto fail;
 	}
 
