@@ -19,8 +19,6 @@
 
 #include <winpr/config.h>
 
-#if defined __linux__ && !defined ANDROID
-
 #include <winpr/assert.h>
 #include <errno.h>
 #include <termios.h>
@@ -44,7 +42,7 @@ BOOL _comm_set_permissive(HANDLE hDevice, BOOL permissive)
 }
 
 /* Computes VTIME in deciseconds from Ti in milliseconds */
-static UCHAR _vtime(ULONG Ti)
+static UCHAR svtime(ULONG Ti)
 {
 	/* FIXME: look for an equivalent math function otherwise let
 	 * do the compiler do the optimization */
@@ -171,7 +169,7 @@ BOOL CommReadFile(HANDLE hDevice, LPVOID lpBuffer, DWORD nNumberOfBytesToRead,
 	if ((pTimeouts->ReadIntervalTimeout > 0) && (pTimeouts->ReadIntervalTimeout < MAXULONG))
 	{
 		/* Ti */
-		vtime = _vtime(pTimeouts->ReadIntervalTimeout);
+		vtime = svtime(pTimeouts->ReadIntervalTimeout);
 	}
 
 	/* TMAX */
@@ -186,8 +184,8 @@ BOOL CommReadFile(HANDLE hDevice, LPVOID lpBuffer, DWORD nNumberOfBytesToRead,
 	else
 	{
 		/* Tmax */
-		Tmax = nNumberOfBytesToRead * pTimeouts->ReadTotalTimeoutMultiplier +
-		       pTimeouts->ReadTotalTimeoutConstant;
+		Tmax = 1ull * nNumberOfBytesToRead * pTimeouts->ReadTotalTimeoutMultiplier +
+		       1ull * pTimeouts->ReadTotalTimeoutConstant;
 
 		/* INDEFinitely */
 		if ((Tmax == 0) && (pTimeouts->ReadIntervalTimeout < MAXULONG) &&
@@ -398,8 +396,8 @@ BOOL CommWriteFile(HANDLE hDevice, LPCVOID lpBuffer, DWORD nNumberOfBytesToWrite
 	/* discard a possible and no more relevant event */
 	eventfd_read(pComm->fd_write_event, NULL);
 	/* ms */
-	ULONGLONG Tmax = nNumberOfBytesToWrite * pComm->timeouts.WriteTotalTimeoutMultiplier +
-	                 pComm->timeouts.WriteTotalTimeoutConstant;
+	ULONGLONG Tmax = 1ull * nNumberOfBytesToWrite * pComm->timeouts.WriteTotalTimeoutMultiplier +
+	                 1ull * pComm->timeouts.WriteTotalTimeoutConstant;
 	/* NB: select() may update the timeout argument to indicate
 	 * how much time was left. Keep the timeout variable out of
 	 * the while() */
@@ -545,5 +543,3 @@ return_false:
 	LeaveCriticalSection(&pComm->WriteLock);
 	return FALSE;
 }
-
-#endif /* __linux__ */
