@@ -21,11 +21,7 @@
 
 #include <winpr/config.h>
 #include <winpr/debug.h>
-
-#if defined(__FreeBSD_kernel__) && defined(__GLIBC__)
-#define _GNU_SOURCE
-#define KFREEBSD
-#endif
+#include <winpr/assert.h>
 
 #include <winpr/wtypes.h>
 #include <winpr/crt.h>
@@ -87,7 +83,7 @@ static BOOL FileCloseHandle(HANDLE handle)
 		/* Don't close stdin/stdout/stderr */
 		if (fileno(file->fp) > 2)
 		{
-			fclose(file->fp);
+			(void)fclose(file->fp);
 			file->fp = NULL;
 		}
 	}
@@ -100,14 +96,15 @@ static BOOL FileCloseHandle(HANDLE handle)
 static BOOL FileSetEndOfFile(HANDLE hFile)
 {
 	WINPR_FILE* pFile = (WINPR_FILE*)hFile;
-	INT64 size = 0;
 
 	if (!hFile)
 		return FALSE;
 
-	size = _ftelli64(pFile->fp);
+	const INT64 size = _ftelli64(pFile->fp);
+	if (size < 0)
+		return FALSE;
 
-	if (ftruncate(fileno(pFile->fp), size) < 0)
+	if (ftruncate(fileno(pFile->fp), (off_t)size) < 0)
 	{
 		char ebuffer[256] = { 0 };
 		WLog_ERR(TAG, "ftruncate %s failed with %s [0x%08X]", pFile->lpFileName,
@@ -119,8 +116,8 @@ static BOOL FileSetEndOfFile(HANDLE hFile)
 	return TRUE;
 }
 
-static DWORD FileSetFilePointer(HANDLE hFile, LONG lDistanceToMove, PLONG lpDistanceToMoveHigh,
-                                DWORD dwMoveMethod)
+static DWORD FileSetFilePointer(HANDLE hFile, LONG lDistanceToMove,
+                                const PLONG lpDistanceToMoveHigh, DWORD dwMoveMethod)
 {
 	WINPR_FILE* pFile = (WINPR_FILE*)hFile;
 	INT64 offset = 0;
@@ -374,13 +371,13 @@ static BOOL FileGetFileInformationByHandle(HANDLE hFile,
 #else
 	ft = STAT_TIME_TO_FILETIME(st.st_ctime);
 #endif
-	lpFileInformation->ftCreationTime.dwHighDateTime = ((UINT64)ft) >> 32ULL;
+	lpFileInformation->ftCreationTime.dwHighDateTime = (ft) >> 32ULL;
 	lpFileInformation->ftCreationTime.dwLowDateTime = ft & 0xFFFFFFFF;
 	ft = STAT_TIME_TO_FILETIME(st.st_mtime);
-	lpFileInformation->ftLastWriteTime.dwHighDateTime = ((UINT64)ft) >> 32ULL;
+	lpFileInformation->ftLastWriteTime.dwHighDateTime = (ft) >> 32ULL;
 	lpFileInformation->ftLastWriteTime.dwLowDateTime = ft & 0xFFFFFFFF;
 	ft = STAT_TIME_TO_FILETIME(st.st_atime);
-	lpFileInformation->ftLastAccessTime.dwHighDateTime = ((UINT64)ft) >> 32ULL;
+	lpFileInformation->ftLastAccessTime.dwHighDateTime = (ft) >> 32ULL;
 	lpFileInformation->ftLastAccessTime.dwLowDateTime = ft & 0xFFFFFFFF;
 	lpFileInformation->nFileSizeHigh = ((UINT64)st.st_size) >> 32ULL;
 	lpFileInformation->nFileSizeLow = st.st_size & 0xFFFFFFFF;
@@ -565,100 +562,114 @@ static UINT64 FileTimeToUS(const FILETIME* ft)
 	return tmp;
 }
 
+#if defined(_POSIX_C_SOURCE) && (_POSIX_C_SOURCE >= 200809L)
+static struct timespec filetimeToTimespec(const FILETIME* ftime)
+{
+	WINPR_ASSERT(ftime);
+	UINT64 tmp = FileTimeToUS(ftime);
+	struct timespec ts = { 0 };
+	ts.tv_sec = tmp / 1000000ULL;
+	ts.tv_nsec = (tmp % 1000000ULL) * 1000ULL;
+	return ts;
+}
+
 static BOOL FileSetFileTime(HANDLE hFile, const FILETIME* lpCreationTime,
                             const FILETIME* lpLastAccessTime, const FILETIME* lpLastWriteTime)
 {
-	int rc = 0;
-#if defined(__APPLE__) || defined(ANDROID) || defined(__FreeBSD__) || defined(KFREEBSD)
-	struct stat buf;
-	/* OpenBSD, NetBSD and DragonflyBSD support POSIX futimens */
-	struct timeval timevals[2];
-#else
-	struct timespec times[2]; /* last access, last modification */
-#endif
+	struct timespec times[2] = { { UTIME_OMIT, UTIME_OMIT },
+		                         { UTIME_OMIT, UTIME_OMIT } }; /* last access, last modification */
 	WINPR_FILE* pFile = (WINPR_FILE*)hFile;
 
 	if (!hFile)
 		return FALSE;
 
-#if defined(__APPLE__) || defined(ANDROID) || defined(__FreeBSD__) || defined(KFREEBSD)
-	rc = fstat(fileno(pFile->fp), &buf);
+	if (lpLastAccessTime)
+		times[0] = filetimeToTimespec(lpLastAccessTime);
 
-	if (rc < 0)
-		return FALSE;
-
-#endif
-
-	if (!lpLastAccessTime)
-	{
-#if defined(__FreeBSD__) || defined(__APPLE__) || defined(KFREEBSD)
-		timevals[0].tv_sec = buf.st_atime;
-#ifdef _POSIX_SOURCE
-		TIMESPEC_TO_TIMEVAL(&timevals[0], &buf.st_atim);
-#else
-		TIMESPEC_TO_TIMEVAL(&timevals[0], &buf.st_atimespec);
-#endif
-#elif defined(ANDROID)
-		timevals[0].tv_sec = buf.st_atime;
-		timevals[0].tv_usec = buf.st_atimensec / 1000UL;
-#else
-		times[0].tv_sec = UTIME_OMIT;
-		times[0].tv_nsec = UTIME_OMIT;
-#endif
-	}
-	else
-	{
-		UINT64 tmp = FileTimeToUS(lpLastAccessTime);
-#if defined(ANDROID) || defined(__FreeBSD__) || defined(__APPLE__) || defined(KFREEBSD)
-		timevals[0].tv_sec = tmp / 1000000ULL;
-		timevals[0].tv_usec = tmp % 1000000ULL;
-#else
-		times[0].tv_sec = tmp / 1000000ULL;
-		times[0].tv_nsec = (tmp % 1000000ULL) * 1000ULL;
-#endif
-	}
-
-	if (!lpLastWriteTime)
-	{
-#if defined(__FreeBSD__) || defined(__APPLE__) || defined(KFREEBSD)
-		timevals[1].tv_sec = buf.st_mtime;
-#ifdef _POSIX_SOURCE
-		TIMESPEC_TO_TIMEVAL(&timevals[1], &buf.st_mtim);
-#else
-		TIMESPEC_TO_TIMEVAL(&timevals[1], &buf.st_mtimespec);
-#endif
-#elif defined(ANDROID)
-		timevals[1].tv_sec = buf.st_mtime;
-		timevals[1].tv_usec = buf.st_mtimensec / 1000UL;
-#else
-		times[1].tv_sec = UTIME_OMIT;
-		times[1].tv_nsec = UTIME_OMIT;
-#endif
-	}
-	else
-	{
-		UINT64 tmp = FileTimeToUS(lpLastWriteTime);
-#if defined(ANDROID) || defined(__FreeBSD__) || defined(__APPLE__) || defined(KFREEBSD)
-		timevals[1].tv_sec = tmp / 1000000ULL;
-		timevals[1].tv_usec = tmp % 1000000ULL;
-#else
-		times[1].tv_sec = tmp / 1000000ULL;
-		times[1].tv_nsec = (tmp % 1000000ULL) * 1000ULL;
-#endif
-	}
+	if (lpLastWriteTime)
+		times[1] = filetimeToTimespec(lpLastWriteTime);
 
 	// TODO: Creation time can not be handled!
-#if defined(ANDROID) || defined(__FreeBSD__) || defined(__APPLE__) || defined(KFREEBSD)
-	rc = utimes(pFile->lpFileName, timevals);
-#else
-	rc = futimens(fileno(pFile->fp), times);
-#endif
-
+	const int rc = futimens(fileno(pFile->fp), times);
 	if (rc != 0)
 		return FALSE;
 
 	return TRUE;
 }
+#elif defined(__APPLE__) || defined(ANDROID) || defined(__FreeBSD__) || defined(KFREEBSD)
+static struct timeval filetimeToTimeval(const FILETIME* ftime)
+{
+	WINPR_ASSERT(ftime);
+	UINT64 tmp = FileTimeToUS(ftime);
+	struct timeval tv = { 0 };
+	tv.tv_sec = tmp / 1000000ULL;
+	tv.tv_usec = tmp % 1000000ULL;
+	return tv;
+}
+
+static struct timeval statToTimeval(const struct stat* sval)
+{
+	WINPR_ASSERT(sval);
+	struct timeval tv = { 0 };
+#if defined(__FreeBSD__) || defined(__APPLE__) || defined(KFREEBSD)
+	tv.tv_sec = sval->st_atime;
+#ifdef _POSIX_SOURCE
+	TIMESPEC_TO_TIMEVAL(&tv, &sval->st_atim);
+#else
+	TIMESPEC_TO_TIMEVAL(&tv, &sval->st_atimespec);
+#endif
+#elif defined(ANDROID)
+	tv.tv_sec = sval->st_atime;
+	tv.tv_usec = sval->st_atimensec / 1000UL;
+#endif
+	return tv;
+}
+
+static BOOL FileSetFileTime(HANDLE hFile, const FILETIME* lpCreationTime,
+                            const FILETIME* lpLastAccessTime, const FILETIME* lpLastWriteTime)
+{
+	struct stat buf = { 0 };
+	/* OpenBSD, NetBSD and DragonflyBSD support POSIX futimens */
+	WINPR_FILE* pFile = (WINPR_FILE*)hFile;
+
+	if (!hFile)
+		return FALSE;
+
+	const int rc = fstat(fileno(pFile->fp), &buf);
+	if (rc < 0)
+		return FALSE;
+
+	struct timeval timevals[2] = { statToTimeval(&buf), statToTimeval(&buf) };
+	if (lpLastAccessTime)
+		timevals[0] = filetimeToTimeval(lpLastAccessTime);
+
+	if (lpLastWriteTime)
+		timevals[1] = filetimeToTimeval(lpLastWriteTime);
+
+	// TODO: Creation time can not be handled!
+	{
+		const int rc = utimes(pFile->lpFileName, timevals);
+		if (rc != 0)
+			return FALSE;
+	}
+
+	return TRUE;
+}
+#else
+static BOOL FileSetFileTime(HANDLE hFile, const FILETIME* lpCreationTime,
+                            const FILETIME* lpLastAccessTime, const FILETIME* lpLastWriteTime)
+{
+	WINPR_FILE* pFile = (WINPR_FILE*)hFile;
+
+	if (!hFile)
+		return FALSE;
+
+	WLog_WARN(TAG, "TODO: Creation, Access and Write time can not be handled!");
+	WLog_WARN(TAG,
+	          "TODO: Define _POSIX_C_SOURCE >= 200809L or implement a platform specific handler!");
+	return TRUE;
+}
+#endif
 
 static HANDLE_OPS fileOps = {
 	FileIsHandled,
@@ -905,7 +916,7 @@ static HANDLE FileCreateFileA(LPCSTR lpFileName, DWORD dwDesiredAccess, DWORD dw
 		return INVALID_HANDLE_VALUE;
 	}
 
-	setvbuf(fp, NULL, _IONBF, 0);
+	(void)setvbuf(fp, NULL, _IONBF, 0);
 
 #ifdef __sun
 	lock.l_start = 0;
@@ -963,11 +974,11 @@ static BOOL IsFileDevice(LPCTSTR lpDeviceName)
 	return TRUE;
 }
 
-static HANDLE_CREATOR _FileHandleCreator = { IsFileDevice, FileCreateFileA };
+static HANDLE_CREATOR FileHandleCreator = { IsFileDevice, FileCreateFileA };
 
 HANDLE_CREATOR* GetFileHandleCreator(void)
 {
-	return &_FileHandleCreator;
+	return &FileHandleCreator;
 }
 
 static WINPR_FILE* FileHandle_New(FILE* fp)
@@ -975,7 +986,7 @@ static WINPR_FILE* FileHandle_New(FILE* fp)
 	WINPR_FILE* pFile = NULL;
 	char name[MAX_PATH] = { 0 };
 
-	_snprintf(name, sizeof(name), "device_%d", fileno(fp));
+	(void)_snprintf(name, sizeof(name), "device_%d", fileno(fp));
 	pFile = (WINPR_FILE*)calloc(1, sizeof(WINPR_FILE));
 	if (!pFile)
 	{
@@ -1443,7 +1454,7 @@ HANDLE GetFileHandleForFileDescriptor(int fd)
 	if (!fp)
 		return INVALID_HANDLE_VALUE;
 
-	setvbuf(fp, NULL, _IONBF, 0);
+	(void)setvbuf(fp, NULL, _IONBF, 0);
 
 	pFile = FileHandle_New(fp);
 	if (!pFile)
