@@ -174,9 +174,9 @@
  * Asynchronous I/O User Guide:
  * http://code.google.com/p/kernel/wiki/AIOUserGuide
  */
-static wArrayList* _HandleCreators;
+static wArrayList* HandleCreators;
 
-static pthread_once_t _HandleCreatorsInitialized = PTHREAD_ONCE_INIT;
+static pthread_once_t HandleCreatorsInitialized = PTHREAD_ONCE_INIT;
 
 extern HANDLE_CREATOR* GetNamedPipeClientHandleCreator(void);
 
@@ -184,22 +184,22 @@ extern HANDLE_CREATOR* GetNamedPipeClientHandleCreator(void);
 #include "../comm/comm.h"
 #endif /* __linux__ && !defined ANDROID */
 
-static void _HandleCreatorsInit(void)
+static void HandleCreatorsInit(void)
 {
-	WINPR_ASSERT(_HandleCreators == NULL);
-	_HandleCreators = ArrayList_New(TRUE);
+	WINPR_ASSERT(HandleCreators == NULL);
+	HandleCreators = ArrayList_New(TRUE);
 
-	if (!_HandleCreators)
+	if (!HandleCreators)
 		return;
 
 	/*
 	 * Register all file handle creators.
 	 */
-	ArrayList_Append(_HandleCreators, GetNamedPipeClientHandleCreator());
+	ArrayList_Append(HandleCreators, GetNamedPipeClientHandleCreator());
 #if defined __linux__ && !defined ANDROID
-	ArrayList_Append(_HandleCreators, GetCommHandleCreator());
+	ArrayList_Append(HandleCreators, GetCommHandleCreator());
 #endif /* __linux__ && !defined ANDROID */
-	ArrayList_Append(_HandleCreators, GetFileHandleCreator());
+	ArrayList_Append(HandleCreators, GetFileHandleCreator());
 }
 
 #ifdef WINPR_HAVE_AIO_H
@@ -236,35 +236,35 @@ HANDLE CreateFileA(LPCSTR lpFileName, DWORD dwDesiredAccess, DWORD dwShareMode,
 	if (!lpFileName)
 		return INVALID_HANDLE_VALUE;
 
-	if (pthread_once(&_HandleCreatorsInitialized, _HandleCreatorsInit) != 0)
+	if (pthread_once(&HandleCreatorsInitialized, HandleCreatorsInit) != 0)
 	{
 		SetLastError(ERROR_DLL_INIT_FAILED);
 		return INVALID_HANDLE_VALUE;
 	}
 
-	if (_HandleCreators == NULL)
+	if (HandleCreators == NULL)
 	{
 		SetLastError(ERROR_DLL_INIT_FAILED);
 		return INVALID_HANDLE_VALUE;
 	}
 
-	ArrayList_Lock(_HandleCreators);
+	ArrayList_Lock(HandleCreators);
 
-	for (size_t i = 0; i <= ArrayList_Count(_HandleCreators); i++)
+	for (size_t i = 0; i <= ArrayList_Count(HandleCreators); i++)
 	{
-		HANDLE_CREATOR* creator = ArrayList_GetItem(_HandleCreators, i);
+		HANDLE_CREATOR* creator = ArrayList_GetItem(HandleCreators, i);
 
 		if (creator && creator->IsHandled(lpFileName))
 		{
 			HANDLE newHandle =
 			    creator->CreateFileA(lpFileName, dwDesiredAccess, dwShareMode, lpSecurityAttributes,
 			                         dwCreationDisposition, dwFlagsAndAttributes, hTemplateFile);
-			ArrayList_Unlock(_HandleCreators);
+			ArrayList_Unlock(HandleCreators);
 			return newHandle;
 		}
 	}
 
-	ArrayList_Unlock(_HandleCreators);
+	ArrayList_Unlock(HandleCreators);
 	return INVALID_HANDLE_VALUE;
 }
 
@@ -604,16 +604,17 @@ static const char* flagsToStr(char* buffer, size_t size, DWORD flags)
 	if (flags & FILE_ATTRIBUTE_VIRTUAL)
 		append(buffer, size, "FILE_ATTRIBUTE_VIRTUAL");
 
-	_snprintf(strflags, sizeof(strflags), " [0x%08" PRIx32 "]", flags);
+	(void)_snprintf(strflags, sizeof(strflags), " [0x%08" PRIx32 "]", flags);
 	winpr_str_append(strflags, buffer, size, NULL);
 	return buffer;
 }
 
 BOOL SetFileAttributesA(LPCSTR lpFileName, DWORD dwFileAttributes)
 {
-	struct stat st;
-	int fd = 0;
 	BOOL rc = FALSE;
+#ifdef WINPR_HAVE_FCNTL_H
+	struct stat st = { 0 };
+	int fd = 0;
 
 	if (dwFileAttributes & ~FILE_ATTRIBUTE_READONLY)
 	{
@@ -645,6 +646,7 @@ BOOL SetFileAttributesA(LPCSTR lpFileName, DWORD dwFileAttributes)
 	rc = TRUE;
 fail:
 	close(fd);
+#endif
 	return rc;
 }
 
@@ -885,7 +887,8 @@ static WIN32_FILE_SEARCH* file_search_new(const char* name, size_t namelen, cons
 	WIN32_FILE_SEARCH* pFileSearch = (WIN32_FILE_SEARCH*)calloc(1, sizeof(WIN32_FILE_SEARCH));
 	if (!pFileSearch)
 		return NULL;
-	strncpy(pFileSearch->magic, file_search_magic, sizeof(pFileSearch->magic));
+	WINPR_ASSERT(sizeof(file_search_magic) == sizeof(pFileSearch->magic));
+	memcpy(pFileSearch->magic, file_search_magic, sizeof(pFileSearch->magic));
 
 	pFileSearch->lpPath = strndup(name, namelen);
 	pFileSearch->lpPattern = strndup(pattern, patternlen);
@@ -925,7 +928,10 @@ static WIN32_FILE_SEARCH* file_search_new(const char* name, size_t namelen, cons
 
 	return pFileSearch;
 fail:
+	WINPR_PRAGMA_DIAG_PUSH
+	WINPR_PRAGMA_DIAG_IGNORED_MISMATCHED_DEALLOC
 	FindClose(pFileSearch);
+	WINPR_PRAGMA_DIAG_POP
 	return NULL;
 }
 
@@ -936,7 +942,7 @@ static BOOL is_valid_file_search_handle(HANDLE handle)
 		return FALSE;
 	if (pFileSearch == INVALID_HANDLE_VALUE)
 		return FALSE;
-	if (strcmp(file_search_magic, pFileSearch->magic) != 0)
+	if (strncmp(file_search_magic, pFileSearch->magic, sizeof(file_search_magic)) != 0)
 		return FALSE;
 	return TRUE;
 }
@@ -972,13 +978,13 @@ static BOOL FindDataFromStat(const char* path, const struct stat* fileStat,
 #else
 	ft = STAT_TIME_TO_FILETIME(fileStat->st_ctime);
 #endif
-	lpFindFileData->ftCreationTime.dwHighDateTime = ((UINT64)ft) >> 32ULL;
+	lpFindFileData->ftCreationTime.dwHighDateTime = (ft) >> 32ULL;
 	lpFindFileData->ftCreationTime.dwLowDateTime = ft & 0xFFFFFFFF;
 	ft = STAT_TIME_TO_FILETIME(fileStat->st_mtime);
-	lpFindFileData->ftLastWriteTime.dwHighDateTime = ((UINT64)ft) >> 32ULL;
+	lpFindFileData->ftLastWriteTime.dwHighDateTime = (ft) >> 32ULL;
 	lpFindFileData->ftLastWriteTime.dwLowDateTime = ft & 0xFFFFFFFF;
 	ft = STAT_TIME_TO_FILETIME(fileStat->st_atime);
-	lpFindFileData->ftLastAccessTime.dwHighDateTime = ((UINT64)ft) >> 32ULL;
+	lpFindFileData->ftLastAccessTime.dwHighDateTime = (ft) >> 32ULL;
 	lpFindFileData->ftLastAccessTime.dwLowDateTime = ft & 0xFFFFFFFF;
 	lpFindFileData->nFileSizeHigh = ((UINT64)fileStat->st_size) >> 32ULL;
 	lpFindFileData->nFileSizeLow = fileStat->st_size & 0xFFFFFFFF;
