@@ -41,7 +41,6 @@
 #include <sys/un.h>
 #include <sys/socket.h>
 #include <winpr/assert.h>
-#include <unistd.h>
 
 #ifdef WINPR_HAVE_SYS_AIO_H
 #undef WINPR_HAVE_SYS_AIO_H /* disable for now, incomplete */
@@ -113,8 +112,8 @@ static BOOL PipeCloseHandle(HANDLE handle)
 static BOOL PipeRead(PVOID Object, LPVOID lpBuffer, DWORD nNumberOfBytesToRead,
                      LPDWORD lpNumberOfBytesRead, LPOVERLAPPED lpOverlapped)
 {
-	SSIZE_T io_status;
-	WINPR_PIPE* pipe;
+	SSIZE_T io_status = 0;
+	WINPR_PIPE* pipe = NULL;
 	BOOL status = TRUE;
 
 	if (lpOverlapped)
@@ -152,8 +151,8 @@ static BOOL PipeRead(PVOID Object, LPVOID lpBuffer, DWORD nNumberOfBytesToRead,
 static BOOL PipeWrite(PVOID Object, LPCVOID lpBuffer, DWORD nNumberOfBytesToWrite,
                       LPDWORD lpNumberOfBytesWritten, LPOVERLAPPED lpOverlapped)
 {
-	SSIZE_T io_status;
-	WINPR_PIPE* pipe;
+	SSIZE_T io_status = 0;
+	WINPR_PIPE* pipe = NULL;
 
 	if (lpOverlapped)
 	{
@@ -249,8 +248,8 @@ static BOOL NamedPipeCloseHandle(HANDLE handle)
 BOOL NamedPipeRead(PVOID Object, LPVOID lpBuffer, DWORD nNumberOfBytesToRead,
                    LPDWORD lpNumberOfBytesRead, LPOVERLAPPED lpOverlapped)
 {
-	SSIZE_T io_status;
-	WINPR_NAMED_PIPE* pipe;
+	SSIZE_T io_status = 0;
+	WINPR_NAMED_PIPE* pipe = NULL;
 	BOOL status = TRUE;
 
 	if (lpOverlapped)
@@ -342,8 +341,8 @@ BOOL NamedPipeRead(PVOID Object, LPVOID lpBuffer, DWORD nNumberOfBytesToRead,
 BOOL NamedPipeWrite(PVOID Object, LPCVOID lpBuffer, DWORD nNumberOfBytesToWrite,
                     LPDWORD lpNumberOfBytesWritten, LPOVERLAPPED lpOverlapped)
 {
-	SSIZE_T io_status;
-	WINPR_NAMED_PIPE* pipe;
+	SSIZE_T io_status = 0;
+	WINPR_NAMED_PIPE* pipe = NULL;
 	BOOL status = TRUE;
 
 	if (lpOverlapped)
@@ -473,8 +472,8 @@ BOOL CreatePipe(PHANDLE hReadPipe, PHANDLE hWritePipe, LPSECURITY_ATTRIBUTES lpP
                 DWORD nSize)
 {
 	int pipe_fd[2];
-	WINPR_PIPE* pReadPipe;
-	WINPR_PIPE* pWritePipe;
+	WINPR_PIPE* pReadPipe = NULL;
+	WINPR_PIPE* pWritePipe = NULL;
 
 	WINPR_UNUSED(lpPipeAttributes);
 	WINPR_UNUSED(nSize);
@@ -515,8 +514,7 @@ BOOL CreatePipe(PHANDLE hReadPipe, PHANDLE hWritePipe, LPSECURITY_ATTRIBUTES lpP
 
 static void winpr_unref_named_pipe(WINPR_NAMED_PIPE* pNamedPipe)
 {
-	size_t index;
-	NamedPipeServerSocketEntry* baseSocket;
+	NamedPipeServerSocketEntry* baseSocket = NULL;
 
 	if (!pNamedPipe)
 		return;
@@ -526,7 +524,7 @@ static void winpr_unref_named_pipe(WINPR_NAMED_PIPE* pNamedPipe)
 	// WLog_VRB(TAG, "%p (%s)", (void*) pNamedPipe, pNamedPipe->name);
 	ArrayList_Lock(g_NamedPipeServerSockets);
 
-	for (index = 0; index < ArrayList_Count(g_NamedPipeServerSockets); index++)
+	for (size_t index = 0; index < ArrayList_Count(g_NamedPipeServerSockets); index++)
 	{
 		baseSocket =
 		    (NamedPipeServerSocketEntry*)ArrayList_GetItem(g_NamedPipeServerSockets, index);
@@ -558,8 +556,7 @@ HANDLE CreateNamedPipeA(LPCSTR lpName, DWORD dwOpenMode, DWORD dwPipeMode, DWORD
                         DWORD nOutBufferSize, DWORD nInBufferSize, DWORD nDefaultTimeOut,
                         LPSECURITY_ATTRIBUTES lpSecurityAttributes)
 {
-	size_t index;
-	char* lpPipePath;
+	char* lpPipePath = NULL;
 	WINPR_NAMED_PIPE* pNamedPipe = NULL;
 	int serverfd = -1;
 	NamedPipeServerSocketEntry* baseSocket = NULL;
@@ -609,7 +606,7 @@ HANDLE CreateNamedPipeA(LPCSTR lpName, DWORD dwOpenMode, DWORD dwPipeMode, DWORD
 	pNamedPipe->ServerMode = TRUE;
 	pNamedPipe->common.ops = &namedOps;
 
-	for (index = 0; index < ArrayList_Count(g_NamedPipeServerSockets); index++)
+	for (size_t index = 0; index < ArrayList_Count(g_NamedPipeServerSockets); index++)
 	{
 		baseSocket =
 		    (NamedPipeServerSocketEntry*)ArrayList_GetItem(g_NamedPipeServerSockets, index);
@@ -649,22 +646,28 @@ HANDLE CreateNamedPipeA(LPCSTR lpName, DWORD dwOpenMode, DWORD dwPipeMode, DWORD
 
 		if ((serverfd = socket(AF_UNIX, SOCK_STREAM, 0)) == -1)
 		{
-			WLog_ERR(TAG, "CreateNamedPipeA: socket error, %s", strerror(errno));
+			char ebuffer[256] = { 0 };
+			WLog_ERR(TAG, "CreateNamedPipeA: socket error, %s",
+			         winpr_strerror(errno, ebuffer, sizeof(ebuffer)));
 			goto out;
 		}
 
 		s.sun_family = AF_UNIX;
-		sprintf_s(s.sun_path, ARRAYSIZE(s.sun_path), "%s", pNamedPipe->lpFilePath);
+		(void)sprintf_s(s.sun_path, ARRAYSIZE(s.sun_path), "%s", pNamedPipe->lpFilePath);
 
 		if (bind(serverfd, (struct sockaddr*)&s, sizeof(struct sockaddr_un)) == -1)
 		{
-			WLog_ERR(TAG, "CreateNamedPipeA: bind error, %s", strerror(errno));
+			char ebuffer[256] = { 0 };
+			WLog_ERR(TAG, "CreateNamedPipeA: bind error, %s",
+			         winpr_strerror(errno, ebuffer, sizeof(ebuffer)));
 			goto out;
 		}
 
 		if (listen(serverfd, 2) == -1)
 		{
-			WLog_ERR(TAG, "CreateNamedPipeA: listen error, %s", strerror(errno));
+			char ebuffer[256] = { 0 };
+			WLog_ERR(TAG, "CreateNamedPipeA: listen error, %s",
+			         winpr_strerror(errno, ebuffer, sizeof(ebuffer)));
 			goto out;
 		}
 
@@ -685,6 +688,7 @@ HANDLE CreateNamedPipeA(LPCSTR lpName, DWORD dwOpenMode, DWORD dwPipeMode, DWORD
 		if (!ArrayList_Append(g_NamedPipeServerSockets, baseSocket))
 		{
 			free(baseSocket->name);
+			free(baseSocket);
 			goto out;
 		}
 
@@ -709,6 +713,7 @@ HANDLE CreateNamedPipeA(LPCSTR lpName, DWORD dwOpenMode, DWORD dwPipeMode, DWORD
 #endif
 	}
 
+	// NOLINTNEXTLINE(clang-analyzer-unix.Malloc): ArrayList_Append takes ownership of baseSocket
 	ArrayList_Unlock(g_NamedPipeServerSockets);
 	return pNamedPipe;
 out:
@@ -732,9 +737,9 @@ HANDLE CreateNamedPipeW(LPCWSTR lpName, DWORD dwOpenMode, DWORD dwPipeMode, DWOR
 
 BOOL ConnectNamedPipe(HANDLE hNamedPipe, LPOVERLAPPED lpOverlapped)
 {
-	int status;
-	socklen_t length;
-	WINPR_NAMED_PIPE* pNamedPipe;
+	int status = 0;
+	socklen_t length = 0;
+	WINPR_NAMED_PIPE* pNamedPipe = NULL;
 
 	if (lpOverlapped)
 	{
@@ -784,7 +789,7 @@ BOOL ConnectNamedPipe(HANDLE hNamedPipe, LPOVERLAPPED lpOverlapped)
 
 BOOL DisconnectNamedPipe(HANDLE hNamedPipe)
 {
-	WINPR_NAMED_PIPE* pNamedPipe;
+	WINPR_NAMED_PIPE* pNamedPipe = NULL;
 	pNamedPipe = (WINPR_NAMED_PIPE*)hNamedPipe;
 
 	if (pNamedPipe->clientfd != -1)
@@ -815,10 +820,10 @@ BOOL TransactNamedPipe(HANDLE hNamedPipe, LPVOID lpInBuffer, DWORD nInBufferSize
 
 BOOL WaitNamedPipeA(LPCSTR lpNamedPipeName, DWORD nTimeOut)
 {
-	BOOL status;
-	DWORD nWaitTime;
-	char* lpFilePath;
-	DWORD dwSleepInterval;
+	BOOL status = 0;
+	DWORD nWaitTime = 0;
+	char* lpFilePath = NULL;
+	DWORD dwSleepInterval = 0;
 
 	if (!lpNamedPipeName)
 		return FALSE;
@@ -861,9 +866,9 @@ BOOL WaitNamedPipeW(LPCWSTR lpNamedPipeName, DWORD nTimeOut)
 BOOL SetNamedPipeHandleState(HANDLE hNamedPipe, LPDWORD lpMode, LPDWORD lpMaxCollectionCount,
                              LPDWORD lpCollectDataTimeout)
 {
-	int fd;
-	int flags;
-	WINPR_NAMED_PIPE* pNamedPipe;
+	int fd = 0;
+	int flags = 0;
+	WINPR_NAMED_PIPE* pNamedPipe = NULL;
 	pNamedPipe = (WINPR_NAMED_PIPE*)hNamedPipe;
 
 	if (lpMode)
