@@ -516,8 +516,8 @@ BOOL SetWaitableTimer(HANDLE hTimer, const LARGE_INTEGER* lpDueTime, LONG lPerio
 
 	if (lPeriod > 0)
 	{
-		timer->timeout.it_interval.tv_sec = (lPeriod / 1000);              /* seconds */
-		timer->timeout.it_interval.tv_nsec = ((lPeriod % 1000) * 1000000); /* nanoseconds */
+		timer->timeout.it_interval.tv_sec = (lPeriod / 1000ULL);                 /* seconds */
+		timer->timeout.it_interval.tv_nsec = (1000000ULL * (lPeriod % 1000ULL)); /* nanoseconds */
 	}
 
 	if (lpDueTime->QuadPart != 0)
@@ -670,7 +670,6 @@ BOOL CancelWaitableTimer(HANDLE hTimer)
 
 int GetTimerFileDescriptor(HANDLE hTimer)
 {
-#ifndef _WIN32
 	WINPR_HANDLE* hdl = NULL;
 	ULONG type = 0;
 
@@ -682,9 +681,6 @@ int GetTimerFileDescriptor(HANDLE hTimer)
 	}
 
 	return winpr_Handle_getFd(hTimer);
-#else
-	return -1;
-#endif
 }
 
 /**
@@ -707,11 +703,11 @@ static void timespec_add_ms(struct timespec* tspec, UINT32 ms)
 
 static void timespec_gettimeofday(struct timespec* tspec)
 {
-	struct timeval tval;
 	WINPR_ASSERT(tspec);
-	gettimeofday(&tval, NULL);
-	tspec->tv_sec = tval.tv_sec;
-	tspec->tv_nsec = tval.tv_usec * 1000;
+
+	const UINT64 ns = winpr_GetUnixTimeNS();
+	tspec->tv_sec = WINPR_TIME_NS_TO_S(ns);
+	tspec->tv_nsec = WINPR_TIME_NS_REM_NS(ns);
 }
 
 static INT64 timespec_compare(const struct timespec* tspec1, const struct timespec* tspec2)
@@ -881,12 +877,13 @@ static void* TimerQueueThread(void* arg)
 
 		status = pthread_cond_timedwait(&(timerQueue->cond), &(timerQueue->cond_mutex), &timeout);
 		FireExpiredTimerQueueTimers(timerQueue);
+		const BOOL bCancelled = timerQueue->bCancelled;
 		pthread_mutex_unlock(&(timerQueue->cond_mutex));
 
 		if ((status != ETIMEDOUT) && (status != 0))
 			break;
 
-		if (timerQueue->bCancelled)
+		if (bCancelled)
 			break;
 	}
 
