@@ -15,22 +15,21 @@ static DWORD WINAPI thread_func(LPVOID arg)
 
 int TestThreadExitThread(int argc, char* argv[])
 {
-	HANDLE thread;
-	DWORD waitResult;
-	int i;
+	HANDLE thread = NULL;
+	DWORD waitResult = 0;
 
 	WINPR_UNUSED(argc);
 	WINPR_UNUSED(argv);
 
 	/* FIXME: create some noise to better guaranty the test validity and
 	 * decrease the number of loops */
-	for (i = 0; i < 100; i++)
+	for (int i = 0; i < 100; i++)
 	{
 		thread = CreateThread(NULL, 0, thread_func, NULL, 0, NULL);
 
 		if (thread == INVALID_HANDLE_VALUE)
 		{
-			fprintf(stderr, "Got an invalid thread!\n");
+			(void)fprintf(stderr, "Got an invalid thread!\n");
 			return -1;
 		}
 
@@ -43,8 +42,8 @@ int TestThreadExitThread(int argc, char* argv[])
 			 * the end of the thread. Therefore WaitForSingleObject
 			 * never get the signal.
 			 */
-			fprintf(stderr,
-			        "300ms should have been enough for the thread to be in a signaled state\n");
+			(void)fprintf(
+			    stderr, "300ms should have been enough for the thread to be in a signaled state\n");
 			return -1;
 		}
 
