@@ -515,13 +515,6 @@ static size_t get_element_count(const char* list, BOOL* failed, BOOL fullquoted)
 				if (!fullquoted)
 				{
 					int now = is_quoted(*it);
-					if ((quoted == 0) && !first)
-					{
-						WLog_ERR(TAG, "Invalid argument (misplaced quote) '%s'", list);
-						*failed = TRUE;
-						return 0;
-					}
-
 					if (now == quoted)
 						quoted = 0;
 					else if (quoted == 0)
@@ -706,7 +699,7 @@ char** CommandLineParseCommaSeparatedValuesEx(const char* name, const char* list
 			{
 				char* dst = (char*)&p[1];
 				p[0] = dst;
-				sprintf_s(dst, clen + 1, "%s", name);
+				(void)sprintf_s(dst, clen + 1, "%s", name);
 				*count = 1;
 				success = TRUE;
 				goto fail;
