@@ -117,7 +117,8 @@ static void StreamPool_ShiftUsed(wStreamPool* pool, size_t index, INT64 count)
 	else if (count < 0)
 	{
 		const size_t pcount = (size_t)-count;
-		if ((pool->uSize - index - pcount) > 0)
+		const size_t off = index + pcount;
+		if (pool->uSize > off)
 		{
 			MoveMemory(&pool->uArray[index], &pool->uArray[index + pcount],
 			           (pool->uSize - index - pcount) * sizeof(wStream*));
@@ -169,8 +170,8 @@ static void StreamPool_ShiftAvailable(wStreamPool* pool, size_t index, INT64 cou
 	else if (count < 0)
 	{
 		const size_t pcount = (size_t)-count;
-
-		if ((pool->aSize - index - pcount) > 0)
+		const size_t off = index + pcount;
+		if (pool->aSize > off)
 		{
 			MoveMemory(&pool->aArray[index], &pool->aArray[index + pcount],
 			           (pool->aSize - index - pcount) * sizeof(wStream*));
@@ -211,7 +212,7 @@ wStream* StreamPool_Take(wStreamPool* pool, size_t size)
 		if (!s)
 			goto out_fail;
 	}
-	else
+	else if (s)
 	{
 		Stream_SetPosition(s, 0);
 		Stream_SetLength(s, Stream_Capacity(s));
@@ -399,9 +400,10 @@ char* StreamPool_GetStatistics(wStreamPool* pool, char* buffer, size_t size)
 
 	if (!buffer || (size < 1))
 		return NULL;
-	_snprintf(buffer, size - 1,
-	          "aSize    =%" PRIuz ", uSize    =%" PRIuz "aCapacity=%" PRIuz ", uCapacity=%" PRIuz,
-	          pool->aSize, pool->uSize, pool->aCapacity, pool->uCapacity);
+	(void)_snprintf(buffer, size - 1,
+	                "aSize    =%" PRIuz ", uSize    =%" PRIuz "aCapacity=%" PRIuz
+	                ", uCapacity=%" PRIuz,
+	                pool->aSize, pool->uSize, pool->aCapacity, pool->uCapacity);
 	buffer[size - 1] = '\0';
 	return buffer;
 }
