@@ -273,7 +273,7 @@ static void* winpr_bitmap_write_buffer(const BYTE* data, size_t size, UINT32 wid
 		goto fail;
 	Stream_Write(s, bmp_header, WINPR_IMAGE_BMP_HEADER_LEN);
 
-	if (!Stream_EnsureRemainingCapacity(s, stride * height * 1ull))
+	if (!Stream_EnsureRemainingCapacity(s, 1ULL * stride * height))
 		goto fail;
 
 	for (size_t y = 0; y < height; y++)
@@ -325,7 +325,7 @@ int winpr_bitmap_write_ex(const char* filename, const BYTE* data, size_t stride,
 
 fail:
 	if (fp)
-		fclose(fp);
+		(void)fclose(fp);
 	free(bmpdata);
 	return ret;
 }
@@ -341,7 +341,7 @@ static int write_and_free(const char* filename, void* data, size_t size)
 		goto fail;
 
 	size_t w = fwrite(data, 1, size, fp);
-	fclose(fp);
+	(void)fclose(fp);
 
 	status = (w == size) ? 1 : -1;
 fail:
@@ -430,7 +430,8 @@ static int winpr_image_bitmap_read_buffer(wImage* image, const BYTE* buffer, siz
 
 	image->bitsPerPixel = bi.biBitCount;
 	image->bytesPerPixel = (image->bitsPerPixel / 8);
-	image->scanline = ((((bi.biWidth * bi.biBitCount) + 31) & ~31) >> 3);
+	const size_t bpp = (bi.biBitCount + 7) / 8;
+	image->scanline = bi.biWidth * bpp;
 	const size_t bmpsize = 1ull * image->scanline * image->height;
 	if (bmpsize != bi.biSizeImage)
 		WLog_WARN(TAG, "bmpsize=%" PRIuz " != bi.biSizeImage=%" PRIu32, bmpsize, bi.biSizeImage);
@@ -478,9 +479,9 @@ int winpr_image_read(wImage* image, const char* filename)
 		return -1;
 	}
 
-	fseek(fp, 0, SEEK_END);
+	(void)fseek(fp, 0, SEEK_END);
 	INT64 pos = _ftelli64(fp);
-	fseek(fp, 0, SEEK_SET);
+	(void)fseek(fp, 0, SEEK_SET);
 
 	if (pos > 0)
 	{
@@ -495,7 +496,7 @@ int winpr_image_read(wImage* image, const char* filename)
 		}
 		free(buffer);
 	}
-	fclose(fp);
+	(void)fclose(fp);
 	return status;
 }
 
@@ -676,7 +677,7 @@ SSIZE_T winpr_convert_from_jpeg(const BYTE* comp_data, size_t comp_data_bytes, U
 	if (!jpeg_start_decompress(&cinfo))
 		goto fail;
 
-	size_t stride = cinfo.image_width * cinfo.num_components;
+	size_t stride = 1ULL * cinfo.image_width * cinfo.num_components;
 
 	decomp_data = calloc(stride, cinfo.image_height);
 	if (decomp_data)
@@ -687,7 +688,9 @@ SSIZE_T winpr_convert_from_jpeg(const BYTE* comp_data, size_t comp_data_bytes, U
 			if (jpeg_read_scanlines(&cinfo, &row, 1) != 1)
 				goto fail;
 		}
-		size = stride * cinfo.image_height;
+		const size_t ssize = stride * cinfo.image_height;
+		WINPR_ASSERT(ssize < SSIZE_MAX);
+		size = (SSIZE_T)ssize;
 	}
 	jpeg_finish_decompress(&cinfo);
 
@@ -711,13 +714,16 @@ static void* winpr_convert_to_webp(const void* data, size_t size, UINT32 width,
 #else
 	size_t dstSize = 0;
 	uint8_t* pDstData = NULL;
+	WINPR_ASSERT(width <= INT32_MAX);
+	WINPR_ASSERT(height <= INT32_MAX);
+	WINPR_ASSERT(stride <= INT32_MAX);
 	switch (bpp)
 	{
 		case 32:
-			dstSize = WebPEncodeLosslessBGRA(data, width, height, stride, &pDstData);
+			dstSize = WebPEncodeLosslessBGRA(data, (int)width, (int)height, (int)stride, &pDstData);
 			break;
 		case 24:
-			dstSize = WebPEncodeLosslessBGR(data, width, height, stride, &pDstData);
+			dstSize = WebPEncodeLosslessBGR(data, (int)width, (int)height, (int)stride, &pDstData);
 			break;
 		default:
 			return NULL;
@@ -804,7 +810,7 @@ static void png_flush(png_structp png_ptr)
 static SSIZE_T save_png_to_buffer(UINT32 bpp, UINT32 width, UINT32 height, const uint8_t* data,
                                   size_t size, void** pDstData)
 {
-	int rc = -1;
+	SSIZE_T rc = -1;
 	png_structp png_ptr = NULL;
 	png_infop info_ptr = NULL;
 	png_byte** row_pointers = NULL;
@@ -939,14 +945,16 @@ static void* winpr_read_png_from_buffer(const void* data, size_t SrcSize, size_t
 	                 NULL, NULL) != 1)
 		goto fail;
 
-	size_t bpp = PNG_IMAGE_PIXEL_SIZE(color_type);
+	WINPR_ASSERT(bit_depth >= 0);
+	const png_byte channelcount = png_get_channels(png_ptr, info_ptr);
+	const size_t bpp = channelcount * (size_t)bit_depth;
 
 	row_pointers = png_get_rows(png_ptr, info_ptr);
 	if (row_pointers)
 	{
-		const size_t stride = width * bpp;
+		const size_t stride = 1ULL * width * bpp / 8ull;
 		const size_t png_stride = png_get_rowbytes(png_ptr, info_ptr);
-		const size_t size = width * height * bpp;
+		const size_t size = 1ULL * width * height * bpp / 8ull;
 		const size_t copybytes = stride > png_stride ? png_stride : stride;
 
 		rc = malloc(size);
@@ -961,7 +969,7 @@ static void* winpr_read_png_from_buffer(const void* data, size_t SrcSize, size_t
 			*pSize = size;
 			*pWidth = width;
 			*pHeight = height;
-			*pBpp = bpp * 8;
+			*pBpp = bpp;
 		}
 	}
 fail:
