@@ -4,8 +4,8 @@
 int TestBacktrace(int argc, char* argv[])
 {
 	int rc = -1;
-	size_t used, x;
-	char** msg;
+	size_t used = 0;
+	char** msg = NULL;
 	void* stack = winpr_backtrace(20);
 
 	WINPR_UNUSED(argc);
@@ -13,7 +13,7 @@ int TestBacktrace(int argc, char* argv[])
 
 	if (!stack)
 	{
-		fprintf(stderr, "winpr_backtrace failed!\n");
+		(void)fprintf(stderr, "winpr_backtrace failed!\n");
 		return -1;
 	}
 
@@ -21,7 +21,7 @@ int TestBacktrace(int argc, char* argv[])
 
 	if (msg)
 	{
-		for (x = 0; x < used; x++)
+		for (size_t x = 0; x < used; x++)
 			printf("%" PRIuz ": %s\n", x, msg[x]);
 
 		rc = 0;
