@@ -26,7 +26,6 @@
 #include <winpr/cmdline.h>
 #include <winpr/sysinfo.h>
 #include <winpr/crypto.h>
-#include <winpr/file.h>
 
 #ifdef WITH_OPENSSL
 #include <openssl/crypto.h>
@@ -79,9 +78,9 @@ static char* makecert_read_str(BIO* bio, size_t* pOffset)
 
 	while (offset >= length)
 	{
-		size_t new_len;
+		size_t new_len = 0;
 		size_t readBytes = 0;
-		char* new_str;
+		char* new_str = NULL;
 		new_len = length * 2;
 		if (new_len == 0)
 			new_len = 2048;
@@ -112,7 +111,7 @@ static char* makecert_read_str(BIO* bio, size_t* pOffset)
 		if (status <= 0)
 			break;
 
-		offset += (size_t)readBytes;
+		offset += readBytes;
 	}
 
 	if (status < 0)
@@ -131,8 +130,8 @@ static char* makecert_read_str(BIO* bio, size_t* pOffset)
 
 static int makecert_print_command_line_help(COMMAND_LINE_ARGUMENT_A* args, int argc, char** argv)
 {
-	char* str;
-	const COMMAND_LINE_ARGUMENT_A* arg;
+	char* str = NULL;
+	const COMMAND_LINE_ARGUMENT_A* arg = NULL;
 
 	if (!argv || (argc < 1))
 		return -1;
@@ -162,8 +161,8 @@ static int makecert_print_command_line_help(COMMAND_LINE_ARGUMENT_A* args, int a
 				if (!str)
 					return -1;
 
-				sprintf_s(str, length + 1, "%s %s", arg->Name, arg->Format);
-				printf("%-20s", str);
+				(void)sprintf_s(str, length + 1, "%s %s", arg->Name, arg->Format);
+				(void)printf("%-20s", str);
 				free(str);
 			}
 			else
@@ -182,7 +181,7 @@ static int makecert_print_command_line_help(COMMAND_LINE_ARGUMENT_A* args, int a
 static int x509_add_ext(X509* cert, int nid, char* value)
 {
 	X509V3_CTX ctx;
-	X509_EXTENSION* ext;
+	X509_EXTENSION* ext = NULL;
 
 	if (!cert || !value)
 		return 0;
@@ -201,8 +200,8 @@ static int x509_add_ext(X509* cert, int nid, char* value)
 
 static char* x509_name_parse(char* name, char* txt, size_t* length)
 {
-	char* p;
-	char* entry;
+	char* p = NULL;
+	char* entry = NULL;
 
 	if (!name || !txt || !length)
 		return NULL;
@@ -286,9 +285,9 @@ static int command_line_pre_filter(MAKECERT_CONTEXT* context, int index, int arg
 static int makecert_context_parse_arguments(MAKECERT_CONTEXT* context,
                                             COMMAND_LINE_ARGUMENT_A* args, int argc, char** argv)
 {
-	int status;
-	DWORD flags;
-	const COMMAND_LINE_ARGUMENT_A* arg;
+	int status = 0;
+	DWORD flags = 0;
+	const COMMAND_LINE_ARGUMENT_A* arg = NULL;
 
 	if (!context || !argv || (argc < 0))
 		return -1;
@@ -385,7 +384,7 @@ static int makecert_context_parse_arguments(MAKECERT_CONTEXT* context,
 		}
 		CommandLineSwitchCase(arg, "y")
 		{
-			long val;
+			long val = 0;
 
 			if (!(arg->Flags & COMMAND_LINE_ARGUMENT_PRESENT))
 				continue;
@@ -399,14 +398,14 @@ static int makecert_context_parse_arguments(MAKECERT_CONTEXT* context,
 		}
 		CommandLineSwitchCase(arg, "m")
 		{
-			long val;
+			long val = 0;
 
 			if (!(arg->Flags & COMMAND_LINE_ARGUMENT_PRESENT))
 				continue;
 
 			val = strtol(arg->Value, NULL, 0);
 
-			if ((errno != 0) || (val < 1) || (val > 12))
+			if ((errno != 0) || (val < 0))
 				return -1;
 
 			context->duration_months = (int)val;
@@ -441,12 +440,12 @@ int makecert_context_output_certificate_file(MAKECERT_CONTEXT* context, const ch
 {
 #ifdef WITH_OPENSSL
 	FILE* fp = NULL;
-	int status;
-	size_t length;
-	size_t offset;
+	int status = 0;
+	size_t length = 0;
+	size_t offset = 0;
 	char* filename = NULL;
 	char* fullpath = NULL;
-	char* ext;
+	char* ext = NULL;
 	int ret = -1;
 	BIO* bio = NULL;
 	char* x509_str = NULL;
@@ -480,7 +479,7 @@ int makecert_context_output_certificate_file(MAKECERT_CONTEXT* context, const ch
 	else
 		goto out_fail;
 
-	sprintf_s(filename, length + 8, "%s.%s", context->output_file, ext);
+	(void)sprintf_s(filename, length + 8, "%s.%s", context->output_file, ext);
 
 	if (path)
 		fullpath = GetCombinedPath(path, filename);
@@ -595,7 +594,7 @@ out_fail:
 	BIO_free_all(bio);
 
 	if (fp)
-		fclose(fp);
+		(void)fclose(fp);
 
 	free(x509_str);
 	free(filename);
@@ -611,8 +610,8 @@ int makecert_context_output_private_key_file(MAKECERT_CONTEXT* context, const ch
 {
 #ifdef WITH_OPENSSL
 	FILE* fp = NULL;
-	size_t length;
-	size_t offset;
+	size_t length = 0;
+	size_t offset = 0;
 	char* filename = NULL;
 	char* fullpath = NULL;
 	int ret = -1;
@@ -639,7 +638,7 @@ int makecert_context_output_private_key_file(MAKECERT_CONTEXT* context, const ch
 	if (!filename)
 		return -1;
 
-	sprintf_s(filename, length + 8, "%s.key", context->output_file);
+	(void)sprintf_s(filename, length + 8, "%s.key", context->output_file);
 
 	if (path)
 		fullpath = GetCombinedPath(path, filename);
@@ -676,7 +675,7 @@ int makecert_context_output_private_key_file(MAKECERT_CONTEXT* context, const ch
 out_fail:
 
 	if (fp)
-		fclose(fp);
+		(void)fclose(fp);
 
 	BIO_free_all(bio);
 	free(x509_str);
@@ -909,14 +908,14 @@ int makecert_context_process(MAKECERT_CONTEXT* context, int argc, char** argv)
 		{ NULL, 0, NULL, NULL, NULL, -1, NULL, NULL }
 	};
 #ifdef WITH_OPENSSL
-	size_t length;
-	char* entry;
-	int key_length;
+	size_t length = 0;
+	char* entry = NULL;
+	int key_length = 0;
 	long serial = 0;
 	X509_NAME* name = NULL;
 	const EVP_MD* md = NULL;
-	const COMMAND_LINE_ARGUMENT_A* arg;
-	int ret;
+	const COMMAND_LINE_ARGUMENT_A* arg = NULL;
+	int ret = 0;
 	ret = makecert_context_parse_arguments(context, args, argc, argv);
 
 	if (ret < 1)
@@ -989,8 +988,8 @@ int makecert_context_process(MAKECERT_CONTEXT* context, int argc, char** argv)
 
 	ASN1_INTEGER_set(X509_get_serialNumber(context->x509), serial);
 	{
-		ASN1_TIME* before;
-		ASN1_TIME* after;
+		ASN1_TIME* before = NULL;
+		ASN1_TIME* after = NULL;
 #if (OPENSSL_VERSION_NUMBER < 0x10100000L) || defined(LIBRESSL_VERSION_NUMBER)
 		before = X509_get_notBefore(context->x509);
 		after = X509_get_notAfter(context->x509);
@@ -1000,10 +999,9 @@ int makecert_context_process(MAKECERT_CONTEXT* context, int argc, char** argv)
 #endif
 		X509_gmtime_adj(before, 0);
 
-		if (context->duration_months)
-			X509_gmtime_adj(after, (long)(60 * 60 * 24 * 31 * context->duration_months));
-		else if (context->duration_years)
-			X509_gmtime_adj(after, (long)(60 * 60 * 24 * 365 * context->duration_years));
+		long duration = context->duration_months * 31l + context->duration_years * 365l;
+		duration *= 60l * 60l * 24l;
+		X509_gmtime_adj(after, duration);
 	}
 	X509_set_pubkey(context->x509, context->pkey);
 	name = X509_get_subject_name(context->x509);
@@ -1075,9 +1073,9 @@ int makecert_context_process(MAKECERT_CONTEXT* context, int argc, char** argv)
 
 	if (!context->silent)
 	{
-		BIO* bio;
-		int status;
-		char* x509_str;
+		BIO* bio = NULL;
+		int status = 0;
+		char* x509_str = NULL;
 		bio = BIO_new(BIO_s_mem());
 
 		if (!bio)
